/****************************************************************************
*
*       Copyright (c) 1994 Pixel Semiconductor, Inc.  All rights reserved.
*
*       File Name: I2CBUS.C
*
*       Module Abstract:
*       ----------------
*       I2C controls
*
*       Functions:
*       ----------
*       BYTE DDC2BInit ()
*       BYTE I2cCheck ( LPI2CINFO lpI2cInfo )
*       BYTE I2CGetWriteMask ( LPBYTE lpbyWriteOnlyBits )
*       BYTE i2ciniRead ( LPI2CINFO lpI2cInfo )
*       BYTE I2CMasterNegativeAck ( LPI2CSTRUCT lpI2C )
*       BYTE I2CMasterPositiveAck ( LPI2CSTRUCT lpI2C )
*       BYTE I2CSetWriteMask ( BYTE byWriteOnly )
*       BYTE I2CSlavePositiveAck ( LPI2CSTRUCT lpI2C )
*       BYTE i2c_read ( LPVOID buffer, UINT NumXfers, LPI2CINFO lpI2cInfo )
*       BYTE i2c_receive_data ( LPBYTE data_value, LPI2CSTRUCT lpI2C )
*       BYTE i2c_start ( LPI2CSTRUCT lpI2C, LPI2CINFO lpi2cInfo )
*       BYTE i2c_stop ( LPI2CSTRUCT lpI2C )
*       BYTE i2c_write ( LPVOID buffer, UINT NumXfers, LPI2CINFO lpI2cInfo )
*       BYTE i2c_xmit_data ( UINT data_value, LPI2CSTRUCT lpI2C )
*       BYTE ReadPort (LPI2CSTRUCT lpI2C)
*       void SetSdaScl ( LPI2CSTRUCT lpI2C,
*                        BYTE        bySda,
*                        BYTE        byScl,
*                        LPBYTE      lpbyRegister )
*       void WaitLoop ()
*
*****************************************************************************
*
*       Author: Dan Davis
*       Date:   08-04-94
*
*       Revision History:
*       -----------------
*       WHO             WHEN            WHAT/WHY/HOW
*       ---             ----            ------------
*       Frank Xu        9-9-94        Read init file only once.
*                                     Pass the necessary.
*                                     Change to processor independent wait
*                                     loop.
*
*       Ken M         09/27/94        removed RESTORE_.... macros
*
*       Ken M         09/28/94        the function WaitLoop did nothing
*                                     so it was removed.
*
*       Ken M         09/30/94        Added mask for write bits.
*
*       Ken M         10/30/94        Added DDC2B code
*
****************************************************************************/

/*      INCLUDE FILES AND DEFINITIONS   */

#include <stdio.h>
#include <string.h>
#include <assert.h>
#include <asm/io.h>
#include "poke.h"
#include "i2capi.h"
#include "i2cdef.h"
#include "iovid.h"
#include "iodvp.h"

static BOOL      bInitReadFileOnce = 1;
static I2CSTRUCT i2cst;

BYTE      gbyWriteMask ;
BYTE      gbyWriteOnlyBits ;
BOOL      gbIsThisDDC2B = FALSE ;

#define HIGH       1
#define LOW        0
#define SDA_WRITE_BIT  0x08
#define SCL_WRITE_BIT  0x10
#define SDA_READ_BIT   0x40
#define SCL_READ_BIT   0x80

extern G_pvConfigArray[];





/****************************************************************************
*
*  FUNCTION NAME:
*
*    I2cCheck
*
*  FUNCTIONAL DESCRIPTION:
*
*    Generates the start sda and scl bit sequence.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
****************************************************************************/

BYTE DDC2BInit ()
{
  int       i ;
  int       iData ;
  int       iReturn ;
  I2CSTRUCT LocalI2C ;
  I2CINFO   I2CInfo ;

  LocalI2C = i2cst ;

  bInitReadFileOnce = 0 ;
  gbIsThisDDC2B     = TRUE ;

  i2cst.wRdPort           = 0x03c5 ;
  i2cst.wWrPort           = 0x03c5 ;
  i2cst.AckFlag           = 0 ; /* 0=write, 1=read */
  i2cst.WriteSdaBit       = 0x02 ;
  i2cst.WriteSclBit       = 0x01 ;
  i2cst.ReadSdaBit        = 0x80 ;
  i2cst.ReadSclBit        = 0x04 ;
  i2cst.ResetBit          = 0x00 ;
  i2cst.I2cBitsMask       = i2cst.ReadSdaBit | i2cst.ReadSclBit ;
  i2cst.SdaAndSclHighMask = i2cst.ReadSdaBit | i2cst.ReadSclBit ;
  i2cst.SdaAndSclLowMask  = 0 ;
  i2cst.SdaHighSclLowMask = i2cst.ReadSdaBit ;
  i2cst.SdaLowSclHighMask = i2cst.ReadSclBit ;

  gbyWriteOnlyBits = 0 ;
  gbyWriteMask     = i2cst.WriteSdaBit | i2cst.WriteSclBit ;

  /*
   * Lets get the chip id.
   */

  I2CInfo.PortNumber     = 1 ;
  I2CInfo.address        = 0x86 ;
  I2CInfo.subaddress     = 0x26 ;  /* address of FPRD */
  I2CInfo.subsubaddress  = NOTUSED ;
  I2CInfo.address_option = SUBADDRESSUSED ;
  I2CInfo.regsize        = 12 ;

  iData = 0xf0 ;

  iReturn = i2c_write ((LPVOID )&iData, 1, &I2CInfo ) ;

  if ( iReturn != I2C_SUCCESS )
  {
    bInitReadFileOnce = 1 ;
    i2cst             = LocalI2C ;
    gbIsThisDDC2B     = FALSE ;
    return ( I2C_ERROR ) ;
  }

  I2CInfo.subaddress     = 0x29 ;  /* address of FPSTAT */
  I2CInfo.regsize        = 8 ;

  for ( i = 0; i < 100; i++ )
  {
    iReturn = i2c_read ((LPVOID )&iData, 1, &I2CInfo ) ;

    if ( iReturn != I2C_SUCCESS )
    {
      bInitReadFileOnce = 1 ;
      i2cst             = LocalI2C ;
      gbIsThisDDC2B     = FALSE ;
      return ( I2C_ERROR ) ;
    }

    if ( !( iData & 0x04 ))
    {
      break ;
    }
  }

  if ( i >= 99 )
  {
    bInitReadFileOnce = 1 ;
    i2cst             = LocalI2C ;
    gbIsThisDDC2B     = FALSE ;
    return ( I2C_ERROR ) ;
  }

  I2CInfo.subaddress     = 0x28 ;  /* address of FPDAT */
  I2CInfo.regsize        = 12 ;

  iReturn = i2c_read ((LPVOID )&iData, 1, &I2CInfo ) ;

  if ( iReturn != I2C_SUCCESS )
  {
    bInitReadFileOnce = 1 ;
    i2cst             = LocalI2C ;
    gbIsThisDDC2B     = FALSE ;
    return ( I2C_ERROR ) ;
  }

  if (( iData < 1 ) || ( iData > 0xff ))
  {
    bInitReadFileOnce = 1 ;
    i2cst             = LocalI2C ;
    gbIsThisDDC2B     = FALSE ;
    return ( I2C_ERROR ) ;
  }

  return ( I2C_SUCCESS ) ;
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    I2cCheck
*
*  FUNCTIONAL DESCRIPTION:
*
*    Generates the start sda and scl bit sequence.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
****************************************************************************/

BYTE I2cCheck ( LPI2CINFO lpI2cInfo )
{
  BYTE RtnVal;
  I2CINFO i2cInfo;

  assert (lpI2cInfo != NULL);

  /* Make a local copy */
  memcpy((LPI2CINFO) &i2cInfo, lpI2cInfo, sizeof(I2CINFO));

  /*
  *    Fill in the address of the I2C port on the board.
  */

  if(bInitReadFileOnce)
  {
    RtnVal = i2ciniRead((LPI2CINFO) &i2cInfo);
    if(RtnVal == I2C_ERROR)
    {
      return(I2C_ERROR);
    }
    bInitReadFileOnce = 0;
  }

  /*
  *    Check if device is out there.
  */

  RtnVal = i2c_start((LPI2CSTRUCT) &i2cst, (LPI2CINFO) &i2cInfo);

  if(RtnVal)
  {
    return(I2C_ERROR);
  }

  return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    I2CGetWriteMask
*
*  FUNCTIONAL DESCRIPTION:
*
*    Gets the write only bit mask
*
*  RETURN VALUE:
*
*    Returns write mask and places the write only bit mask in the passed in
*    byte.
*
****************************************************************************/

BYTE I2CGetWriteMask ( LPBYTE lpbyWriteOnlyBits )
{
  *lpbyWriteOnlyBits = gbyWriteOnlyBits ;

  return ( gbyWriteMask );
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    i2ciniRead
*
*  FUNCTIONAL DESCRIPTION:
*
*  This routine will read a integer from the specified
*  Section/Key in the currently selected INI file.
*
*  NOTE: By default, szI2CIni will point to the PXVPS.INI
*  path.  If a function wants to override this, it should
*  save and restore this path.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
***************************************************************************/

BYTE i2ciniRead ( LPI2CINFO lpI2cInfo )
{
  static char SectionName[32];
  VIDPorts *pVIDPorts;

  assert(lpI2cInfo != NULL);

  pVIDPorts = (VIDPorts *)G_pvConfigArray[VIDMODBASE];

  /*
  * Fill in i2c structure.
  */

  i2cst.wRdPort = pVIDPorts->VIDPort0;


  i2cst.wWrPort = pVIDPorts->VIDPort0;

  i2cst.WriteSdaBit = SDA_WRITE_BIT;

  i2cst.WriteSclBit = SCL_WRITE_BIT;

  i2cst.ReadSdaBit = SDA_READ_BIT;

  i2cst.ReadSclBit = SCL_READ_BIT;

  i2cst.ResetBit = RESET_BIT;

  i2cst.I2cBitsMask       = i2cst.ReadSdaBit | i2cst.ReadSclBit;
  i2cst.SdaAndSclHighMask =  i2cst.ReadSdaBit | i2cst.ReadSclBit;
  i2cst.SdaAndSclLowMask  = 0;
  i2cst.SdaHighSclLowMask = i2cst.ReadSdaBit;
  i2cst.SdaLowSclHighMask = i2cst.ReadSclBit;

  gbyWriteOnlyBits = 0;

  gbyWriteMask |= i2cst.WriteSdaBit | i2cst.WriteSclBit ;


  return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    i2c_master_negative_ack
*
*  FUNCTIONAL DESCRIPTION:
*
*    Generates a negative acknowledgement from the master
*    receiving device.  This informs the slave transmitter that
*    all data has been read.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
****************************************************************************/

BYTE I2CMasterNegativeAck ( LPI2CSTRUCT lpI2C )
{
  UINT count;
  BYTE i2cRegisterVal;

  assert (lpI2C != NULL);

  /*
  * Read the values for SDA and SCL.
  */

  i2cRegisterVal = ReadPort ( lpI2C ) ;

  /*
  * Release the SDA line (SDA high).
  */

  SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;

  /*
  * Wait for SDA to be released by slave.
  * If more than TIME_DELAY calls to status register result in no release,
  * assume that an abort must be undertaken.
  */

  for(count=0; count<TIME_DELAY; count++)
  {
    i2cRegisterVal = ReadPort ( lpI2C ) ;

    if(i2cRegisterVal & lpI2C->ReadSdaBit) /* SDA released */
    {
      break;
    }
  }

  if(count == TIME_DELAY)
  {
    return(I2C_ERROR);
  }

  /*
  * Drive SCL high while keeping SDA high.
  */

  SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;

  /*
  * Drive SCL low while keeping SDA high.
  */

  SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;

  return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    I2CMasterPositiveAck
*
*  FUNCTIONAL DESCRIPTION:
*
*    Generates a positive acknowledgement from the master
*    receiving device.  This informs the slave transmitter that
*    the previous data byte has been read.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
****************************************************************************/

BYTE I2CMasterPositiveAck ( LPI2CSTRUCT lpI2C )
{
  BYTE i2cRegisterVal;

  assert (lpI2C != NULL);

  /*
  * Read the values for SDA and SCL.
  */

  i2cRegisterVal = ReadPort ( lpI2C ) ;

  /*
  * Drive SDA low (it may already be low if first byte of read is 0).
  * SCL should already be low.
  */

  SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;

  /*
  * Release SCL high.
  */
  SetSdaScl ( lpI2C,  LOW, HIGH, &i2cRegisterVal ) ;

  /*
  * Drive SCL low.
  * SDA is already low.
  */

  SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;

  /*
  * Release the SDA line (SDA high).
  */

  SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;

  return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    I2CSetWriteMask
*
*  FUNCTIONAL DESCRIPTION:
*
*    Sets the write only bit mask
*
*  RETURN VALUE:
*
*    Returns write mask.
*
****************************************************************************/

BYTE I2CSetWriteMask ( BYTE byWriteOnly )
{
  /*
   * Set all the Read/Write bits to 1
   */

  byWriteOnly |= ~gbyWriteOnlyBits ;

  gbyWriteMask = byWriteOnly ;

  return ( gbyWriteMask );
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    I2CSlavePositiveAck
*
*  FUNCTIONAL DESCRIPTION:
*
*    Waits for an acknowledgement from the slave device.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
****************************************************************************/

BYTE I2CSlavePositiveAck ( LPI2CSTRUCT lpI2C )
{
     UINT count;
     BYTE i2cRegisterVal;

     assert(lpI2C != NULL);

     /*
      * Read the values for SDA and SCL.
      */

     i2cRegisterVal = ReadPort ( lpI2C ) ;

     /*
      * Release the SDA line (SDA high).
      */

     SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;

     /*
      * Wait for acknowledgement. This is signaled by SDA being pulled
      * low by the slave.
      * If more than 100 calls to status register result in no ack,
      * assume that an abort must be undertaken.
      */

     for(count=0; count<TIME_DELAY; count++)
     {
       i2cRegisterVal = ReadPort ( lpI2C ) ;

       if(!(i2cRegisterVal & lpI2C->ReadSdaBit))
       {
         break;
       }
     }

     if(count == TIME_DELAY)
     {
       return(I2C_ERROR);
     }

     /*
      * Clock the ack pulse received from the slave.  Hold the SDA line
      * low when it is done.  In this way it can continue on into a natural
      * stop condition by letting go of SDA while SCL is high or the SDA line
      * can be let go prior to clocking in the next byte following an ack.
      */

     SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;
     SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;

     /*
      * Only bother checking a change on the SDA line if a write operation
      * is being generated.  During a read operation, the first bit may be a 0
      * causing the SDA line to remain low.
      */

     if(lpI2C->AckFlag == MASTER_WRITE)
     {
       /*
        * Wait for slave to negate the acknowledge bit (SDA goes high).
        */
       for(count=0; count<TIME_DELAY; count++)
       {
         i2cRegisterVal = ReadPort ( lpI2C ) ;

         if(i2cRegisterVal & lpI2C->ReadSdaBit) /* ack negated */
         {
           break;
         }
       }

       if(count == TIME_DELAY)
       {
         return(I2C_ERROR);
       }
     }

     return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    i2c_read
*
*  FUNCTIONAL DESCRIPTION:
*
*    Reads data from I2C slave device.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
***************************************************************************/

BYTE i2c_read ( LPVOID buffer, UINT NumXfers, LPI2CINFO lpI2cInfo )
{
  BYTE rtn_val;
  UINT xfercnt;
  I2CINFO i2cInfo;

  assert (buffer != NULL);
  assert (lpI2cInfo != NULL);

  /* Make a local copy */
  memcpy((LPI2CINFO) &i2cInfo, lpI2cInfo, sizeof(I2CINFO));

  /*
  *  Fill in the address of the I2C port on the board.
  *  Only read init file once
  */

  if(bInitReadFileOnce)
  {
    rtn_val = i2ciniRead(&i2cInfo);
    if(rtn_val == I2C_ERROR)
    {
      return(I2C_ERROR);
    }
    bInitReadFileOnce = 0;
  }

  /*
  *    This is a master write operation.
  */

  i2cst.AckFlag = MASTER_WRITE;

  /*
  * Write the address of the subaddressed register in order to read from
  * it next.
  */

  rtn_val = i2c_start((LPI2CSTRUCT) &i2cst, (LPI2CINFO) &i2cInfo);
  if(rtn_val)
  {
    return(I2C_ERROR);
  }

  /*
  * Xmit start sequence accessing only the address (no subaddress used,
  * as it was specified in the earlier write to the read register.
  * Make sure that the read address is used (address |= 0x01).
  */

  i2cInfo.address |= 0x01;
  i2cInfo.address_option = ADDRESSUSED;

  /*
  *    This is a master read operation.
  */

  i2cst.AckFlag = MASTER_READ;
  rtn_val = i2c_start((LPI2CSTRUCT)&i2cst, (LPI2CINFO) &i2cInfo);
  if(rtn_val)
  {
    return(I2C_ERROR);
  }

  /*
  * Read 8 bit register data from slave.
  */

  /*
  * If it is not 8 bit register, NumXfers doubled
  * since the xfercnt increment twice.
  */

  if(i2cInfo.regsize != REGSIZE8BITS)
  {
    NumXfers <<= 1;
  }

  for(xfercnt=0; xfercnt<NumXfers; xfercnt++)
  {
    if(i2cInfo.regsize <= REGSIZE8BITS)
    {
      rtn_val = i2c_receive_data((LPBYTE)buffer+xfercnt,
                                (LPI2CSTRUCT) &i2cst);
      if(rtn_val)
      {
        i2c_stop((LPI2CSTRUCT) &i2cst);
        return(I2C_ERROR);
      }
    }
    else
    {
      /* Read upper byte */
      rtn_val = i2c_receive_data((LPBYTE)buffer+xfercnt+1,
                                (LPI2CSTRUCT) &i2cst);
      if(rtn_val)
      {
        i2c_stop((LPI2CSTRUCT) &i2cst);
        return(I2C_ERROR);
      }

      /*
      * Put in Master positive ack.
      */

      I2CMasterPositiveAck((LPI2CSTRUCT) &i2cst);
      if(rtn_val)
      {
        i2c_stop((LPI2CSTRUCT) &i2cst);
        return(I2C_ERROR);
      }

      /* Read lower byte */
      rtn_val = i2c_receive_data((LPBYTE)buffer+xfercnt,
                                (LPI2CSTRUCT) &i2cst);
      if(rtn_val)
      {
        i2c_stop((LPI2CSTRUCT) &i2cst);
        return(I2C_ERROR);
      }

      /* Do not step over the 16 bit read by incrementing the */
      /* xfercnt one more time. */
      xfercnt++;
    }

    /*
    * If this is the final transfer, use a negative ack to inform slave,
    * else use the postive ack.
    */

    if(xfercnt == NumXfers-1)
    {
      rtn_val = I2CMasterNegativeAck((LPI2CSTRUCT) &i2cst);
      if(rtn_val)
      {
        i2c_stop((LPI2CSTRUCT) &i2cst);
        return(I2C_ERROR);
      }
    }
    else
    {
      rtn_val = I2CMasterPositiveAck((LPI2CSTRUCT) &i2cst);
      if(rtn_val)
      {
        i2c_stop((LPI2CSTRUCT) &i2cst);
        return(I2C_ERROR);
      }
    }
  } /* END OF for loop */

  /*
  * Send stop sequence.
  */

  i2c_stop((LPI2CSTRUCT) &i2cst);
  if(rtn_val)
  {
    return(I2C_ERROR);
  }

  return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    i2c_receive_data
*
*  FUNCTIONAL DESCRIPTION:
*
*    Reads in a byte of data from an I2C device.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
****************************************************************************/

BYTE i2c_receive_data ( LPBYTE data_value, LPI2CSTRUCT lpI2C )
{
  UINT index;
  BYTE value8bit=0;
  BYTE i2cRegisterVal;

  assert (data_value != NULL);
  assert (lpI2C != NULL);

  /*
  * Receive Phase.
  * Receive data xfer, msb first.
  */

  for(index=REGSIZE8BITS; index>0; index--)
  {
    /*
    * Read the SDA line.
    */

    i2cRegisterVal = ReadPort ( lpI2C ) ;

    /*
    * Fill in the appropriate bit in the xfer being captured (MSB first).
    */

    if(i2cRegisterVal & lpI2C->ReadSdaBit)
    {
      value8bit |= (UINT) (1 << (index - 1));
    }

    /*
    * Load up the acquired data byte prior to returning to calling routine.
    */

    *data_value = value8bit;

    /*
    * Clock the SCL line, keeping the SDA line high.
    */

    SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;

    /*
    * Drop the SCL line, keeping the SDA line high.
    */

    SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
  }

  return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    i2c_start
*
*  FUNCTIONAL DESCRIPTION:
*
*    Generates the start sda and scl bit sequence.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
****************************************************************************/

BYTE i2c_start ( LPI2CSTRUCT lpI2C, LPI2CINFO lpi2cInfo )
{
  UINT index;
  BYTE rtn_val;
  BYTE address_value;
  BYTE address_count;
  UINT count;
  BYTE i2cRegisterVal;

  assert(lpI2C != NULL);
  assert(lpi2cInfo != NULL);

  /*
  * Read the values for SDA and SCL and transition smoothly
  * into start sequence.
  */

  i2cRegisterVal = ReadPort ( lpI2C ) ;

  if((i2cRegisterVal & lpI2C->I2cBitsMask) ==
    (BYTE)(lpI2C->SdaAndSclLowMask)) /* both low */
  {
    SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
    SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;
  }

  else if ((i2cRegisterVal & lpI2C->I2cBitsMask) ==
    (BYTE)(lpI2C->SdaLowSclHighMask))
  {
    SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;
    SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
    SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;
  }

  else if((i2cRegisterVal & lpI2C->I2cBitsMask) ==
    (BYTE)(i2cst.SdaHighSclLowMask))
  {
    SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;
  }

  /*
  * Wait for both lines to both high (unasserted).
  */

  for(count=0; count<TIME_DELAY; count++)
  {
    i2cRegisterVal = ReadPort ( lpI2C ) ;

    if((i2cRegisterVal & lpI2C->I2cBitsMask) == lpI2C->SdaAndSclHighMask)
    {
      break;
    }
  }

  if(count == TIME_DELAY)
  {
    i2c_stop(lpI2C);
    return(I2C_ERROR);
  }

  /*
  * Transmit start sequence.
  */

  SetSdaScl ( lpI2C,  LOW, HIGH, &i2cRegisterVal ) ;
  SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;

  /*
  *  Transmit address and then subaddress to slave.
  *  Note: main address already contains the write bit (0) as its lsb.
  */

  for(address_count=0; address_count<lpi2cInfo->address_option; address_count++)
  {
    /*
    * Read the values for SDA and SCL and start data sequence.
    */

    i2cRegisterVal = ReadPort ( lpI2C ) ;
    switch(address_count)
    {
      case (ADDRESSUSED-1):
        /*
        * Send out address.
        */
        address_value = lpi2cInfo->address;
        break;

      case (SUBADDRESSUSED-1):
        /*
        * Send out subaddress.
        */
        address_value = lpi2cInfo->subaddress;
        break;

      case (SUB_SUBADDRESSUSED-1):
        /*
        * Send out sub-subaddress.
        */
        address_value = lpi2cInfo->subsubaddress;
        break;

      default:
        i2c_stop(lpI2C);
        return(I2C_ERROR);
    }

    /*
    * If main address, transmit 7-bit address and 1-bit access
    * type (lsb) to slave.  If subaddress, transmit the 8-bit
    * address.
    */

    for(index=0;index<8;index++)
    {
      /*
        * The next bit is high.
        */

      if((address_value << index) & 0x80)
      {
        SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
        SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;
        SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
      }
      /*
        * The next bit is low.
        */
      else
      {
        SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;
        SetSdaScl ( lpI2C,  LOW, HIGH, &i2cRegisterVal ) ;
        SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;
      }
    }

    /*
      * Acknowledgement Phase.
      */

    /*
      * A read start procedure requires a master positive ack.
      * If a write start procedure a slave positive ack is required.
      */

    if(lpI2C->AckFlag == MASTER_WRITE)
    {
      rtn_val = I2CSlavePositiveAck(lpI2C);
      if(rtn_val)
      {
        i2c_stop(lpI2C);
        return(I2C_ERROR);
      }
    }
    else
    {
      rtn_val = I2CMasterPositiveAck(lpI2C);
      if(rtn_val)
      {
        i2c_stop(lpI2C);
        return(I2C_ERROR);
      }
    }
  } /* END OF for(address_count=0;address_count<2;address_count++) */

  return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    i2c_stop
*
*  FUNCTIONAL DESCRIPTION:
*
*    Generates the stop sda and scl bit sequence.
*
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
****************************************************************************/

BYTE i2c_stop ( LPI2CSTRUCT lpI2C )
{
  UINT loopcount=0;
  BYTE i2cRegisterVal;

  assert(lpI2C != NULL);

  /*
  * Get the static value of the register that contains the i2c bits.
  */

  i2cRegisterVal = ReadPort ( lpI2C ) ;

  /*
  * Transmit stop sequence.
  */

  if((i2cRegisterVal & lpI2C->I2cBitsMask) == lpI2C->SdaAndSclHighMask)
  {
    SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
    SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;
    SetSdaScl ( lpI2C,  LOW, HIGH, &i2cRegisterVal ) ;
    SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;
  }
  else if((i2cRegisterVal & lpI2C->I2cBitsMask) == lpI2C->SdaAndSclLowMask)
  {
    SetSdaScl ( lpI2C,  LOW, HIGH, &i2cRegisterVal ) ;
    SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;

    /*
    * If the SDA line is still low then the slave is holding it low
    * for an acknowledgement or data.  Continue clocking until done.
    */

    i2cRegisterVal = ReadPort ( lpI2C ) ;

    if((i2cRegisterVal & lpI2C->I2cBitsMask) != lpI2C->SdaAndSclHighMask)
    {
      loopcount=0;
      while((i2cRegisterVal & lpI2C->I2cBitsMask) == lpI2C->SdaLowSclHighMask)
      {
        SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
        SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;

        /*
        * Check i2c sda line again.
        */

        i2cRegisterVal = ReadPort ( lpI2C ) ;

        if(loopcount++ == REGSIZE8BITS)
        {
          return(I2C_ERROR);
        }
      }

      /*
      * Now that we have SDA and SCL high, send the stop sequence.
      */

      SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
      SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;
      SetSdaScl ( lpI2C,  LOW, HIGH, &i2cRegisterVal ) ;
      SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;
    }
  }

  else if((i2cRegisterVal & lpI2C->I2cBitsMask) == lpI2C->SdaHighSclLowMask)
  {
    SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;
    SetSdaScl ( lpI2C,  LOW, HIGH, &i2cRegisterVal ) ;
    SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;
  }

  else if((i2cRegisterVal & lpI2C->I2cBitsMask) == lpI2C->SdaLowSclHighMask)
  {
    SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;

    /*
    * If the SDA line is still low then the slave is holding it low
    * for an acknowledgement or data.  Continue clocking until done.
    */

    i2cRegisterVal = ReadPort ( lpI2C ) ;

    if((i2cRegisterVal & lpI2C->I2cBitsMask) != lpI2C->SdaAndSclHighMask)
    {
      loopcount=0;

      while((i2cRegisterVal & lpI2C->I2cBitsMask) == lpI2C->SdaLowSclHighMask)
      {
        SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
        SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;

        /*
        * Check i2c sda line again.
        */

        i2cRegisterVal = ReadPort ( lpI2C ) ;

        if(loopcount++ == REGSIZE8BITS)
        {
          return(I2C_ERROR);
        }
      }

      /*
      * Now that we have SDA and SCL high, send the stop sequence.
      */

      SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
      SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;
      SetSdaScl ( lpI2C,  LOW, HIGH, &i2cRegisterVal ) ;
      SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;
    }
  }

  /*
  * Make sure that the i2c lines are not asserted.
  */

  i2cRegisterVal = ReadPort ( lpI2C ) ;

  SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;

  return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    i2c_write
*
*  FUNCTIONAL DESCRIPTION:
*
*    Writes data to I2C slave device.
*    Note: The register data must be right justified.  If writing to
*          a 12-bit register, bits 11-0 contain valid data, bits
*          15-12 are zero filled.  Either all 16 (if reg size > 8 bits)
*          or 8 bits (if reg size <= 8 bits) are transmitted.
*          This justification must be done prior to calling this routine.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
****************************************************************************/

BYTE i2c_write ( LPVOID buffer, UINT NumXfers, LPI2CINFO lpI2cInfo )
{
  BYTE rtn_val;
  UINT xfercnt;
  I2CINFO i2cInfo;


  assert (buffer != NULL);
  assert (lpI2cInfo != NULL);

  /* Make a local copy */
  memcpy((LPI2CINFO) &i2cInfo, lpI2cInfo, sizeof(I2CINFO));

  /*
  * This is a write operation.
  */

  i2cst.AckFlag = MASTER_WRITE;

  /*
  * Fill in the address of the I2C port on the board.
  * Only read init file once.
  */

  if(bInitReadFileOnce)
  {
    rtn_val = i2ciniRead((LPI2CINFO) &i2cInfo);
    if(rtn_val == I2C_ERROR)
    {
      return(I2C_ERROR);
    }
    bInitReadFileOnce = 0;
  }

  /*
  * Xmit start sequence and address the proper device and subaddress
  * within that device.  Make sure that the write address is used.
  */

  i2cInfo.address &= 0xFE;

  rtn_val = i2c_start((LPI2CSTRUCT) &i2cst, (LPI2CINFO) &i2cInfo);
  if(rtn_val)
  {
    return(I2C_ERROR);
  }

  /*
  * The following must be contiguously addressed (auto-incremented) bytes.
  */

  for(xfercnt=0; xfercnt<NumXfers; xfercnt++)
  {
    if(i2cInfo.regsize <= REGSIZE8BITS)
    {
      /*
      * Xmit the data.
      */

      rtn_val = i2c_xmit_data((UINT)(*((LPBYTE)buffer+xfercnt)),
                              (LPI2CSTRUCT) &i2cst);
      if(rtn_val)
      {
        i2c_stop((LPI2CSTRUCT) &i2cst);
        return(I2C_ERROR);
      }
    }
    else
    {
      /*
      * Xmit the data.
      */
      rtn_val = i2c_xmit_data((UINT)(*((UINT *)buffer+xfercnt))>>8,
                              (LPI2CSTRUCT) &i2cst);
      if(rtn_val)
      {
        i2c_stop((LPI2CSTRUCT) &i2cst);
        return(I2C_ERROR);
      }

      rtn_val = i2c_xmit_data((UINT)(*((UINT *)buffer+xfercnt)),
                              (LPI2CSTRUCT) &i2cst);
      if(rtn_val)
      {
        i2c_stop((LPI2CSTRUCT) &i2cst);
        return(I2C_ERROR);
      }
    }   /* if (regsize <= REGSIZE8BITS) */
  }  /* for numxfers loop */

  /*
  *    Send stop sequence.
  */

  rtn_val = i2c_stop((LPI2CSTRUCT) &i2cst);
  if(rtn_val)
  {
    return(I2C_ERROR);
  }
  return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    i2c_xmit_data
*
*  FUNCTIONAL DESCRIPTION:
*
*    Transmits a byte of data to an I2C device.
*
*  RETURN VALUE:
*
*    I2C_SUCCESS OR FAILURE.
*
****************************************************************************/

BYTE i2c_xmit_data ( UINT data_value, LPI2CSTRUCT lpI2C )
{
  UINT index;
  BYTE rtn_val;
  UINT msbbitpolarity=0;
  UINT msbbitmask=0;
  BYTE i2cRegisterVal;

  assert(lpI2C != NULL);

  /*
  * Transfer Phase.
  */

  /*
  * Get the static value of the register that contains the i2c bits.
  */

  i2cRegisterVal = ReadPort ( lpI2C ) ;
  for(index=REGSIZE8BITS; index>0; index--)
  {
    /*
    * Check if the next bit is high.
    */

    msbbitmask = (UINT) (1 << (index - 1));
    msbbitpolarity = data_value & msbbitmask;

    if(msbbitpolarity)
    {
      SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
      SetSdaScl ( lpI2C, HIGH, HIGH, &i2cRegisterVal ) ;
      SetSdaScl ( lpI2C, HIGH,  LOW, &i2cRegisterVal ) ;
    }
    /*
      * The next bit is low.
      */
    else
    {
      SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;
      SetSdaScl ( lpI2C,  LOW, HIGH, &i2cRegisterVal ) ;
      SetSdaScl ( lpI2C,  LOW,  LOW, &i2cRegisterVal ) ;
    }
  }

  /*
  *  Acknowledgement Phase.
  *  Wait for acknowledgement.  If more than 100 calls to status
  *  register result in no ack, assume that an abort must be undertaken.
  */

  rtn_val = I2CSlavePositiveAck ( lpI2C );

  if(rtn_val)
  {
    i2c_stop(lpI2C);
    return(I2C_ERROR);
  }

  return(I2C_SUCCESS);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    ReadPort
*
*  FUNCTIONAL DESCRIPTION:
*
*    Reads the port
*
*  RETURN VALUE:
*
*    BYTE value of the port.
*
****************************************************************************/

BYTE ReadPort (LPI2CSTRUCT lpI2C)
{
  BYTE i2cRegisterVal;

  assert(lpI2C != NULL);
  
  /* WaitLoop () ; */

  if ( gbIsThisDDC2B )
  {
    outb_p ( DDC2B_INDEX, DDC2B_SETUP_PORT);
  }

  /* WaitLoop () ; */

  /*
   * Read the values for SDA and SCL.
   */

  i2cRegisterVal = inb_p ( lpI2C->wRdPort ) ;

  return ( i2cRegisterVal ) ;
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    SetSdaScl
*
*  FUNCTIONAL DESCRIPTION:
*
****************************************************************************/

void SetSdaScl ( LPI2CSTRUCT lpI2C,
                 BYTE        bySda,
                 BYTE        byScl,
                 LPBYTE      lpbyRegister )
{
  if ( gbIsThisDDC2B )
  {
    byScl = ~byScl & 0x01 ;
    bySda = ~bySda & 0x01 ;
  }                        
  
  /* WaitLoop () ; */

  if ( byScl == LOW )
  {
  *lpbyRegister = ( *lpbyRegister & ~lpI2C->ResetBit ) | lpI2C->WriteSclBit ;
  }

  else  /* byScl == HIGH */
  {
  *lpbyRegister &= ~lpI2C->WriteSclBit & ~lpI2C->ResetBit ;
  }

  if ( bySda == LOW )
  {
  *lpbyRegister = ( *lpbyRegister & ~lpI2C->ResetBit ) | lpI2C->WriteSdaBit ;
  }

  else  /* bySda == HIGH */
  {
  *lpbyRegister &= ~lpI2C->WriteSdaBit & ~lpI2C->ResetBit ;
  }

  /*
   * Need to take care of all write only bits.
   */

  *lpbyRegister |= gbyWriteOnlyBits ;
  *lpbyRegister &= gbyWriteMask ;

  if ( gbIsThisDDC2B )
  {
    *lpbyRegister |= 0x40 ;

    outb_p ( DDC2B_INDEX, DDC2B_SETUP_PORT);
  }

  /* WaitLoop () ; */

  outb_p ( (int )*lpbyRegister, lpI2C->wWrPort);
}

/****************************************************************************
*
*  FUNCTION NAME:
*
*    WaitLoop
*
*  FUNCTIONAL DESCRIPTION:
*
*    Provides a wait mechnism.
*
****************************************************************************/

void WaitLoop ()
{
  int i ;
  
  for ( i = 0; i < 0; i++ )
  {
    /*timeGetTime () ; */
  }
}


