/**********************************************************
*
*       Copyright (c) 1994 Pixel Semiconductor, Inc.  All rights reserved.
*
*       File Name: I2CDEF.H
*
*       Module Abstract:
*       ----------------
*       Header file for I2CDEF.H
*
***********************************************************
*
*       Author: Dan Davis
*       Date:   6/1/94
*
*       Revision History:
*       -----------------
*       WHO             WHEN            WHAT/WHY/HOW
*       ---             ----            ------------
*       Frank Xu      9-9-94        Changed the structure definition
*                                   and this structure should only be
*                                   known by I2C internal functions
*
*       Ken M.        09/27/94      changed to use BYTE and WORD
*
*       Ken M.        09/30/94      Added write mask and bits ini keys
*
**********************************************************/

#ifndef I2CDEF
#define I2CDEF

/*
 *    #defines
 */

#ifndef BYTE
#define BYTE unsigned char
#endif

#ifndef LPBYTE
#define LPBYTE unsigned char *
#endif

#ifndef WORD
#define WORD unsigned short
#endif

#ifndef UINT
#define UINT unsigned int
#endif

/*
*   PXVPS.ini Key words.
*/
#define INI_FILE_NAME                   "PXI2C.INI"
#define INI_SECTION_NAME                "InfoPort"
#define INI_READ_ENTRY_NAME             "RdPortAddr"
#define INI_WRITE_ENTRY_NAME            "WrPortAddr"
#define INI_DEFAULT_RTNVAL              -3
#define INI_WRITE_SDA_BIT_ENTRY_NAME    "SdaWriteBit"
#define INI_WRITE_SCL_BIT_ENTRY_NAME    "SclWriteBit"
#define INI_READ_SDA_BIT_ENTRY_NAME     "SdaReadBit"
#define INI_READ_SCL_BIT_ENTRY_NAME     "SclReadBit"
#define INI_RESET_BIT_ENTRY_NAME        "ResetBit"
#define INI_WRITE_BITS_ENTRY_NAME       "WriteOnlyBits"
#define INI_WRITE_MASK_ENTRY_NAME       "WriteMask"

#define MASTER_WRITE                    0
#define MASTER_READ                     1
#define TIME_DELAY                      100
#define POSITIVE_ACK                    0
#define NEGATIVE_ACK                    1

/*
 *    I2C Data Structure.
 */

typedef struct tagI2CSTRUCT
{
  WORD wRdPort;
  WORD wWrPort;
  BYTE AckFlag; // 0=write, 1=read
  BYTE WriteSdaBit;
  BYTE WriteSclBit;
  BYTE ReadSdaBit;
  BYTE ReadSclBit;
  BYTE ResetBit;
  BYTE I2cBitsMask;
  BYTE SdaAndSclHighMask;
  BYTE SdaAndSclLowMask;
  BYTE SdaHighSclLowMask;
  BYTE SdaLowSclHighMask;
} I2CSTRUCT;

typedef I2CSTRUCT * LPI2CSTRUCT;

/*
*   Non-Exported Function Prototypes.
*/
BYTE I2CSlavePositiveAck (LPI2CSTRUCT);
BYTE I2CMasterPositiveAck (LPI2CSTRUCT);
BYTE I2CMasterNegativeAck (LPI2CSTRUCT);
BYTE i2c_xmit_data (UINT, LPI2CSTRUCT);
BYTE i2c_receive_data (LPBYTE, LPI2CSTRUCT);
BYTE i2c_start (LPI2CSTRUCT, LPI2CINFO);
BYTE i2c_stop (LPI2CSTRUCT);
BYTE i2ciniRead (LPI2CINFO);


/*
 * DDC2B items
 */
                                   
#define DDC2B_SDA_WRITE_BIT  0x02       /* 00000010 */
#define DDC2B_SDA_READ_BIT   0x80       /* 10000000 */
#define DDC2B_SCL_WRITE_BIT  0x01       /* 00000001 */
#define DDC2B_SCL_READ_BIT   0x04       /* 00000100 */

#define DDC2B_IO_PORT        0x3c5
#define DDC2B_SETUP_PORT     0x3c4
#define DDC2B_INDEX          0x08  

BYTE I2cCheck ( LPI2CINFO lpI2cInfo ) ;
BYTE i2ciniRead ( LPI2CINFO lpI2cInfo ) ;
BYTE I2CMasterNegativeAck ( LPI2CSTRUCT lpI2C ) ;
BYTE I2CMasterPositiveAck ( LPI2CSTRUCT lpI2C ) ;
BYTE I2CSlavePositiveAck ( LPI2CSTRUCT lpI2C )  ;
BYTE i2c_receive_data ( LPBYTE data_value, LPI2CSTRUCT lpI2C ) ;
BYTE i2c_start ( LPI2CSTRUCT lpI2C, LPI2CINFO lpi2cInfo ) ;
BYTE i2c_stop ( LPI2CSTRUCT lpI2C ) ;
BYTE i2c_xmit_data ( UINT data_value, LPI2CSTRUCT lpI2C ) ;
BYTE ReadPort (LPI2CSTRUCT lpI2C) ;
void SetSdaScl ( LPI2CSTRUCT lpI2C,
                 BYTE        bySda,
                 BYTE        byScl,
                 LPBYTE      lpbyRegister ) ;
void WaitLoop () ;


#endif   
