/**********************************************************
* Copyright Pixel Semiconductor, 1992. All rights reserved.
***********************************************************
*
*       File Name:  io9051.c
*
*       Module Abstract:
*       ----------------
*       This module provides read access to the registers
*       on the VIDEO module.
*
*       Functions:
*       ----------
*
***********************************************************
*       Author: Mike Corry/KAP
*       Date:   1992
*
*       Revision History:
*       -----------------
*       WHO             WHEN      WHAT/WHY/HOW
*       ---             ----      ------------
*
***********************************************************/

/* #includes --------------------------------------------*/

#include <stdio.h>

#include "pxvidapi.h"
#include "iovid.h"
#include "iodvp.h"
#include "i2capi.h"
/*#include "pxvid.h" */

/* Global variables ------------------------------------*/

extern void *G_pvConfigArray[];
int giCurrentVID;
VIDPorts *gpCurrentVIDPorts;

/*extern VIDEO_DEV_CAPS geDeviceCapsArray[PXVID_MAX_PORTS]; */
/*extern CURRENT_VIDEO_PARAMS geCurrentVidParmsArray[PXVID_MAX_PORTS]; */

/**********************************************************
*
*       File Name:  iovid.c
*
*       Module Abstract:  This module provides write access
*               to the registers on the video module.
*
*       Calling Sequence:
*       DrvVidModWrite(ucSubAddr,ucIndex,ucValue);
*
*       Input Parameters:
*       unsigned char   ucSubAddr       Address of on chip Register
*       unsigned char   ucValue         Value to be written
*
*       Output Parameters:
*       iError          Return status  0 = success
*                                     -1 = failure
*
*       Global Variables:
*       none
***********************************************************
*       Author: Mike Corry
*       Date:   10/18/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*     Frank Xu        09-11-94         Make mods to change the i2c structure
*                                      definition.
*
*********************************************************/
int DrvVidModWrite(unsigned char ucSubAddr,unsigned char ucValue)
{
     int iError=0;
     static int iVideoPort;
     int RtnVal;
     static I2CINFO i2cst;
     static unsigned char ucTemp;

     ucTemp = ucValue;

/*
*    Fill in the I2C structure.
*/

/*
*    Load in a relative Port address for now (1 or 2), the pxi2c.dll will
*    convert this to an absolute address by reading out of the pxi2c.ini
*    file.
*/
     i2cst.PortNumber = iVideoPort+1;
     i2cst.address = SAA9051WrAddr;
     i2cst.subaddress = ucSubAddr;
     i2cst.subsubaddress = NOTUSED;
     i2cst.address_option = SUBADDRESSUSED;
     i2cst.regsize = REGSIZE8BITS;

     if(i2c_write (&ucTemp, 1, &i2cst))
     {
	iError = -1;
     }

     return(iError);
}

/**********************************************************
*
*       File Name:  iovid.c
*
*       Module Abstract:  This module provides write access
*               to the registers on the video module.
*
*       Calling Sequence:
*       DrvVidModRead(&bValue);
*
*       Input Parameters:
*       bValue          Pointer to variable
*       Output Parameters:
*       iError          Return status  0 = success
*                                     -1 = failure
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/7/94
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*********************************************************/
int DrvVidModRead(LPVOID iData)
{
     int iError=0;
     static int iVideoPort;

     static I2CINFO i2cst;
     int iTemp;

     /*ucTemp = ucValue; */

/*
*    Fill in the I2C structure.
*/

/*
*    Load in a relative Port address for now (1 or 2), the pxi2c.dll will
*    convert this to an absolute address by reading out of the pxi2c.ini
*    file.
*/
     i2cst.PortNumber = iVideoPort+1;
     i2cst.address = SAA9051WrAddr;
     i2cst.subaddress = NOTUSED;
     i2cst.subsubaddress = NOTUSED;
     i2cst.address_option = ADDRESSUSED;
     /*i2cst.address_option = SUBADDRESSUSED; */
     i2cst.regsize = REGSIZE8BITS;

     if(i2c_read ((LPVOID)iData, 1, &i2cst))
     {
	iError = -1;
     }

     return(iError);
}

/**********************************************************
*
*       File Name:  ioVID.c
*
*       Module Abstract:  This module provides the ability to
*               select the desired video module for communications.
*               In systems where there is only one video module,
*               it is not necessary to call this routine.
*
*       Calling Sequence:
*       lError = ioSetCurrentVID(iProc);
*
*       Input Parameters:
*       int             iProc           Index of desired 2070
*
*       Output Parameters:
*       long            lError          Return 0=Success, -1=Fail
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/2/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/


int ioSetCurrentVID(iProc)
int iProc;
{
int iError;

/* If index out of range or no Vid Mod assigned, indicate error. */
if ((iProc >= MAXVIDMODCOUNT) || (G_pvConfigArray[iProc + VIDMODBASE] == NULL))
  iError = -1;
else
  {
  iError = 0;
  giCurrentVID = iProc;
  gpCurrentVIDPorts = (VIDPorts *) G_pvConfigArray[iProc + VIDMODBASE];
  }
return(iError);
} /* End ioSetCurrentVID */

/**********************************************************
*
*       File Name:  ioDVP.c
*
*       Module Abstract:  This module provides the ability to
*               determine the currently active Video module.
*               In systems where there is only one video module,
*               it is not necessary to call this routine.
*
*       Calling Sequence:
*       iProc = ioGetCurrentVID();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       int             iProc           Index of current 2070
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/2/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

int ioGetCurrentVID()
{
int iProc;

if (gpCurrentVIDPorts == NULL)
  iProc = -1;
else
  iProc = giCurrentVID;
return(iProc);
} /* End ioGetCurrentVID */

/**********************************************************
*
*       File Name:  ioDVP.c
*
*       Module Abstract:  This module provides the ability to
*               determine the currently active Video module's port address.
*
*       Calling Sequence:
*       iPort = ioGetCurrentVIDPort();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       int             iPort           Port of current Vid Mod
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   1/28/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

int ioGetCurrentVIDPort()
{
int iPort;

if (gpCurrentVIDPorts == NULL)
  iPort = -1;
else
  iPort = gpCurrentVIDPorts->VIDPort0;
return(iPort);
} /* End ioGetCurrentVIDPort */



/**********************************************************
*
*       File Name:  iovid.c
*
*       Module Abstract:  This module allows selection of the
*               hue value for decoder on the video module.
*
*       Calling Sequence:
*       int ioSetVideoHue(PhillipsIOParams  far *PIOParams);
*
*       Input Parameters:
*         PhillipsIOParams  far *PIOParams    Pointer to structure
*       Output Parameters:
*         error status
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle A. Pratt
*       Date:   06-09-93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

int ioSetVideoHue(int iHue)
{
  int iError = -1;
  unsigned char bValue;
  unsigned char bSubAddr;

  if ((iHue >= -128) && (iHue <= 127))
  {
    iError =0;
    bValue = (unsigned char) (iHue & 0xff) ;
  } /* if iHue in range */
  else
  {
    return(iError);
  }
  bSubAddr = HUE_PHASE_REG_9051;
  iError = DrvVidModWrite(bSubAddr,bValue);
  return(iError);
} /* End ioSetVideoHue */



/**********************************************************
*
*       File Name:  iovid.c
*
*       Module Abstract:  This module initializes
*               the registers on the video module.
*
*       Calling Sequence:
*       int ioInitVid(PhillipsIOParms far *);
*
*       Input Parameters:
*         PhillipsIOParms far * : pointer to stucture
*       Output Parameters:
*         error status
*
*       Global Variables:
*       none
***********************************************************
*       Author: Mike Corry
*       Date:   10/18/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/


int ioInitVid(LPCURRENT_VIDEO_PARAMS lpParmStruct)
{
     unsigned char bSubAddr;
     unsigned char bValue;
     int iError=0;



/*
*       Load up the 9051 registers.
*/
	bValue = VAL_idel;
	bSubAddr = IDEL_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

	bValue = VAL_hsb5;
	bSubAddr = HSY_START_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

	bValue = VAL_hss5;
	bSubAddr = HSY_STOP_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

	bValue = VAL_hcb5;
	bSubAddr = HC_START_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

	bValue = VAL_hcs5;
	bSubAddr = HC_STOP_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

	bValue = VAL_hsp5;
	bSubAddr = HS_START_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

/*  bValue = (unsigned char)lpParmStruct->iVideoFilter; */
/*  if (lpParmStruct->eVInFormat == SVHS) */
/*    bValue |= 80; */
	/* */
	/* @MIKEY, Bogus value?  Causes a hatched artifact. */
	/* */
	#if 0
	  bValue = VAL_lum;
	#else
	  bValue = P51_FILTER_4;
	#endif
	bSubAddr = HOR_PEAK_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

	bValue = VAL_hue;
	bSubAddr = HUE_PHASE_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

	/*if ( geCurrentVidParmsArray[giCurrentVID].eVInFormat == PAL ) */
	/*{ */
	/*   bValue = VAL_cktq_Pal ; */
	/*} */
	/*else if ( geCurrentVidParmsArray[giCurrentVID].eVInFormat == SECAM ) */
	/*{ */
	/*   bValue = VAL_cktq_Sec ; */
	/*} */
	/*else */
	/*{ */
	   bValue = VAL_cktq_NTSC ;
	/*} */

	bSubAddr = CTRL1_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

	bValue = VAL_ckts;
	bSubAddr = CTRL2_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

	bValue = VAL_plse;
	bSubAddr = CTRL3_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

	bValue = VAL_sese;
	bSubAddr = SECAM_DLY_REG_9051;
	if (iError = DrvVidModWrite(bSubAddr,bValue)) return(iError);

     return(0);
} /* End ioInitVid */


/**********************************************************
*
*       File Name:  iovid.c
*
*       Module Abstract:  This module allows selection of the
*               video channel input on the video module.
*
*       Calling Sequence:
*       int ioSetVidChannel(PhillipsIOParams  far *PIOParams);
*
*       Input Parameters:
*         PhillipsIOParams  far *PIOParams    Pointer to structure
*       Output Parameters:
*         error status
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle A. Pratt
*       Date:   05-10-93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioSetVidChannel(int iVideoChannel)
{
  int iError = -1;
  unsigned char bValue;
  unsigned char bSubAddr;

  /* */
  /* @MIKEY, Why make this check?  What does this mean? */
  /* */
  /*if ((geCurrentVidParmsArray[giCurrentVID].eVInFormat == NTSC) || */
  /*    (geCurrentVidParmsArray[giCurrentVID].eVInFormat == PAL) || */
  /*    (geCurrentVidParmsArray[giCurrentVID].eVInFormat == SECAM) ) */
  /*{ */
    switch(iVideoChannel)
    {
      case PCS_CHAN1_INPUT:
        bValue = VAL_iock_port0;    /* j4 */
        iError=0;
        break;
      case PCS_CHAN2_INPUT:
        bValue = VAL_iock_port1;    /* j8 */
        iError=0;
        break;
      case PCS_CHAN3_INPUT:
        bValue = VAL_iock_port2;    /* j7 */
        iError=0;
        break;
      default:
        return(iError);
    } /* Switch bChannelIn */
  /*} // if NTSC PAL or SECAM */

  bSubAddr = CTRL3_REG_9051 ;
  iError = DrvVidModWrite(bSubAddr,bValue);
  return(iError);
} /* End ioSetVidChannel */

/**********************************************************
*
*       File Name:  iovid.c
*
*       Module Abstract:  This module allows selection of the
*               decoder filter on the video module. The filter
*               values are listed in an array with the visual
*               sharpness of the filter increasing with the
*               index of the array.
*
*       Calling Sequence:
*       int ioSetVidFilter(PhillipsIOParams  far *PIOParams);
*
*       Input Parameters:
*         PhillipsIOParams  far *PIOParams    Pointer to structure
*       Output Parameters:
*         error status
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle A. Pratt
*       Date:   05-10-93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioSetVidFilter(int iFilter)

{
  int iError = -1;
  unsigned char bValue;
  unsigned char bSubAddr;
  unsigned char bFilterArray[PCS_MAX_FILTERS] =
  { PCS_FILTER_0,PCS_FILTER_1,PCS_FILTER_2,PCS_FILTER_3,PCS_FILTER_4,
    PCS_FILTER_5,PCS_FILTER_6,PCS_FILTER_7,PCS_FILTER_8,PCS_FILTER_9};

  /*if ((geCurrentVidParmsArray[giCurrentVID].eVInFormat == NTSC) || */
  /*    (geCurrentVidParmsArray[giCurrentVID].eVInFormat == PAL)  || */
  /*    (geCurrentVidParmsArray[giCurrentVID].eVInFormat == SECAM)) */
  /*{ */
    if (iFilter >= PCS_MAX_FILTERS) return(iError);

    iError = 0;
    bValue = bFilterArray[iFilter];

  /*} // if NTSC  or PAL */

  bSubAddr = HOR_PEAK_REG_9051;
  iError = DrvVidModWrite(bSubAddr,bValue);
  return(iError);

}/* End ioSetVidFilter */

/**********************************************************
*
*       File Name:  iovid.c
*
*       Module Abstract:  This module allows selection of the
*               decoder video format on the video module.
*
*       Calling Sequence:
*       int ioSetVidInFormat(PhillipsIOParams  far *PIOParams);
*
*       Input Parameters:
*         PhillipsIOParams  far *PIOParams    Pointer to structure
*       Output Parameters:
*         error status
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle A. Pratt
*       Date:   06-03-93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioSetVidInFormat(VFORMAT eVInFormat)

{
  int iError = -1;
  unsigned char bValue;
  unsigned char bSubAddr;

  if (eVInFormat == NTSC)
  {
    bValue = VAL_cktq_NTSC ;
  }
  else if (eVInFormat == PAL)
  {
    bValue = VAL_cktq_Pal ;
  }
  else if (eVInFormat == SECAM)
  {
/*    iError = DrvVidModWrite (SECAM_DLY_REG_9051, 0x20); */
/*    iError = DrvVidModWrite (IDEL_REG_9051, 0x28); */

    bValue = VAL_cktq_Sec ;
  }

  bSubAddr = CTRL1_REG_9051;
  iError = DrvVidModWrite(bSubAddr,bValue);

  return(iError);

}/* End ioSetVidInFormat */

/**********************************************************
*
*       File Name:  iovid.c
*
*       Module Abstract:  This module is a stub.
*
*       Calling Sequence:
*       int ioSetVideoMode(PhillipsIOParams  far *PIOParams);
*
*       Input Parameters:
*         PhillipsIOParams  far *PIOParams    Pointer to structure
*       Output Parameters:
*         error status =0
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle A. Pratt
*       Date:   06-21-93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

int ioSetVideoMode(VMODE eVMode)
{
  return (0);
} /* End ioSetVideoMode */



