/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               select the desired 2080 for communications.
*               In systems where there is only one 2080,
*               it is not necessary to call this routine.
*
*       Calling Sequence:
*       lError = ioSetCurrentMD(iProc);
*
*       Input Parameters:
*       int             iProc           Index of desired 2080
*
*       Output Parameters:
*       long            lError          Return 0=Success, -1=Fail
*
*       Global Variables:
*       none
**********************************************************
*       Author: Kyle Pratt
*       Date:   11/29/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

#include <asm/io.h>
#include <string.h>
#include <stdio.h>
#include "poke.h"
#define IOMD
#include "iodvp.h"
#include "iomd.h"

/* external variables -----------------------------------*/
extern unsigned long G_Px2080BaseAddress;
extern unsigned long G_Px2085BaseAddress;
extern SwMode G_SwMode;
extern void *G_pvConfigArray[MAXCONFIGARRAY];
int S_iCurrentMD;
PX2080Ports *S_pCurrentMDPorts;
int S_iMDRegOffset;
int S_GSR_Call;
unsigned char S_bCR3,S_bASC;


unsigned short loc_MD(char reg);
/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the cursor color registers. There are four
*               24 bit RGB locations to be written. The bIndex
*               value must be 0 - 3 and the iCount/3 value added to
*               bIndex must be less than four.
*
*       Calling Sequence:
*       iError = ioCrsrColorWriteMD(bIndex,pbList,iCount);
*
*       Input Parameters:
*       bIndex          Index of the first location to be written
*       pbList          Pointer to a list of RGB triplets
*       iCount          Number of bytes to be written
*
*       Output Parameters:
*       iError          Return value  0 = success    - 1 = fail
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/29/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioCrsrColorWriteMD(bIndex,pbList,iCount)
unsigned char bIndex;
unsigned char *pbList;
int iCount;

{
  int iError = -1;
  return(iError);
} /* End ioCrsrColorWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the cursor color registers. There are four
*               24 bit RGB locations that can be read. The bIndex
*               value must be 0 - 3 and the iCount/3 value added to
*               bIndex must be less than four.
*
*       Calling Sequence:
*       iError = ioCrsrColorReadMD(bIndex,pbList,iCount);
*
*       Input Parameters:
*       bIndex          Index of the first location to be read
*       pbList          Pointer to memory for RGB triplets
*       iCount          Number of bytes to be read
*
*       Output Parameters:
*       iError          Return value  0 = success    - 1 = fail
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/29/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioCrsrColorReadMD(bIndex,pbList,iCount)
unsigned char bIndex;
unsigned char *pbList;
int iCount;

{
  int iError = -1;
  return(iError);
} /* End ioCrsrColorReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the cursor pattern ram. There are 256
*               8 bit locations to be written. The bIndex
*               value must be 0 - 127 and the iCount value added to
*               bIndex must be less than 256.
*
*       Calling Sequence:
*       iError = ioCrsrPtrnWriteMD(bIndex,pbList,iCount);
*
*       Input Parameters:
*       bIndex          Index of the first location to be written
*       pbList          Pointer to a list of bytes
*       iCount          Number of bytes to be written
*
*       Output Parameters:
*       iError          Return value  0 = success    - 1 = fail
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/30/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioCrsrPtrnWriteMD(bIndex,pbList,iCount)
unsigned char bIndex;
unsigned char *pbList;
int iCount;

{
  int iError = -1;
  return(iError);
} /* End ioCrsrPtrnWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the cursor pattern ram. There are 256
*               8 bit locations to be read. The bIndex
*               value must be 0 - 127 and the iCount value added to
*               bIndex must be less than 256.
*
*       Calling Sequence:
*       iError = ioCrsrPtrnReadMD(bIndex,pbList,iCount);
*
*       Input Parameters:
*       bIndex          Index of the first location to be read
*       pbList          Pointer to a memory block for the list of bytes
*       iCount          Number of bytes to be read
*
*       Output Parameters:
*       iError          Return value  0 = success    - 1 = fail
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/30/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioCrsrPtrnReadMD(bIndex,pbList,iCount)
unsigned char bIndex;
unsigned char *pbList;
int iCount;

{
  int iError = -1;
  return(iError);
} /* End ioCrsrPtrnReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the 64 x64 cursor pattern ram. There are 1024
*               8 bit locations to be written. The bIndex
*               value must be 0 - 1023 and the iCount value added to
*               bIndex must be less than 1024.
*
*       Calling Sequence:
*       iError = ioCrsrPtrn64WriteMD(wIndex,pbList,iCount);
*
*       Input Parameters:
*       bIndex          Index of the first location to be written
*       pbList          Pointer to a list of bytes
*       iCount          Number of bytes to be written
*
*       Output Parameters:
*       iError          Return value  0 = success    - 1 = fail
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt/Scott McDonald
*       Date:   08/14/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

int ioCrsrPtrn64WriteMD(wIndex,pbList,iCount)
unsigned int wIndex;
unsigned char *pbList;
int iCount;

{
  int iError = -1;
  return(iError);
} /* End ioCrsrPtrnWriteMD */
/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the graphics status register.
*
*       Calling Sequence:
*       bStatus = ioStatusReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bStatus         Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioStatusReadMD()
{
  unsigned char bReturn;

      bReturn=ioPort5BitReadMD(PX2080_GSR);

  return(bReturn);
} /* End ioStatusReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write command register 3 of the 2085.
*
*       Calling Sequence:
*       ioComReg3WriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/12/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioComReg3WriteMD(bData)
unsigned char bData;

{
} /* End ioComReg3WriteMD */


/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the command register 3 of the 2085.
*
*       Calling Sequence:
*       bData = ioComReg3ReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/12/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioComReg3ReadMD()
{
    return(0xff);
} /* End ioComReg3ReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the graphics format control register.
*
*       Calling Sequence:
*       ioGraphicsFormatWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioGraphicsFormatWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_GFC,bData);
} /* End ioGraphicsFormatWriteMD */


/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the graphics format control register.
*
*       Calling Sequence:
*       bData = ioGraphcisFormatReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioGraphicsFormatReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_GFC));
} /* End ioGraphicsFormatReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the cursor setup control register.
*
*       Calling Sequence:
*       ioCrsrSetupWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioCrsrSetupWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_CSC,bData);
} /* End ioCrsrSetupWriteMD */


/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the cursor setup control register.
*
*       Calling Sequence:
*       bData = ioCrsrSetupReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioCrsrSetupReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_CSC));
} /* End ioCrsrSetupReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the grapahics overlay control register.
*
*       Calling Sequence:
*       ioGraphicsOvlyWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioGraphicsOvlyWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_GOC,bData);
} /* End ioGraphcsOvlyWriteMD */


/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the graphics overlay control register.
*
*       Calling Sequence:
*       bData = ioGraphicsOvlyReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioGraphicsOvlyReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_GOC));
} /* End ioGraphicsOvlyReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the video format control register.
*
*       Calling Sequence:
*       ioVideoFormatWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioVideoFormatWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_VFC,bData);
} /* End ioVideoFormatWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the video format control register.
*
*       Calling Sequence:
*       bData = ioVideoFormatReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioVideoFormatReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_VFC));
} /* End ioVideoFormatReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the sync alignment register.
*
*       Calling Sequence:
*       ioSyncAlignWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioSyncAlignWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_SAR,bData);
} /* End ioSyncAlignWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the sync alignment register.
*
*       Calling Sequence:
*       bData = ioSyncAlignReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioSyncAlignReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_SAR));
} /* End ioSyncAlignReadMD */


/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the reserved 1 register.
*
*       Calling Sequence:
*       ioRSV1WriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/13/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioRSV1WriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_RSV1,(bData));
} /* End ioRSV1WriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the RSV1 register.
*
*       Calling Sequence:
*       bData = ioRSV1ReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   03/3/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioRSV1ReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_RSV1));
} /* End ioRSV1ReadMD */


/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the reserved 2 register.
*
*       Calling Sequence:
*       ioRSV2WriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/13/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioRSV2WriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_RSV2,(bData));
} /* End ioRSV2WriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the RSV2 register.
*
*       Calling Sequence:
*       bData = ioRSV2ReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   03/3/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioRSV2ReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_RSV2));
} /* End ioRSV2ReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the VAFC register of the 2085.
*
*       Calling Sequence:
*       ioVAFCWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/13/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioVAFCWriteMD(bData)
unsigned char bData;

{
} /* End ioVAFCWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the VAFC register of the Px2085.
*
*       Calling Sequence:
*       bData = ioVAFCReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/13/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioVAFCReadMD()
{
    return(0xff);

} /* End ioVAFCReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the reserved 3 register.
*
*       Calling Sequence:
*       ioRSV3WriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/13/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioRSV3WriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_RSV3,(bData));
} /* End ioRSV3WriteMD */


/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the RSV3 register.
*
*       Calling Sequence:
*       bData = ioRSV3ReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   03/3/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioRSV3ReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_RSV3));
} /* End ioRSV3ReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the reserved 4 register.
*
*       Calling Sequence:
*       ioRSV4WriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/13/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioRSV4WriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_RSV4,(bData));
} /* End ioRSV4WriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the RSV4 register.
*
*       Calling Sequence:
*       bData = ioRSV4ReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   03/3/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioRSV4ReadMD()
{

	 /* Read the data */
	 return(ioPort5BitReadMD(PX2080_RSV4));
} /* End ioRSV4ReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the analog setup control register.
*
*       Calling Sequence:
*       ioAnalogSetupWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioAnalogSetupWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_ASC,(bData));
} /* End ioAnalogSetupWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the analog setup controlregister.
*
*       Calling Sequence:
*       bData = ioAnalogSetupReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioAnalogSetupReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_ASC));
} /* End ioAnalogSetupReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the red chroma key  register.
*
*       Calling Sequence:
*       ioRedChromaKeyWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioRedChromaKeyWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_CKR,bData);
} /* End ioRedChromaKeyWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the red chroma key register.
*
*       Calling Sequence:
*       bData = ioRedChromaKeyReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioRedChromaKeyReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_CKR));
} /* End ioRedChromaKeyReadMD */
/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the green chroma key  register.
*
*       Calling Sequence:
*       ioGreenChromaKeyWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioGreenChromaKeyWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_CKG,bData);
} /* End ioGreenChromaKeyWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the green chroma key register.
*
*       Calling Sequence:
*       bData = ioGreenChromaKeyReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioGreenChromaKeyReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_CKG));
} /* End ioGreenChromaKeyReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the blue chroma key  register.
*
*       Calling Sequence:
*       ioBlueChromaKeyWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioBlueChromaKeyWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_CKB,bData);
} /* End ioBlueChromaKeyWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the blue chroma key register.
*
*       Calling Sequence:
*       bData = ioBlueChromaKeyReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioBlueChromaKeyReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_CKB));
} /* End ioBlueChromaKeyReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the red chroma mask  register.
*
*       Calling Sequence:
*       ioRedChromaMaskWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioRedChromaMaskWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_KMR,bData);
} /* End ioRedChromaMaskWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the red chroma mask register.
*
*       Calling Sequence:
*       bData = ioRedChromaMaskReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioRedChromaMaskReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_KMR));
} /* End ioRedChromaMaskReadMD */
/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the green chroma mask  register.
*
*       Calling Sequence:
*       ioGreenChromaMaskWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioGreenChromaMaskWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_KMG,bData);
} /* End ioGreenChromaMaskWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the green chroma mask register.
*
*       Calling Sequence:
*       bData = ioGreenChromaMaskReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioGreenChromaMaskReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_KMG));
} /* End ioGreenChromaMaskReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the blue chroma mask  register.
*
*       Calling Sequence:
*       ioBlueChromaMaskWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioBlueChromaMaskWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_KMB,bData);
} /* End ioBlueChromaMaskWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the blue chroma mask register.
*
*       Calling Sequence:
*       bData = ioBlueChromaMaskReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioBlueChromaMaskReadMD()
{

	/* Read the data */
	return(ioPort5BitReadMD(PX2080_KMB));
} /* End ioBlueChromaMaskReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write a value to the X position registers in the 2080.
*               A short is passed to the routine and it is broken into
*               the upper and lower components to write the actual registers.
*
*       Calling Sequence:
*       ioCrsrXPosWriteMD(wData);
*
*       Input Parameters:
*       unsigned short wData            Data to be written
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void ioCrsrXPosWriteMD(wData)
unsigned short wData;
{
} /* End ioCrsrXPosWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read a value from the X position registers in the 2080.
*               A short is returned from the routine and it is
*               comprised of the upper and lower components of
*               the actual registers.
*
*       Calling Sequence:
*       wData = ioCrsrXPosReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       unsigned short wData            Upper and lower X position
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned short ioCrsrXPosReadMD()

{
    return(0xffff);
} /* End ioCrsrXPosReadMD */


/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the cursor X low register.
*
*       Calling Sequence:
*       ioCrsrXLowPosWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/14/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioCrsrXLowPosWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_CXL,(bData));
} /* End ioCrsrXLowPosWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read a value from the Low X position registers in the 2080.
*
*       Calling Sequence:
*       wData = ioCrsrXLowPosReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       unsigned char bData             lower X position
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   03/3/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned char ioCrsrXLowPosReadMD()

{

	/* Read the low data */
	return(ioPort5BitReadMD(PX2080_CXL));
} /* End ioCrsrXLowPosReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the cursor X high register.
*
*       Calling Sequence:
*       ioCrsrXHiPosWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/14/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioCrsrXHiPosWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_CXH,(bData));
} /* End ioCrsrXHiPosWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read a value from the Hi X position registers in the 2080.
*
*       Calling Sequence:
*       wData = ioCrsrXHiPosReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       unsigned char bData             upper X position
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   03/3/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned char ioCrsrXHiPosReadMD()

{

	/* Read the Hi data */
	return(ioPort5BitReadMD(PX2080_CXH));

} /* End ioCrsrXHiPosReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the cursor Y low register.
*
*       Calling Sequence:
*       ioCrsrYLowPosWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/14/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioCrsrYLowPosWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_CYL,(bData));
} /* End ioCrsrYLowPosWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read a value from the Low Y position registers in the 2080.
*
*       Calling Sequence:
*       wData = ioCrsrYLowPosReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       unsigned char bData             lower Y position
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   03/3/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned char ioCrsrYLowPosReadMD()

{

	/* Read the low data */
	return(ioPort5BitReadMD(PX2080_CYL));
} /* End ioCrsrYLowPosReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the cursor Y high register.
*
*       Calling Sequence:
*       ioCrsrYHiPosWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/14/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioCrsrYHiPosWriteMD(bData)
unsigned char bData;

{

	/* Write the data */
	ioPort5BitWriteMD(PX2080_CYH,(bData));
} /* End ioCrsrYHiPosWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read a value from the Hi Y position registers in the 2080.
*
*       Calling Sequence:
*       wData = ioCrsrYHiPosReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       unsigned char bData             Upper Y position
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   03/3/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned char ioCrsrYHiPosReadMD()

{

	/* Read the low data */
	return(ioPort5BitReadMD(PX2080_CYH));
} /* End ioCrsrYHiPosReadMD */



/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write a value to the Y position registers in the 2080.
*               A short is passed to the routine and it is broken into
*               the upper and lower components to write the actual registers.
*
*       Calling Sequence:
*       ioCrsrYPosWriteMD(wData);
*
*       Input Parameters:
*       unsigned short wData            Data to be written
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void ioCrsrYPosWriteMD(wData)
unsigned short wData;
{
} /* End ioCrsrYPosWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read a value from the Y position registers in the 2080.
*               A short is returned from the routine and it is
*               comprised of the upper and lower components of
*               the actual registers.
*
*       Calling Sequence:
*       wData = ioCrsrYPosReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       unsigned short wData            Upper and lower Y position
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned short ioCrsrYPosReadMD()

{
    return(0xffff);

} /* End ioCrsrYPosReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the gamma lut in the 2080.
*               The index must be between 0 - 255 and the index
*               plus iCount/3 must be less than 256.
*
*       Calling Sequence:
*       iError = ioGammaLutWriteMD(bIndex,pbList,iCount);
*
*       Input Parameters:
*       unsigned char   bIndex          Start address of palette
*       unsigned char   *pbList         FAR pointer to list of bytes
*       int             iCount          Number of bytes to write
*
*       Output Parameters:
*       int     iError          Error that input parms exceeded
*                                       bounds.
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioGammaLutWriteMD(bIndex,pbList,iCount)
unsigned char bIndex;
unsigned char *pbList;
int iCount;
{

  /* Test input parms */
  if ((bIndex + iCount/3) >256) return(-1);



	/* Write the address */
	ioPort5BitWriteMD(PX2080_VGW, bIndex);

	/* Write the data */
	while(iCount)
	{
	  ioPort5BitWriteMD(PX2080_VGD, *pbList);
	  iCount--;
	  pbList++;
	}
       return(0);
} /* End ioGammaLutWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the gamma lut in the 2080.
*               The index must be between 0 - 255 and the index
*               plus iCount/3 must be less than 256.
*
*       Calling Sequence:
*       iError = ioGammaLutReadMD(bIndex,pbList,iCount);
*
*       Input Parameters:
*       unsigned char   bIndex          Start address of palette
*       unsigned char   *pbList         FAR pointer for list of bytes
*       int             iCount          Number of bytes to write
*
*       Output Parameters:
*       int     iError          Error that input parms exceeded
*                                       bounds.
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/1/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioGammaLutReadMD(bIndex,pbList,iCount)
unsigned char bIndex;
unsigned char *pbList;
int iCount;
{

  /* Test input parms */
  if ((bIndex + iCount/3) >256) return(-1);


	/* Read the data once to fix hw bug */
      ioPort5BitReadMD(PX2080_VGD);

	/* Write the address ? different with document */
      ioPort5BitWriteMD(PX2080_VGR, bIndex);

	/* Read the data */
	while(iCount)
	{
	*pbList=ioPort5BitReadMD(PX2080_VGD);
	iCount--;
	pbList++;
	}
	return(0);
} /* End ioGammaLutReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the color lut in the 2080.
*               The index must be between 0 - 255 and the index
*               plus iCount/3 must be less than 256.
*
*       Calling Sequence:
*       iError = ioColorPaletteWriteMD(bIndex,pbList,iCount);
*
*       Input Parameters:
*       unsigned char   bIndex          Start address of palette
*       unsigned char   *pbList         FAR pointer to list of bytes
*       int             iCount          Number of bytes to write
*
*       Output Parameters:
*       int     iError          Error that input parms exceeded
*                                       bounds.
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   1/29/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioColorPaletteWriteMD(bIndex,pbList,iCount)
unsigned char bIndex;
unsigned char *pbList;
int iCount;
{

  /* Test input parms */
  if ((bIndex + iCount/3) >256) return(-1);


	ioPort5BitWriteMD(PX2080_LAW,bIndex);

	/* Write the data */
	while(iCount)
	{
	ioPort5BitWriteMD(PX2080_LCD, *pbList);
	  iCount--;
	  pbList++;
	}
	return(0);
} /* End ioColorPaletteWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the Color lut in the 2080.
*               The index must be between 0 - 255 and the index
*               plus iCount/3 must be less than 256.
*
*       Calling Sequence:
*       iError = ioColorPaletteReadMD(bIndex,pbList,iCount);
*
*       Input Parameters:
*       unsigned char   bIndex          Start address of palette
*       unsigned char   *pbList         FAR pointer for list of bytes
*       int             iCount          Number of bytes to write
*
*       Output Parameters:
*       int     iError          Error that input parms exceeded
*                                       bounds.
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   1/29/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioColorPaletteReadMD(bIndex,pbList,iCount)
unsigned char bIndex;
unsigned char *pbList;
int iCount;
{

  /* Test input parms */
  if ((bIndex + iCount/3) >256) return(-1);



	ioPort5BitWriteMD(PX2080_LAR,bIndex);

	/* Read the data */
	while(iCount)
	{
	*pbList=ioPort5BitReadMD(PX2080_LCD);
	  iCount--;
	  pbList++;
	}
	return(0);
} /* End ioColorPaletteReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write the pixel mask register.
*
*       Calling Sequence:
*       ioPixelMaskWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/8/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioPixelMaskWriteMD(bData)
unsigned char bData;

{
	ioPort5BitWriteMD(PX2080_LPM,bData);
} /* End ioPixelMaskWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read the pixel mask register.
*
*       Calling Sequence:
*       bData = ioPixelMaskReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/8/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioPixelMaskReadMD()
{

	return(ioPort5BitReadMD(PX2080_LPM));
} /* End ioPixelMaskReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write a value to the Block portion of the BIR
*               register in the 2080.
*
*       Calling Sequence:
*       ioSetBIRBlockMD(bData);
*
*       Input Parameters:
*       unsigned char bData             Data to be written
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   1/19/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void ioSetBIRBlockMD(bData)
unsigned char bData;

{
} /* End ioSetBIRBlockMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write a value to the BIR register in the 2080.
*
*       Calling Sequence:
*       ioBIRWriteMD(bData);
*
*       Input Parameters:
*       unsigned char bData             Data to be written
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/6/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void ioBIRWriteMD(bData)
unsigned char bData;

{
} /* End ioBIRWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read a value from the BIR register in the 2080.
*
*       Calling Sequence:
*       bData = ioBIRReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       unsigned char bData             Data read
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/6/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned char ioBIRReadMD()
{
   int ret=inb_p((unsigned short)(S_pCurrentMDPorts->PX2080Bir & 0xffff));
   return ret;
} /* End ioBIRReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write a value to a specified port in the 2080.
*
*       Calling Sequence:
*       ioISAPortWriteMD(iPort,bData);
*
*       Input Parameters:
*       int iPort                       Port to be addressed
*       unsigned char bData             Data to be written
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/6/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioISAPortWriteMD(iPort,bData)
int iPort;
unsigned char bData;

{
int iError = 0;
return(iError);
} /* End ioISAPortWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read a value to a specified port in the 2080.
*
*       Calling Sequence:
*       bData = ioISAPortReadMD(iPort);
*
*       Input Parameters:
*       int iPort                       Port to be addressed
*
*       Output Parameters:
*       unsigned char                   Data read
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/6/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned char ioISAPortReadMD(iPort)
int iPort;

{
unsigned char bReturnVal=0xff;
return(bReturnVal);
} /* End ioISAPortReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write a value to a specified port in the 2080
*               in the memory mapped mode.
*
*       Calling Sequence:
*       ioMemPortWriteMD(iPort,bData);
*
*       Input Parameters:
*       int iPort                       Port to be addressed
*       unsigned char bData             Data to be written
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   04/15/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioMemPortWriteMD(iPort,bData)
int iPort;
unsigned char bData;

{
int iError = 0xdead;
return(iError);
} /* End ioMemPortWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read a value to a specified port in the 2080
*               while it is in the memory mapped mode.
*
*       Calling Sequence:
*       bData = ioMemPortReadMD(iPort);
*
*       Input Parameters:
*       int iPort                       Port to be addressed
*
*       Output Parameters:
*       unsigned char                   Data read
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   04/15/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned char ioMemPortReadMD(iPort)
int iPort;

{
 return(0xff);
} /* End ioMemPortReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               write a value to a specified port in the 2080
*               in the 4Bit IO mapped mode.
*
*       Calling Sequence:
*       ioPort5BitWriteMD(iPort,bData);
*
*       Input Parameters:
*       int iPort                       Port to be addressed
*       unsigned char bData             Data to be written
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/16/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int ioPort5BitWriteMD(iPort,bData)
int iPort;
unsigned char bData;

{
  int iError = 0xdead;
  unsigned long dwPortAddress;
  int iExtended=0;
  unsigned char bTemp,bVGALocked;
  FILE * gene;
  /* Unlock the DAC regs */
  /*UNLOCK_MD_REGS */

  switch(iPort)
  {
    case PX2080_LAW:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port0;
      iError =0;
      break;
    case PX2080_LCD:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port1;
      iError =0;
      break;
    case PX2080_LPM:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port2;
      iError =0;
      break;
    case PX2080_LAR:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port3;
      iError =0;
      break;
    case PX2080_CAW:
      /*ioSet4BitBlockMD(PX2080_CAW); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port4;
      iError =0;
      break;
    case PX2080_CCD:
      /*ioSet4BitBlockMD(PX2080_CCD); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port5;
      iError =0;
      break;
    case PX2080_ASC:
      /*ioSet4BitBlockMD(PX2080_ASC); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port6;
      iError =0;
      break;
    case PX2080_CAR:
      /*ioSet4BitBlockMD(PX2080_CAR); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port7;
      iError =0;
      break;
    case PX2080_GFC:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port8;
      iError =0;
      break;
    case PX2080_CSC:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port9;
      iError =0;
      break;
    case PX2080_GSR:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port10;
      iError =0;
      break;
    case PX2080_CPR:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port11;
      iError =0;
      break;
    case PX2080_CXL:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port12;
      iError =0;
      break;
    case PX2080_CXH:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port13;
      iError =0;
      break;
    case PX2080_CYL:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port14;
      iError =0;
      break;
    case PX2080_CYH:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port15;
      iError =0;
      break;
    case PX2080_VFC:
      /*ioSet4BitBlockMD(PX2080_VFC); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port16;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_GOC:
      /*ioSet4BitBlockMD(PX2080_GOC); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port17;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_SAR:
      /*ioSet4BitBlockMD(PX2080_SAR); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port18;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_RSV1:
      /*ioSet4BitBlockMD(PX2080_RSV1); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port19;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_VGW:
      /*ioSet4BitBlockMD(PX2080_VGW); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port20;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_VGD:
      /*ioSet4BitBlockMD(PX2080_VGD); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port21;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_RSV2:
      /*ioSet4BitBlockMD(PX2080_RSV2); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port22;
      iError =0;
      /*iExtended = 1; */
      break;
    case PX2080_VGR:
      /*ioSet4BitBlockMD(PX2080_VGR); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port23;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_CKR:
      /*ioSet4BitBlockMD(PX2080_CKR); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port24;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_CKG:
      /*ioSet4BitBlockMD(PX2080_CKG); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port25;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_CKB:
      /*ioSet4BitBlockMD(PX2080_CKB); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port26;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_RSV3:
      /*ioSet4BitBlockMD(PX2080_RSV3); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port27;
      iError =0;
     /* iExtended =1; */
      break;
    case PX2080_KMR:
      /*ioSet4BitBlockMD(PX2080_KMR); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port28;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_KMG:
      /*ioSet4BitBlockMD(PX2080_KMG); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port29;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_KMB:
      /*ioSet4BitBlockMD(PX2080_KMB); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port30;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_RSV4:
      /*ioSet4BitBlockMD(PX2080_RSV4); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port31;
      iError =0;
      /*iExtended =1; */
      break;

    default:
      iError = 0xdead;
      break;
  } /* Switch */
  gene=fopen("port","wt");
  fprintf(gene,"%d\n",dwPortAddress);
  fclose(gene);
  outw(bData,dwPortAddress);

  /* Clear the block of CR3 if necessary */
  if (iExtended)
  {
    iExtended = 0;
    ioClear4BitBlockMD();
  }

  /* Lock the registers */
  /*LOCK_MD_REGS */

  return(iError);
} /* End ioPort5BitWriteMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               read a value from a specified port in the 2080
*               while it is in the 4Bit IO mapped mode.
*
*       Calling Sequence:
*       bData = ioPort5BitReadMD(iPort);
*
*       Input Parameters:
*       int iPort                       Port to be addressed
*
*       Output Parameters:
*       unsigned char                   Data read
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/16/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned char ioPort5BitReadMD(iPort)
int iPort;

{
  int iError = 0xff;
  unsigned long dwPortAddress;
  int iExtended = 0;
  unsigned char bReturnVal;
  unsigned char bTemp,bVGALocked;

  /* Unlock the DAC regs */
  /*UNLOCK_MD_REGS */

  switch(iPort)
  {
    case PX2080_LAW:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port0;
      iError =0;
      break;
    case PX2080_LCD:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port1;
      iError =0;
      break;
    case PX2080_LPM:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port2;
      iError =0;
      break;
    case PX2080_LAR:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port3;
      iError =0;
      break;
    case PX2080_CAW:
      /*ioSet4BitBlockMD(PX2080_CAW); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port4;
      iError =0;
      break;
    case PX2080_CCD:
      /*ioSet4BitBlockMD(PX2080_CCD); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port5;
      iError =0;
      break;
    case PX2080_ASC:
      /*ioSet4BitBlockMD(PX2080_ASC); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port6;
      iError =0;
      break;
    case PX2080_CAR:
      /*ioSet4BitBlockMD(PX2080_CAR); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port7;
      iError =0;
      break;
    case PX2080_GFC:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port8;
      iError =0;
      break;
    case PX2080_CSC:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port9;
      iError =0;
      break;
    case PX2080_GSR:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port10;
      iError =0;
      break;
    case PX2080_CPR:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port11;
      iError =0;
      break;
    case PX2080_CXL:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port12;
      iError =0;
      break;
    case PX2080_CXH:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port13;
      iError =0;
      break;
    case PX2080_CYL:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port14;
      iError =0;
      break;
    case PX2080_CYH:
      dwPortAddress = S_pCurrentMDPorts->PX2080Port15;
      iError =0;
      break;
    case PX2080_VFC:
      /*ioSet4BitBlockMD(PX2080_VFC); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port16;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_GOC:
      /*ioSet4BitBlockMD(PX2080_GOC); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port17;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_SAR:
      /*ioSet4BitBlockMD(PX2080_SAR); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port18;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_RSV1:
      /*ioSet4BitBlockMD(PX2080_RSV1); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port19;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_VGW:
      /*ioSet4BitBlockMD(PX2080_VGW); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port20;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_VGD:
      /*ioSet4BitBlockMD(PX2080_VGD); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port21;
      iError =0;
      /*Extended =1; */
      break;
    case PX2080_RSV2:
      /*ioSet4BitBlockMD(PX2080_RSV2); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port22;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_VGR:
      /*ioSet4BitBlockMD(PX2080_VGR); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port23;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_CKR:
      /*ioSet4BitBlockMD(PX2080_CKR); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port24;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_CKG:
      /*ioSet4BitBlockMD(PX2080_CKG); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port25;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_CKB:
      /*ioSet4BitBlockMD(PX2080_CKB); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port26;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_RSV3:
      /*ioSet4BitBlockMD(PX2080_RSV3); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port27;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_KMR:
      /*ioSet4BitBlockMD(PX2080_KMR); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port28;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_KMG:
      /*ioSet4BitBlockMD(PX2080_KMG); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port29;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_KMB:
      /*ioSet4BitBlockMD(PX2080_KMB); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port30;
      iError =0;
      /*iExtended =1; */
      break;
    case PX2080_RSV4:
      /*ioSet4BitBlockMD(PX2080_RSV4); */
      dwPortAddress = S_pCurrentMDPorts->PX2080Port31;
      iError =0;
      /*iExtended =1; */
      break;

    default:
      iError = 0xdead;
      break;
  } /* Switch */


  if(iError)
    goto ERROREXIT;
  else
  {
    bReturnVal = inb_p((unsigned short)(dwPortAddress & 0xffff));



    ERROREXIT:
    /* Lock the registers */
    /*LOCK_MD_REGS */

    return(bReturnVal);
  }

} /* End ioPort5BitReadMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               set the block index for the extended registers
*               of the PX208X while in the 4Bit IO mapped mode.
*
*       Calling Sequence:
*       ioSet4BitBlockMD(iReg);
*
*       Input Parameters:
*       int iReg                       Register to be indexed
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void ioSet4BitBlockMD(int iReg)
{
} /* End ioSet4BitBlockMD */
/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               clear the block index for the extended registers
*               of the PX208X while in the 4Bit IO mapped mode.
*
*       Calling Sequence:
*       ioClear4BitBlockMD(void);
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void ioClear4BitBlockMD(void)
{
} /* End ioClear4BitBlockMD */

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This routine...
*
*       Calling Sequence:
*       void GetVgaClut(int index, FPRGBCOLOR fpRgb);
*
*       Input Parameters:
*
*
*       Output Parameters:
*
*
*       Global Variables:
*       None
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   07/19/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*********************************************************/

void GetVgaClut(int index, FPRGBCOLOR fpRgb)
{
  outw_p(index,CLUT_READ_ADDRESS);
  fpRgb->Red = (unsigned char) inb_p(CLUT_COLOR_DATA);
  fpRgb->Green = (unsigned char) inb_p(CLUT_COLOR_DATA);
  fpRgb->Blue = (unsigned char) inb_p(CLUT_COLOR_DATA);

}

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This routine...
*
*       Calling Sequence:
*       void PutPx2080Clut(int index, FPRGBCOLOR fpRgb)
*
*       Input Parameters:
*
*
*       Output Parameters:
*
*
*       Global Variables:
*       None
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   07/19/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*********************************************************/

void PutPx2080Clut(int index, FPRGBCOLOR fpRgb)
{

#if 0
  ioUtlProtectWrite((unsigned short)0x6c00, G_wPx2080Selector, index);
  ioUtlProtectWrite((unsigned short)0x6c04, G_wPx2080Selector, fpRgb->Red);
  ioUtlProtectWrite((unsigned short)0x6c04, G_wPx2080Selector, fpRgb->Green);
  ioUtlProtectWrite((unsigned short)0x6c04, G_wPx2080Selector, fpRgb->Blue);
#endif

}

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This routine...
*
*       Calling Sequence:
*
*
*       Input Parameters:
*
*
*       Output Parameters:
*
*
*       Global Variables:
*       None
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   07/19/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*********************************************************/

void cpclut()
{
  int   i;
  RGBCOLOR  rgb;

  for (i = 0; i < 256; i++)
  {
    GetVgaClut(i, &rgb);
    PutPx2080Clut(i, &rgb);
  }
}

/**********************************************************
*
*       File Name:  ioMD.c
*
*       Module Abstract:  This module provides the ability to
*               initialize the 2080. A pointer to a PX2080InitParms
*               struct is passed int the call. If the pointer is
*               NULL, default values are used.
*
*       Calling Sequence:
*       ioInitMD(PX2080InitParms *pInitStruct);
*
*       Input Parameters:
*       PX2080InitParms *pInitStruct        Pointer to structure
*
*       Output Parameters:
*       int iError      Return Value    0 = Success -1 = Fail
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   1/25/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

int ioInitMD(pInitStruct)
PX2080InitParms *pInitStruct;

{
  int i;
  unsigned char bTestWord,bWriteWord,bReadVal;
  unsigned char bGammaArray[256][3];
  PortType ePortType;





  ioGraphicsOvlyWriteMD(GOC_GRAPHICS_ONLY);



  ioSyncAlignWriteMD(SAR_NORMAL);

  ioRSV1WriteMD(0);
  ioRedChromaKeyWriteMD(WINDOWS_FILL);
  ioGreenChromaKeyWriteMD(WINDOWS_FILL);
  ioBlueChromaKeyWriteMD(WINDOWS_FILL);
  ioRedChromaMaskWriteMD(NO_MASK);
  ioGreenChromaMaskWriteMD(NO_MASK);
  ioBlueChromaMaskWriteMD(NO_MASK);
  ioVideoFormatWriteMD(VFC_YUV_422);

  return (0);
} /* End ioInitMD */

/**********************************************************
*
*       File Name:  ioMD2.c
*
*       Module Abstract:  This module provides the ability to
*               write the CAW register.
*
*       Calling Sequence:
*       ioCAWWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioCAWWriteMD(bData)
unsigned char bData;

{
        ioPort5BitWriteMD(PX2080_CAW,(bData));
} /* End ioCAWWriteMD */

/**********************************************************
*
*       File Name:  ioMD2c
*
*       Module Abstract:  This module provides the ability to
*               read the CAW register.
*
*       Calling Sequence:
*       bData = ioCAWReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioCAWReadMD()
{
        /* Read the data */
        return(ioPort5BitReadMD(PX2080_CAW));
} /* End ioCAWReadMD */

/**********************************************************
*
*       File Name:  ioMD2.c
*
*       Module Abstract:  This module provides the ability to
*               write the CAR register.
*
*       Calling Sequence:
*       ioCARWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioCARWriteMD(bData)
unsigned char bData;

{
        /* Write the data */
        ioPort5BitWriteMD(PX2080_CAR,(bData));
} /* End ioCARWriteMD */

/**********************************************************
*
*       File Name:  ioMD2c
*
*       Module Abstract:  This module provides the ability to
*               read the CAR register.
*
*       Calling Sequence:
*       bData = ioCARReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioCARReadMD()
{
        /* Read the data */
        return(ioPort5BitReadMD(PX2080_CAR));
} /* End ioCARReadMD */

/**********************************************************
*
*       File Name:  ioMD2.c
*
*       Module Abstract:  This module provides the ability to
*               write the VGW register.
*
*       Calling Sequence:
*       ioVGWWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioVGWWriteMD(bData)
unsigned char bData;

{
        /* Write the data */
        ioPort5BitWriteMD(PX2080_VGW,(bData));
} /* End ioVGWWriteMD */

/**********************************************************
*
*       File Name:  ioMD2c
*
*       Module Abstract:  This module provides the ability to
*               read the VGW register.
*
*       Calling Sequence:
*       bData = ioVGWReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioVGWReadMD()
{
        /* Read the data */
        return(ioPort5BitReadMD(PX2080_VGW));
} /* End ioVGWReadMD */


/**********************************************************
*
*       File Name:  ioMD2.c
*
*       Module Abstract:  This module provides the ability to
*               write the VGR register.
*
*       Calling Sequence:
*       ioVGRWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioVGRWriteMD(bData)
unsigned char bData;

{
        /* Write the data */
        ioPort5BitWriteMD(PX2080_VGR,(bData));
} /* End ioVGRWriteMD */

/**********************************************************
*
*       File Name:  ioMD2c
*
*       Module Abstract:  This module provides the ability to
*               read the VGR register.
*
*       Calling Sequence:
*       bData = ioVGRReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioVGRReadMD()
{
        /* Read the data */
        return(ioPort5BitReadMD(PX2080_VGR));
} /* End ioVGRReadMD */

/**********************************************************
*
*       File Name:  ioMD2.c
*
*       Module Abstract:  This module provides the ability to
*               write the LAW register.
*
*       Calling Sequence:
*       ioLAWWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioLAWWriteMD(bData)
unsigned char bData;

{
        /* Write the data */
        ioPort5BitWriteMD(PX2080_LAW,bData);
} /* End ioLAWWriteMD */

/**********************************************************
*
*       File Name:  ioMD2c
*
*       Module Abstract:  This module provides the ability to
*               read the LAW register.
*
*       Calling Sequence:
*       bData = ioLAWReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioLAWReadMD()
{
        /* Read the data */
        return(ioPort5BitReadMD(PX2080_LAW));
} /* End ioLAWReadMD */


/**********************************************************
*
*       File Name:  ioMD2.c
*
*       Module Abstract:  This module provides the ability to
*               write the LAR register.
*
*       Calling Sequence:
*       ioLARWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioLARWriteMD(bData)
unsigned char bData;

{
        /* Write the data */
        ioPort5BitWriteMD(PX2080_LAR,bData);
} /* End ioLARWriteMD */

/**********************************************************
*
*       File Name:  ioMD2c
*
*       Module Abstract:  This module provides the ability to
*               read the LAR register.
*
*       Calling Sequence:
*       bData = ioLARReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioLARReadMD()
{
        /* Read the data */
        return(ioPort5BitReadMD(PX2080_LAR));
} /* End ioLARReadMD */


/**********************************************************
*
*       File Name:  ioMD2.c
*
*       Module Abstract:  This module provides the ability to
*               write the LCD register.
*
*       Calling Sequence:
*       ioLCDWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioLCDWriteMD(bData)
unsigned char bData;

{
        /* Write the data */
        ioPort5BitWriteMD(PX2080_LCD,bData);
} /* End ioLCDWriteMD */

/**********************************************************
*
*       File Name:  ioMD2c
*
*       Module Abstract:  This module provides the ability to
*               read the LCD register.
*
*       Calling Sequence:
*       bData = ioLCDReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioLCDReadMD()
{
        /* Read the data */
        return(ioPort5BitReadMD(PX2080_LCD));
} /* End ioLCDReadMD */

/**********************************************************
*
*       File Name:  ioMD2.c
*
*       Module Abstract:  This module provides the ability to
*               write the CCD register.
*
*       Calling Sequence:
*       ioCCDWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioCCDWriteMD(bData)
unsigned char bData;

{
        /* Write the data */
        ioPort5BitWriteMD(PX2080_CCD,bData);
} /* End ioCCDWriteMD */

/**********************************************************
*
*       File Name:  ioMD2c
*
*       Module Abstract:  This module provides the ability to
*               read the CCD register.
*
*       Calling Sequence:
*       bData = ioCCDReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioCCDReadMD()
{
        /* Read the data */
        return(ioPort5BitReadMD(PX2080_CCD));
} /* End ioCCDReadMD */

/**********************************************************
*
*       File Name:  ioMD2.c
*
*       Module Abstract:  This module provides the ability to
*               write the CPR register.
*
*       Calling Sequence:
*       ioCPRWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioCPRWriteMD(bData)
unsigned char bData;

{
} /* End ioCPRWriteMD */

/**********************************************************
*
*       File Name:  ioMD2c
*
*       Module Abstract:  This module provides the ability to
*               read the CPR register.
*
*       Calling Sequence:
*       bData = ioCPRReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioCPRReadMD()
{
} /* End ioCPRReadMD */


/**********************************************************
*
*       File Name:  ioMD2.c
*
*       Module Abstract:  This module provides the ability to
*               write the VGD register.
*
*       Calling Sequence:
*       ioVGDWriteMD(bData);
*
*       Input Parameters:
*       bData           Data to be writen
*
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

void ioVGDWriteMD(bData)
unsigned char bData;

{
        /* Write the data */
        ioPort5BitWriteMD(PX2080_VGD,bData);
} /* End ioVGDWriteMD */

/**********************************************************
*
*       File Name:  ioMD2c
*
*       Module Abstract:  This module provides the ability to
*               read the VGD register.
*
*       Calling Sequence:
*       bData = ioVGDReadMD();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       bData           Return value of register
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/17/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

unsigned char ioVGDReadMD()
{
        /* Read the data */
        return(ioPort5BitReadMD(PX2080_VGD));
} /* End ioVGDReadMD */

unsigned short loc_MD(char reg)
{
	printf("called loc_MD\n");
	exit(256);
	if(reg<32)
	{
		/* Determine 2080 register location */
		outw(6,Gi);
		tmp=inw(Gd);
		tmp &= ((0xffff - MISC_BLOCK)<<11);
		outw(7,Gi);
		tmp |= inw(Gd);
		return ((tmp&0xfff)|reg);
	}
	printf("Bad MD register: %d. Exiting.\n",reg);
	exit(255);
}

int ioSetCurrentMD(int iProc)
{
	int iError;
	
	if((iProc >= MAX2080COUNT) || (G_pvConfigArray[PX2080BASE] == NULL))
		iError = -1;
	else
	{
		iError = 0;
		S_iCurrentMD = iProc;

		if (G_eWhichDac == Px2080)
		{
			S_pCurrentMDPorts =
			(PX2080Ports *) G_pvConfigArray[PX2080BASE];
		}
	}
	return iError;
}
