/**********************************************************
* Copyright Pixel Semiconductor, 1992. All rights reserved.
***********************************************************
/****************************************************************************
**      Copyright (c) 1992 Pixel Semiconductor, Inc.  All rights reserved
**
**      FILENAME:
**
**        iovid.h
**
**      ABSTRACT:
**
**       This header file contains the definitions and type
**       definitions for the Phillips Chip Set.
**
***********************************************************
*       Author: Mike Corry , Kyle Pratt
*       Date:   12-10-92
*       Rev:    1.XA
*       Module: 1.1
*
*       Revision History:
*       -----------------
*       WHO             WHEN      WHAT/WHY/HOW
*       ---             ----      ------------
*
***********************************************************/
#ifndef EXPORTED
#define far pascal _export
#endif

#ifndef I2C_CTL
#define I2C_CTL

#include "pxvidapi.h"
// Typedefs ----------------------------------------------------
typedef struct tagVIDPorts
{
  unsigned short VIDPort0;

} VIDPorts;
#ifndef _PXVIDAPI_H
typedef enum tagVideoMode {PCS_IN_ONLY,PCS_OUT_ONLY,PCS_PIXEL_DUPLEX,TESTMODE} VMODE;
typedef enum tagVideoFormat {NTSC,SVHS,PAL,SECAM,CIF,QCIF,USER} VFORMAT;
#endif

typedef struct tagPillipsIOParams
{
    VMODE VideoMode;              /* Input/Output/Duplex */
    VFORMAT DecodeFormat;         /* NTSC, SVHS, PAL */
    VFORMAT EncodeFormat;         /* NTSC, SVHS, PAL */
    unsigned char bChannelIn;     /* Channel number 1-3 */
    unsigned char bDecodeFilter;   /* Decoder filter selection */
    int iHue;                     /* Decoder Hue setting */
    char szLUTConfigFile[80];     /* file path with LUT data */
    char szFileName[20];
} PhillipsIOParams;





/*
*       Defines
*/
#define IDSTR_CANNOTLOAD 1
#define IDSTR_ERRORTITLE 2

/* Configuration Stuff ------------------------------------*/


/* Encoder/Decoder bit flags -----------------------------*/


#define VIDPORT1        0
#define VIDPORT2        1

#define PCS_CHAN1_INPUT    0       /* Zero based */
#define PCS_CHAN2_INPUT    1
#define PCS_CHAN3_INPUT    2


#ifdef _SAA7191
#define SDA_HIGH_SLC_HIGH       0xC0
#define SDA_HIGH_SLC_LOW        0x40
#define SDA_LOW_SLC_HIGH        0x80
#define SDA_LOW_SLC_LOW         0x00
#define SDA_AND_SCL_HIGH_MASK    0x3F
#define SDA_AND_SCL_LOW_MASK     0xFF
#define SDA_HIGH_SCL_LOW_MASK    0xBF
#define SDA_LOW_SCL_HIGH_MASK    0x7F

#define SDA_BIT                  0x08
#define SCL_BIT                  0x10
#define ACTUAL_I2C_BITS_MASK     0xC0
#define ACTUAL_I2C_SDA_BIT       0x40
#define ACTUAL_I2C_SCL_BIT       0x80

/*
*      7191 7199 addresses
*/
#define SAA7191RdAddr           0x8F
#define SAA7199RdAddr           0xB1
#define SAA7191WrAddr           0x8E
#define SAA7199WrAddr           0xB0
#define SAA7199CtlAddr          0x02
#define SAA7199CtlData          0x03

#endif

#ifdef _SAA9051
#define SDA_HIGH_SLC_HIGH 0x3
#define SDA_HIGH_SLC_LOW  0x2
#define SDA_LOW_SLC_HIGH  0x1
#define SDA_LOW_SLC_LOW		0x00

#define SDA_BIT                  0x02
#define SCL_BIT                  0x1
#define ACTUAL_I2C_BITS_MASK     0x3
#define ACTUAL_I2C_SDA_BIT       0x2
#define ACTUAL_I2C_SCL_BIT       0x1
#endif

#ifdef _MEDIAMANGLER
#define SDA_HIGH_SLC_HIGH 0x3
#define SDA_HIGH_SLC_LOW  0x2
#define SDA_LOW_SLC_HIGH  0x1
#define SDA_LOW_SLC_LOW		0x00

#define SDA_BIT                  0x02
#define SCL_BIT                  0x1
#define ACTUAL_I2C_BITS_MASK     0x3
#define ACTUAL_I2C_SDA_BIT       0x2
#define ACTUAL_I2C_SCL_BIT       0x1

#define SAA9051RdAddr           0x8F // 8B
#define SAA9051WrAddr           0x8E // 8A

#endif


#define SUCCESS                  0
#define EROR1                    1
#define EROR2                    2
#define EROR3                    3
#define EROR4                    4
#define EROR5                    5

#define POSITIVE_ACK             0
#define NEGATIVE_ACK             1

#define TIME_CONSTANT            75
#define SUBADDRESSUSED           2
#define SUBADDRESSNOTUSED        1


/* Decoder channel defines */
#define PCS_CHAN1_INPUT    0       /* Zero based */
#define PCS_CHAN2_INPUT    1
#define PCS_CHAN3_INPUT    2

/* Decoder resolution defines */
#define PCS_MAX_HORZ_RES     704
#define PCS_MAX_VERT_RES     576
#define PCS_NTSC_X           704
#define PCS_NTSC_Y           480
#define PCS_PAL_X            704
#define PCS_PAL_Y            576
#define PCS_MAX_SMPTE         25
#define PCS_MAX_PAL_SMPTE     31
#define PCS_NTSC_FRAME_RATE   60
#define PCS_PAL_FRAME_RATE    50
#define PCS_MAX_FRAME_RATE    60

/* Decoder hue defines */
#define PCS_MAX_HUE          127
#define PCS_MIN_HUE         -128

//
// 9051 addresses
//
#define SAA9051RdAddr           0x8F // 8B
#define SAA9051WrAddr           0x8E // 8A

//
// Port addresses
//
#define VID_PORT_1      0x410e
#define VID_PORT_2      0x410f

//
// Defines for filters in decoder
//
#define PCS_MAX_FILTERS         10
#define PCS_FILTER_DEFAULT      4
#define PCS_FILTER_0            0x00
#define PCS_FILTER_1            0x03
#define PCS_FILTER_2            0x50
#define PCS_FILTER_3            0x42
#define PCS_FILTER_4            0x43
#define PCS_FILTER_5            0x23
#define PCS_FILTER_6            0x62
#define PCS_FILTER_7            0x53
#define PCS_FILTER_8            0x73
#define PCS_FILTER_9            0x63
#define P51_FILTER_0            0x00
#define P51_FILTER_1            0x03
#define P51_FILTER_2            0x50
#define P51_FILTER_3            0x42
#define P51_FILTER_4            0x43
#define P51_FILTER_5            0x23
#define P51_FILTER_6            0x62
#define P51_FILTER_7            0x53
#define P51_FILTER_8            0x73
#define P51_FILTER_9            0x63
#define PCS_MAX_FILTER          9
#define PCS_MIN_FILTER          0

#define WRITE_SDA_BIT            0x08
#define WRITE_SCL_BIT            0x10
#define READ_SDA_BIT             0x40
#define READ_SCL_BIT             0x80
#define RESET_BIT                0x20
// The next five defines concern read back bits only.
#define I2C_BITS_MASK            0xC0
#define SDA_AND_SCL_HIGH_MASK    0xC0
#define SDA_AND_SCL_LOW_MASK     0x00
#define SDA_HIGH_SCL_LOW_MASK    0x40
#define SDA_LOW_SCL_HIGH_MASK	 0x80
//
// SAA9051 subaddress locations.
//
#define IDEL_REG_9051       0x00
#define HSY_START_REG_9051  0x01
#define HSY_STOP_REG_9051   0x02
#define HC_START_REG_9051   0x03
#define HC_STOP_REG_9051    0x04
#define HS_START_REG_9051   0x05
#define HOR_PEAK_REG_9051   0x06
#define HUE_PHASE_REG_9051  0x07
#define CTRL1_REG_9051      0x08
#define CTRL2_REG_9051      0x09
#define CTRL3_REG_9051      0x0A
#define SECAM_DLY_REG_9051  0x0B
//
// 9051 register values
//
#define VAL_idel 0x64     // Reg 0x00
#define VAL_hsb5 0x35     // Reg 0x01
#define VAL_hsb5_Pal 0x30 //          Pal values?
#define VAL_hss5 0x0a     // Reg 0x02
#define VAL_hss5_Pal 0x00 //          Pal values?
#define VAL_hcb5 0xf8     // Reg 0x03
#define VAL_hcb5_Pal 0xe8 //          Pal values?
#define VAL_hcs5 0xca     // Reg 0x04
#define VAL_hsp5 0xfe     // Reg 0x05
#define VAL_lum 0x81      // Reg 0x06 was 0x29
#define VAL_lum_SVHS 0x81
#define VAL_hue 0x00      // Reg 0x07
#define VAL_cktq_Pal  0x38 // Reg 0x08 Pal val   = 38
#define VAL_cktq_NTSC 0x77 // Reg 0x08 NTSC val  = 77
#define VAL_cktq_Sec  0x38 // Reg 0x08 SECAM Val = ??
#define VAL_ckts 0xe0     // Reg 0x09
#define VAL_plse 0x40     // Reg 0x0a
#define VAL_sese 0x00     // Reg 0x0b
//
#define VAL_gain_NTSC 0x00
#define VAL_gain_Sec 0x80
#define VAL_mode_NTSC 0x8c
#define VAL_mode_Sec 0x8d
#define VAL_iock_port0 0x40  // j4  in svhs mode j4 is lum, j8 is chrm
#define VAL_iock_port1 0x48  // j8      NTSC??
#define VAL_iock_port2 0x50  // j7
#define VAL_ctl3_50Hz 0xd9
#define VAL_ctl3_Sec 0xb9
#define VAL_ctl3_422 0x99
#define VAL_ctl3_411 0x91
#define VAL_ctl4 0x00
#define VAL_chrm_NTSC 0x2c
#define VAL_chrm_PAL 0x59
#define VAL_hsb6 0x34  //11
#define VAL_hss6 0x0a  //fe
#define VAL_hcb6 0xf4  //e6
#define VAL_hcs6 0xce
#define VAL_hsp6 0xf4


/*
 *   Global Variables.
 */

#ifdef _PHVIDEO_H
PhillipsIOParams PhilIOPort1 = {PCS_IN_ONLY,NTSC,NTSC,PCS_CHAN1_INPUT,PCS_FILTER_DEFAULT,0,"Untitled.LUT","Untitled.LUT"};
PhillipsIOParams PhilIOPort2 = {PCS_IN_ONLY,NTSC,NTSC,PCS_CHAN1_INPUT,PCS_FILTER_DEFAULT,0,"Untitled.LUT","Untitled.LUT"};
PhillipsIOParams PhilIOTmp = {PCS_IN_ONLY,NTSC,NTSC,PCS_CHAN1_INPUT,PCS_FILTER_DEFAULT,0,"Untitled.LUT","Untitled.LUT"};
#endif

#ifndef _PHVIDEO_H
extern PhillipsIOParams PhilIOPort1;
extern PhillipsIOParams PhilIOPort2;
extern PhillipsIOParams PhilIOTmp;
#endif


// Prototypes ---------------------------------------------------
//int ioSetCurrentVID(int iProc);
//int ioGetCurrentVID(void);
//int ioGetCurrentVIDPort(void);
//unsigned char i2c_read(unsigned char ucDevAddr);
//unsigned char i2c_write(unsigned char ucAddress,unsigned char ucSubAddress,unsigned char ucDataIn);
//unsigned char i2c_write99(unsigned char ucAddress,unsigned char ucCtlAddress,unsigned char ucSubAddress,unsigned char ucDataIn);

//unsigned char i2c_lutload(unsigned char ucAddress, unsigned char ucSubAddress,unsigned char ucLutAddress,unsigned char ucDataIn);
//unsigned char i2c_slave_positive_ack(void);
//unsigned char i2c_master_positive_ack(void);
//unsigned char i2c_master_negative_ack(void);
//unsigned char i2c_start(unsigned char address,
//			unsigned char subaddress,
//			unsigned char number_addr);
//unsigned char i2c_restart(unsigned char address_value);
//unsigned char i2c_xmit_data(unsigned char data_value);
//unsigned char i2c_receive_data(unsigned char *data_value);
//unsigned char i2c_stop(void);
//unsigned char i2c_read(unsigned char ucDevAddr);

int ioSetCurrentVID(int iProc);
int ioGetCurrentVID(void);
int ioGetCurrentVIDPort(void);

int DrvVidModWrite(unsigned char ucSubAddr,unsigned char ucValue);

int ioInitVid(LPCURRENT_VIDEO_PARAMS);
int ioSetVidChannel(int);
int ioSetVidFilter(int);
int ioSetVidInFormat(VFORMAT);
int ioSetVideoHue(int);
int ioSetVideoMode(VMODE);

//void phGetPhilParams(HWND);
//void phOkMessage (HWND, char *, char *, char *);
//void phPopFileInitialize (HWND);
//BOOL phPopFileOpenDlg (HWND, LPSTR, LPSTR);
//static long phPopFileLength (int);
//BOOL phPopFileRead (HWND, LPSTR);
//void phShowLUTFile (HWND, int, char *);
//int phiniReadVideoModuleConfig (int iPort); /* Reads the PhVideoModule configuration from the the SYSTEM.INI */


/* exported prototypes --------------------------------------------*/
#ifdef __cplusplus
extern "C"
{
#endif


//BOOL phPCSDuplexProc (HWND, WORD, WORD, LONG);
//BOOL _far _pascal _export phPCSRealtimeProc (HWND, WORD, WORD, LONG);

//int phVideoSetup(HWND hParent, VMODE VideoMode, VFORMAT far *pVideoFormat);
//int phVideoRealtime(HWND hParent, HWND far *hDlg);
int phSetCurrentVid(int iVideoPort);
int phGetCurrentVid(void);
int phInitHW(int iPort);  /* Calls the HW init routines */
int phSetVidChannel(unsigned char bChannel,int iPort);
int phSetVidFilter(unsigned char bDecodeFilter, int iPort);
int phSetVidInFormat(VFORMAT VideoFormat, int iPort);
int phSetVidOutFormat(VFORMAT VideoFormat, int iPort);
int phSetVideoHue(int iHue, int iPort);
int phSetVideoMode(VMODE VideoMode, int iPort);
int phGetVideoMode(int iPort);
int phGetVideoSyncInfo(VMODE VideoMode);
#ifdef __cplusplus
}
#endif



#endif

