/**********************************************************
*
*       File Name:  PIPDemo.c
*
*       Module Abstract:
*
*       Calling Sequence:
*       PIPDemo(float *fChannels, float* fPicutreIF,int iMinChannel,
*              int iMaxChannel,int CurrentChannel)
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: John Schafer/KAP
*       Date:   12/10/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/* #includes --------------------------------------------*/
#include <stdio.h>

#include <vga.h>

#include "evaldiag.h"
#include "evalprot.h"
#include "iodvp.h"
#include "iomd.h"
#include "px2070.h"


extern G_pvConfigArray[];

void PIPDemo(float *fChannels,float *fPictureIF,int iMinChannel,
	     int iMaxChannel,int iCurrentChannel)
{
    PX2070Ports *pPX2070AddrStruct;
    int iXSize, iYSize, iXRef;
    char keypress;
    int iCurrentDVP;
    float fTemp;
    long cnt;
    unsigned short sval[200000]; /* Must be bigger then iXSize*iYSize */
    int ReadX, ReadY;
 
    iCurrentDVP = ioGetCurrentDVP();

    pPX2070AddrStruct = (PX2070Ports *)G_pvConfigArray[iCurrentDVP];


    /* Take the 1085 out of vafc mode - Writes directly to 1085 */
    ioRSV2WriteMD(2);
    /* disable the gamma palette - Writes direectly to 1085 */
    ioVideoFormatWriteMD(0x10);


    /* When using overlay function, this MUST change to a graphics mode
       that contains <= 256 colors.
       When not using overlay mode and you want to use the sample
       screen dump code below then you must select a graphics mode
       > 265 so that the RGB functions will work.  I use mode 20
       which is G800x600x32K.  This makes the screen very close to
       the actual TV resolution. */
    SetGraphicsMode();

    /* Set up the size of the video picture.  In real world applications
       you would probably want to make this just big enough to capture the
       valueable video data you want to work with.  This is so you don't
       waste time coping unneeded data in.  But then again if your just
       waiting around for the picture like we are here then its OK.
    /* Using an X this big actually captures the Horizontal Sync band at
       the extreme right of the picture. Could someone remind me
       the number of pixel in NTSC video, both picture portion and
       full length. */
    iXSize = 730;
    /* There are 262.5 lines of data in 1 Field of an NTSC frame */
    /* Testing seems to show only 256 lines can be read in from
       hardware though.  This seems to normal with other TV cards. */
/*    iYSize = 256; */
    iYSize = 230;
    iXRef  = 1024; /* Not sure why you set this.  I think its good to
		      have it set to the size of your monitor resolution
		      but I'm not sure.  */

    /* Do a soft reset */
    SoftResetDVP();

    /* halt sequencer */
    SeqHalt();

    /* Clear out the fifos */
    ResetFifo(ALL_FIFOS);

    /* Set up the MMU - tell it 32-bit  Frame Buffer Data Bus and 128k mem */
    SetUpMMU();

    /* Disable all objects - Writes 0 to all OBU?_MCR's */
    OBReset(ALL_OBJECTS);

    /* Disable Units - disables IPU1, IPU2, and OPU.  Is this really
       needed?  It should do the same basic thing when you set up
       your input/outputs later. It may flush out old data though. */
    ioRDTWriteDVP(i_VPU_MCR,0);

    /* Setup DWU to display a window */
    /* Among other things, disables all windows */
    ioRDTWriteDVP(DWU_MCR,0);
    
    /* OK, most registers so far are Posted, meaning they won't
       take effect until a field toggle or a manual request.  So
       be sure and do a manual request so things actually get flushed */
    UpdateGen();

    /* Don't really know.  Something about Horizontal Active Count.
       Specifies the number of pixel periods in the horizontal line
       active interval fore the output CRT display. */
    ioRDTWriteDVP(DWU_HCR, DW_VGA + 24);

    /* I'll use DWU0 for my display (even though I can't see it) */

    /* You can zoom in with this.  Formula is scaling = 256 / Zoom Factor.
       0 is a special case where it does a scaling factor of 1X. */
    ioRDTWriteDVP(DWU0_DZF, DW_ZOOM_1X);
    /* Reference Frame X Size */
    ioRDTWriteDVP(DWU0_RFX,iXRef);
    /* You could probably change these offsets to make the display
       window skip past unwanted data to be seen, such as the VBI.
       Overlay doesn't work for me so I don't know.  */
    ioRDTWriteDVP(DWU0_LSL,0);
    ioRDTWriteDVP(DWU0_LSH,0);
    ioRDTWriteDVP(DWU0_WSX,iXSize);
    ioRDTWriteDVP(DWU0_WSY,iYSize);
    /* The following Specifies te (X,Y) start position on your CRT to
       place the overlay window.  (0,0) is the upper left corner. */
    ioRDTWriteDVP(DWU0_DSX,2+10+160);
    ioRDTWriteDVP(DWU0_DSY,1+9+120);

    /* Means set Graphics Clock to 1x GPCLK if your interested
       and it also turns on Displa Window 0. */
    ioRDTWriteDVP(DWU_MCR,DW_1XCLOCK + DW_WIN0);

    /* This just reads the OCS register, then disable's all IRQ's,
       Imediately post any register updates that haven't been made
       yet. */
    UpdateGen();

    /* Setup Video Port 1 to have Input Video Vertical Sync Polarity */
    ioRDTWriteDVP(i_VIU_MCR1,VIU_IVSP_HI);

    /* Flush out anything related to Field 1. If someone wants to
       do full 60 frames a second for overlay mode they will need
       to initialize both DPC1 and DPC2 since DPC1=Field 1 and
       DPC2=Field 2.
     */
    ioRDTWriteDVP(i_VIU_DPC1, 0);
    UpdateGen();
    /* Field 1 comes from IPU1 and sources its sync from there and
     is also phase qualified. */
    ioRDTWriteDVP(i_VIU_DPC1, IPU1_from_Vp1_Phase);

    /* I'll use Object Buffer 0 for my input object */
    Setup_OB (OBU0_MCR,
	      /* Make Object Buffer 1 in Normal Address mod,
		 with X and Y BLT counters increasing its memory
		 address. */
	      (OB_Normal + OB_XBLT + OB_YBLT),
	      /* Needs to match DWU and IPU */
	      iXRef,
	      /* Offset into buffer to start.  Using anything other then
		 zero has strange results that I don't understand yet.
		 This is a 22-bit value.  The first specifies the
		 upper 6-bits and the 2nd value specifies the lower 16-bits.
	      */
	      0, 0,
	      /* You can also set the following so that Sync fields
		 in the right side aren't captured. */
	      iXSize, iYSize,
	      /* This is an 8-bit mask.  If a given bit is set then
		 for every 8 pixels read in, it will drop the pixel
		 that matches the bit location.  This is probably
	         of use as a fast scaler. */
	      0);

    /* offset,mcrval,xbi,xbf,xei,xsi,xsf,ybi,ybf,yei,ysi,ysf */
    /* Setup IP1 */
    Setup_Ip1 (i_IPU1_F1_BASE,
	       /* Input should always be 411 from Philips chip, I've
		  chosen RGB 5:6:5 output because its pretty simple to parse.
		  If you output RGB then you need to turn on the Color Space
		  Converter option. */
	       ColorConvert+In411+OutRGBNoTag, /* In/Out Format */
	       /* The following two values define a floating point #.
		  The first # can only be a 11-bit value and the second
		  # can only be a 3-bit value.  They are combined in
		  hardware to make a 11.3 value.  For some reason the
		  first # has to be at least a 1.
	       */
	       1,0,		/* XStart */
	       /* Put where you want to stop here.  Make sure you don't
		  include horizontal sync area if you don't want that.
		  Also make sure you always set the following to at
		  least iXSize+Xstart-1
	       */
	       iXSize,		/* XStop */
	       /* Same as above on makeup for 4.10 value. */
	       1,0,		/* XShrink */
	       /* Same as above on makeup for 11.3 value. */
	       /* You could change this to something like 22,0
		  to skip the VBI data.
	       */
	       1,0,		/* YStart */
	       /* Put where you want to stop here.  Make sure you don't
		  include horizontal sync area if you don't want that.
		  Also make sure you always set the following to at
		  least iYSize+Ystart-1
	       */
	       iYSize,		/* YStop */
	       /* Same as above on makeup for 4.10 value. */
	       1,0		/* YShrink */
	);

    /* To SIU_FCS to Enable all FIFO's */
    EnableFifo(ALL_FIFOS);

    /* Enable IP1 */
    /* This Starts IPU1 on field 1, only the single field is processed */
    /* This probably make sences because we can supposedly only read up
       to 30 frames a second through the ISA bus which is what is
       equal to a single fields worth of data in 1 second. */
    /* Needs to be changed this for full 60-frames a second mode, probably
       to IP1_Start_F1. */
    ioRDTWriteDVP(i_VPU_MCR,IP1_F1_Only);

    UpdateGen();
    
    /* Only thing we want to do is copy data from V1 to Object Buffer 0. */
    /* Do this and loop back to the same instruction. */
    ioRDTWriteDVP(SIU_SIM0,(IPU1_to_OB0 + offset_0));      /* Seq Inst 0 */

    /* (SIU_SI1 * 0) means place a Starting Address of 0 into the part of
       the register that contains Start Index 1. */
    ioRDTWriteDVP(i_SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

    /* wait to start the sequencer */
    SeqWait(SIU_Start1);

    do
    {
	keypress=vga_getch();
	if (keypress == 'c')
	{
	    /* Freeze Image */
	    SeqHalt();
	    /* Clear out the fifos */
	    ResetFifo(ALL_FIFOS);

	    /* Disable all objects - Writes 0 to all OBU?_MCR's */
	    OBReset(ALL_OBJECTS);

	    /* Field 1 comes from IPU1 and sources its sync from there and
	       is also phase qualified. But Flush First. */
	    ioRDTWriteDVP(i_VIU_DPC1, 0);
	    UpdateGen();
	    
	    /* To SIU_FCS to Enable all FIFO's */
	    EnableFifo(ALL_FIFOS);
	    UpdateGen();
	    
	    ioRDTWriteDVP(i_VIU_DPC1, OPU_to_Host);
	    
	    Setup_OB(OBU2_MCR,OB_Normal+OB_SSM+OB_XBLT+OB_YBLT+OB_No_Copy,
		     iXRef,0,0,
		     iXSize,iYSize,0);
	    ioRDTWriteDVP(SIU_SIM0,(OB2_to_OP+offset_0));
	    ioRDTWriteDVP(i_SIU_MCR,(SIU_Start1 + SIU_No_Toggle +
				     (SIU_SI1 * 0)));

	    SeqManStart();
	     
	    cnt=0;
	    while(!IsFifoEmpty(FIFO_D)&&(cnt<iXSize*iYSize))
		sval[cnt++]=ioMDTShortReadDVP();
	     
	    printf("Count = %d\n",cnt);
	    cnt=0;
	    for (ReadY = 1; ReadY <= iYSize; ReadY++)
	    {
		for (ReadX = 1; ReadX <= iXSize; ReadX++)
		{
		    /* When using RGB 5:6:5 you have to shrink the
		       X size by 2 using IPU1 for some reason. */
		    vga_setrgbcolor((sval[cnt]&0xf800)>>8,
				    (sval[cnt]&0x07e0)>>3,
				    (sval[cnt]&0x001f)>>3);
		    /* Notice the (ReadY*2).  This is because TV is
		       actually 525 scan lines BUT we only read 1
		       Field so we only have 262 lines to display.
		       This leaves a blank line ever other line and
		       gives a suprisingly good picture of proper
		       proportions.
		    */
		    vga_drawpixel(ReadX,ReadY*2);
		    cnt++;
		}
	    }

	    /* The following code is close to the minimum needed to
	       start moving data again.  For some reason, there is a
	       problem that the captured video starts to "roll".  Does
	       it do this on the overlay video???  If I remove all this
	       code and copy EVERYTHING from the SoftReset() above down
	       to the begining of the while() loop then this problem
	       stops.  Kinda extreme to do a soft reset between each capture
	       though!  FIX ME FIX ME FIX ME PLEASE PLEASE PLEASE 
	     */

	    /* Clear out the fifos */
	    ResetFifo(ALL_FIFOS);

	    /* Disable all objects - Writes 0 to all OBU?_MCR's */
	    OBReset(ALL_OBJECTS);

	    /* Make sure Vertical Sync toggles Master Field Select */
	    ioRDTWriteDVP(i_VIU_WDT,0);
	    UpdateGen();

	    /* Setup Video Port 1 to have Input Video Vertical Sync Polarity */
	    ioRDTWriteDVP(i_VIU_MCR1,VIU_IVSP_HI);
    
	    /* Field 1 comes from IPU1 and sources its sync from there and
	       is also phase qualified. But Flush First. */
	    ioRDTWriteDVP(i_VIU_DPC1, 0);
	    UpdateGen();
	    ioRDTWriteDVP(i_VIU_DPC1, IPU1_from_Vp1_Phase);

	    /* I'll use Object0 for my input object */
	    Setup_OB (OBU0_MCR, (OB_Normal + OB_XBLT + OB_YBLT),
		      iXRef, 0, 0,
		      iXSize, iYSize, 0);

	    /* To SIU_FCS to Enable all FIFO's */
	    EnableFifo(ALL_FIFOS);

	    
	    UpdateGen();
    
	    /* Only thing we want to do is copy data from V1 to Object
	       Buffer 0. */
	    /* Do this and loop back to the same instruction. */
	    ioRDTWriteDVP(SIU_SIM0,(IPU1_to_OB0 + offset_0));      /* Seq Inst 0 */

	    /* (SIU_SI1 * 0) means place a Starting Address of 0 into the
	       part of the register that contains Start Index 1. */
	    ioRDTWriteDVP(i_SIU_MCR,(SIU_Start1 + SIU_No_Toggle +
				     (SIU_SI1 * 0)));
     
	    /* wait to start the sequencer */
	    SeqWait(SIU_Start1);

	} 
	if (keypress == 'm')
	{
	    SetAudioMute(AUDIO_MUTE);
	}
	if (keypress == 's') /* turn on status screen */
	{
	    vga_setmode(TEXT);
	    sleep(3);
	    SetGraphicsMode();
	}
	if (keypress == '+')
	{
	    do 
	    {
		if (++iCurrentChannel > iMaxChannel)
		{
		    iCurrentChannel = iMinChannel;
		}
		fTemp = fChannels[iCurrentChannel]; /* get correct freq */
		printf("Channel: %d\n",iCurrentChannel);
	    } while (fTemp == (float) 0);
	    tnrChangeChannel((float *) &fTemp, (char)0,(float *) fPictureIF);
	}
	if (keypress == '-')
	{
	    do
	    {
		if (--iCurrentChannel < iMinChannel)
		{
		    iCurrentChannel = iMaxChannel; 
		}
		fTemp = fChannels[iCurrentChannel]; /* get correct freq */
		printf("Channel: %d\n", iCurrentChannel);
	    } while (fTemp == (float) 0);
	    tnrChangeChannel((float *) &fTemp, (char)0, (float*) fPictureIF);
	}
	if (keypress == 'u')
	{
	    SetAudioMute(AUDIO_ON);
	}
    }while(keypress  != 'q' && keypress != 'Q');
    vga_setmode(TEXT);
} /* End PIPDemo() */






