/**********************************************************
*
*       Copyright (c) 1994 Pixel Semiconductor, Inc.  All rights reserved.
*
*       File Name: TUNER.H
*
*       Module Abstract:
*       ----------------
*       Header file for TUNER.C
*
***********************************************************
*
*       Author: Gary Peterson
*       Date:   04-04-94
*
*       Revision History:
*       -----------------
*       WHO             WHEN            WHAT/WHY/HOW
*       ---             ----            ------------
*       Frank Xu      8-30-94          Added function to read
*                                      tuner status for autoscan   
*                                      and also make it work for
*                                      both TIMIC and PHILIPS tuners
*
**********************************************************/

/*
 *   Set meaning of EXTERN.
 */
#ifdef PXTUNER_H
#define EXTERN
#else
#define EXTERN extern
#endif

#define TIMIC                       0    // Using TIMIC tuner

/*
 *   Global Defines.
 */
#define TUNER_WRITE_ADDRESS         0xC2
#define TUNER_READ_ADDRESS          0xC2
/*
 *       Tuner subaddress locations.
 */
#define ADDRESS_BYTE                0x00
#define DIVIDER_BYTE0               0x01
#define DIVIDER_BYTE1               0x02
#define CHARGE_PUMP_CTRL            0x03
#define OUTPUT_PORT_CTRL            0x04   

#define ADDRESSUSED                 1
#define SUBADDRESSUSED              2      
#define SUB_SUBADDRESSUSED          3

#define LOW_GAIN                    0x8E
#define HIGH_GAIN                   0xCE

#if TIMIC
#define LOW_FREQ_BAND               0x02  /* 55.25->157.25 MHz. */
#define MID_FREQ_BAND               0x04  /* 163.25->463.25 MHz. */
#define HIGH_FREQ_BAND              0x01  /* 469.25->801.25 MHz. */
#else
#define LOW_FREQ_BAND               0xA0  /* 45->110 MHz. */
#define MID_FREQ_BAND               0x90  /* 112->350 MHz. */
#define HIGH_FREQ_BAND              0x30  /* 360->999 MHz. */
#endif

#define DEFAULT_CHANNEL_HI_BYTE     0x10  /* Channel 4 */
#define DEFAULT_CHANNEL_LOW_BYTE    0x07  /* Channel 4 */
#define DEFAULT_CHARGE_PUMP         LOW_GAIN
#define DEFAULT_FREQ_BAND           LOW_FREQ_BAND

/*
 *   Auxillary Register defines.
 */
#define AUDIO_CS_BIT                0x80
#define AUDIO_UP_BIT                0x40
#define AUDIO_DN_BIT_               0x40
#define AUDIO_INC_BIT               0x20

/*
 *   Define new data types.
 */
typedef unsigned char               byte;
typedef unsigned short              word;
typedef unsigned int                longword;


/*
 *   Global variables.
 */
EXTERN unsigned char szError[160];

#undef EXTERN  

