/**********************************************************
*
*       File Name:  T0001Reg.c
*
*       Module Abstract: This module is the high level test routine
*               that enables the testing of the registers of the 0001.
*
*       Calling Sequence:
*       Test0001Regs()
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_wTestShorts[MAXSHORTPATS]
*       G_pvConfigArray[]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/1/94
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/* #includes --------------------------------------------*/
#include <stdio.h>
#include <asm/io.h>

#include "evaldiag.h"
#include "evalprot.h"
#include "iodvp.h"
#include "px2070.h"
#include "pxhil.h"
#include "iomd.h"
/*#include "pxvidapi.h" */
#include "iovid.h"

#define INDEX_MASK 0xf;
#define PX1070_MASK 0xfff;
#define PX1085_MASK 0xfe0;
#define I2CADDR_MASK 0xfff;
#define I2CPORT_MASK 0x3f;


extern G_iErrorLimit;
extern G_pvConfigArray[];
extern G_Px2070PortType;
/* Global test pattern array */
extern unsigned short G_wTestShorts[];
extern unsigned short wTestResultsArray[];
unsigned short G_Port0,G_Port1;

void Test0001Regs()
{
  Test0001IndexReg();
/*  Test1070AddrRegs(); */
/*  Test1085AddrReg(); */
/*  TestI2CAddrReg(); */
/*  if(G_pvConfigArray[VIDMODBASE]) */
/*    TestI2CPortReg(); */
/*  TestMiscReg(); */
  InitPx0001();
} /* End Test2070Regs */
/**********************************************************
*
*       File Name:  Test0001IndexReg
*
*       Module Abstract: This module performs the diagnostic
*               testing of the index register in the px0001.
*
*       Calling Sequence:
*       Test0001IndexReg()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/1/94
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/* GS void was here */
int Test0001IndexReg()
{
  unsigned short wReadVal,wWriteVal;
  int i;
  PX0001Ports *pPX0001AddrStruct;
  unsigned short wPortArray[4][2] = {0x8370,0x8372,
				     0x8270,0x8272,
				     0x0270,0x0272,
				     0x0370,0x0372};
  pPX0001AddrStruct = (PX0001Ports *)G_pvConfigArray[PX0001BASE];
  G_Port0 = pPX0001AddrStruct->PX0001Port0;
  G_Port1 = pPX0001AddrStruct->PX0001Port1;

  /* Test the address at which the chip is responding */
  for(i=0;i<4;i++)
  {
    G_Port0 = wPortArray[i][0];
    G_Port1 = wPortArray[i][1];
    ioWriteGLU(G_Port0,0xa);
    wReadVal = ioReadGLU(G_Port0) & INDEX_MASK;
    if(wReadVal == 0xa)
    {
      ioWriteGLU(G_Port0,0x5);
      wReadVal = ioReadGLU(G_Port0) & INDEX_MASK;
      if(wReadVal== 0x5)break;
    }
  }

  if(i!=0)
  {
    printf("PX0001 Not Responding At 0x8370\n");
  }

  /* Test the Index  register */
  for (i=0; i < MAXSHORTPATS; i++)
  {

    /* Get the test value and write it. */
    wWriteVal = G_wTestShorts[i] & INDEX_MASK;
    ioWriteGLU(G_Port0,wWriteVal);

    /* Is what you read what you wrote? */
    wReadVal = ioReadGLU(G_Port0) & INDEX_MASK;
    if (wReadVal != wWriteVal)
    {
      printf("PX0001 Index READ ERROR Expected %04x Actual %04x \n",wWriteVal,wReadVal);
    }
  } /* for */
  /* Reset all registers */
  ioWriteGLU(G_Port0,0);
} /* End Test0001IndexReg */


/**********************************************************
*
*       File Name:  Test1085AddrReg
*
*       Module Abstract: This module performs the diagnostic
*               testing of the 1085 address register in the px0001.
*
*       Calling Sequence:
*       Test1085AddrReg()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
*       G_iErrorLimit
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/1/94
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void Test1085AddrReg()
{
  unsigned short wReadVal,wWriteVal;
  int i;

  /* Point the index register to the 1085 address reg */
  ioWriteGLU(G_Port0,7);

  /* Test the Index  register */
  for (i=0; i < MAXSHORTPATS; i++)
  {

    /* Get the test value and write it. */
    wWriteVal = G_wTestShorts[i] & PX1085_MASK;
    ioWriteGLU(G_Port1,wWriteVal);

    /* Is what you read what you wrote? */
    wReadVal = ioReadGLU(G_Port1) & PX1085_MASK;
    if (wReadVal != wWriteVal)
    {
      printf("PX0001 PX1085 Address READ ERROR Expected %04x Actual %04x \n",wWriteVal,wReadVal);
    }
  } /* for */
  /* Reset all registers */
  ioWriteGLU(G_Port1,0);
} /* End Test1085AddrReg */

/**********************************************************
*
*       File Name:  TestI2CAddrReg
*
*       Module Abstract: This module performs the diagnostic
*               testing of the I2C address register in the px0001.
*
*       Calling Sequence:
*       TestI2CAddrReg()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/1/94
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void TestI2CAddrReg()
{
  unsigned short wReadVal,wWriteVal;
  int i;

  /* Point the index register to the I2C address reg */
  ioWriteGLU(G_Port0,5);

  /* Test the Index  register */
  for (i=0; i < MAXSHORTPATS; i++)
  {
    /* Get the test value and write it. */
    wWriteVal = G_wTestShorts[i] & I2CADDR_MASK;
    ioWriteGLU(G_Port1,wWriteVal);

    /* Is what you read what you wrote? */
    wReadVal = ioReadGLU(G_Port1) & I2CADDR_MASK;
    if (wReadVal != wWriteVal)
    {
      printf("PX0001 I2C Address READ ERROR Expected %04x Actual %04x \n",wWriteVal,wReadVal);
    }
  } /* for */
  /* Reset all registers */
  ioWriteGLU(G_Port1,0);
} /* End TestI2CAddrReg */

/**********************************************************
*
*       File Name:  TestMiscReg
*
*       Module Abstract: This module performs the diagnostic
*               testing of the Misc register in the px0001.
*
*       Calling Sequence:
*       TestMiscReg()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/1/94
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void TestMiscReg()
{
  unsigned short wReadVal,wWriteVal;
  int i;

  /* Point the index register to the misc reg */
  ioWriteGLU(G_Port0,6);

  /* Test the Index  register */
  for (i=0; i < MAXSHORTPATS; i++)
  {
    /* Get the test value and write it. */
    wWriteVal = G_wTestShorts[i] ;
    ioWriteGLU(G_Port1,wWriteVal);

    /* Is what you read what you wrote? */
    wReadVal = ioReadGLU(G_Port1) ;
    if (wReadVal != wWriteVal)
    {
      printf("PX0001 MISC READ ERROR Expected %04x Actual %04x \n",wWriteVal,wReadVal);
    }
  } /* for */
  /* Reset all registers */
  ioWriteGLU(G_Port1,0);
} /* End TestMiscReg */

/**********************************************************
*
*       File Name:  TestI2CPortReg
*
*       Module Abstract: This module performs the diagnostic
*               testing of the I2C port register in the px0001.
*
*       Calling Sequence:
*       TestI2CPortReg()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/1/94
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void TestI2CPortReg()
{
  unsigned char bReadVal,bWriteVal;
  int i;
  VIDPorts *pVIDPorts;

  /* Point the index register to the i2c addr reg */
  ioWriteGLU(G_Port0,5);

  /* Get the lower 12 bits of the I2C port and write it to the addr reg */
  pVIDPorts =  (VIDPorts *)G_pvConfigArray[VIDMODBASE];
  ioWriteGLU(G_Port1,pVIDPorts->VIDPort0 & 0xfff);

  /* Point the index register to the misc reg */
  ioWriteGLU(G_Port0,6);

  /* Get the upper 4 bits of the I2C port and write it to the misc reg */
  ioWriteGLU(G_Port1,(pVIDPorts->VIDPort0 & 0xf000) >> 9);

  /*Set the setup ok bit for i2c reads */
  ioWriteGLU(G_Port0,0x10);
  /* Test the i2c port register */
  for (i=0; i < MAXSHORTPATS; i++)
  {
    /* Get the test value and write it. */
    bWriteVal = (unsigned char)G_wTestShorts[i] & I2CPORT_MASK;
    outb_p((unsigned char) bWriteVal,pVIDPorts->VIDPort0);

    /* Is what you read what you wrote? */
    bReadVal = inb_p(pVIDPorts->VIDPort0) & I2CPORT_MASK;
    if (bReadVal != bWriteVal)
    {
      printf("PX0001 I2C PORT READ ERROR Expected %04x Actual %04x \n",bWriteVal,bReadVal);
    }
  } /* for */
  /* Reset the i2c port */
  outb_p(0,pVIDPorts->VIDPort0);

  /* Reset all registers */
  for(i=0;i<8;i++)
  {
    ioWriteGLU(G_Port0,i);
    ioWriteGLU(G_Port1,0);
  }
  ioWriteGLU(G_Port0,0);
} /* End TestI2CPortReg */



/**********************************************************
*
*       File Name:  Test1070AddrRegs
*
*       Module Abstract: This module performs the diagnostic
*               testing of the 1070 address registers in the px0001.
*
*       Calling Sequence:
*       Test1070AddrRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/1/94
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void Test1070AddrRegs()
{
  unsigned short wReadVal,wWriteVal;
  int i,j;

  for (j=0;j<5;j++)
  {
    /* Set the index reg to point to the 1070 Addr reg */
    ioWriteGLU(G_Port0,j);

    /* Test the address  register */
    for (i=0; i < MAXSHORTPATS; i++)
    {
      /* Get the test value and write it. */
      wWriteVal = G_wTestShorts[i] & PX1070_MASK;
      ioWriteGLU(G_Port1,wWriteVal);

      /* Is what you read what you wrote? */
      wReadVal = ioReadGLU(G_Port1) & PX1070_MASK;
      if (wReadVal != wWriteVal)
      {
	printf("PX0001 1070 Address READ ERROR Expected %04x Actual %04x \n",wWriteVal,wReadVal);
      }
    } /* for i */
  } /* for j */
  /* Reset all registers */
  for(i=0;i<5;i++)
  {
    ioWriteGLU(G_Port0,i);
    ioWriteGLU(G_Port1,0);
  }
} /* End Test1070AddrRegs */

/**********************************************************
*
*       File Name:  InitPx0001
*
*       Module Abstract: This module initializes the px0001.
*
*       Calling Sequence:
*       InitPx0001();
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/1/94
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/*Gs void was here */
int InitPx0001()
{
  int i;
  PX2070Ports *pPX2070Ports;
  PX2080Ports *pPX2080Ports;
  VIDPorts *pVIDPorts;


  pPX2070Ports =  (PX2070Ports *)G_pvConfigArray[PX2070BASE];
  pPX2080Ports =  (PX2080Ports *)G_pvConfigArray[PX2080BASE];
  pVIDPorts = (VIDPorts *)G_pvConfigArray[VIDMODBASE];

  /*Set up the 1070 addresses */
  ioWriteGLU(G_Port0,0);
  ioWriteGLU(G_Port1,(pPX2070Ports->PX2070Port0));
  ioWriteGLU(G_Port0,1);
  ioWriteGLU(G_Port1,pPX2070Ports->PX2070Port1);
  ioWriteGLU(G_Port0,2);
  ioWriteGLU(G_Port1,pPX2070Ports->PX2070Port2);
  ioWriteGLU(G_Port0,3);
  ioWriteGLU(G_Port1,pPX2070Ports->PX2070Port3);
  ioWriteGLU(G_Port0,4);
  ioWriteGLU(G_Port1,pPX2070Ports->PX2070Port4);

  /* Setup the 1085 addresses */
  ioWriteGLU(G_Port0,7);
  ioWriteGLU(G_Port1,pPX2080Ports->PX2080Port0);

  /* Setup the i2c addr reg */
  ioWriteGLU(G_Port0,5);
  ioWriteGLU(G_Port1,pVIDPorts->VIDPort0);

  /* Setup the misc reg */
  ioWriteGLU(G_Port0,6);
  if(G_pvConfigArray[PX2070BASE])
    ioWriteGLU(G_Port1,((pPX2070Ports->PX2070Port0 & 0xf000) >> 9) | 0x307);
  else if(G_pvConfigArray[PX2080BASE])
    ioWriteGLU(G_Port1,((pPX2080Ports->PX2080Port0 & 0xf000) >> 9) | 0x307);
  else if(G_pvConfigArray[VIDMODBASE])
    ioWriteGLU(G_Port1,((pVIDPorts->VIDPort0 & 0xf000) >> 9) | 0x307);

  /*Set the setupok bit */
  ioWriteGLU(G_Port0,0x10);

} /* End InitPx0001 */



/**********************************************************
*
*       File Name:  SetGraphicsSource
*
*       Module Abstract: This module switches between
*       VGA and 1085 graphics.
*
*       Calling Sequence:
*       SetGraphicsSource(int iSource)
*
*       Input Parameters:
*       int iSource
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   2/21/95
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void SetGraphicsSource(int iSource)
{
  unsigned short wReadVal,wWriteVal;
  int i;

  /* Check to see if the loopback cable is installed */
  /* Point the status reg */
  ioWriteGLU(G_Port0,0x18);

  wReadVal = ioReadGLU(G_Port1);

  /*printf("status = %x\n",G_Port1); */
  /*printf("status = %x\n",G_Port0); */
  /*while(!kbhit()); */
  /*getch(); */
  wReadVal &= 0x8;

  if (wReadVal==0) /* Cable installed */
  {
    /* Select the graphics source */
    /* Point the index register to the misc reg */
    ioWriteGLU(G_Port0,0x16);
    /* Read whats in the misc reg */
    wReadVal = ioReadGLU(G_Port1);
    /*printf("status = %x\n",wReadVal); */
    wReadVal &= 0xbfff;
    wReadVal |= iSource <<14;
    /*printf("source = %d\n",iSource); */
    /*printf("status = %x\n",wReadVal); */
    /*while(!kbhit()); */
    /*getch(); */
    ioWriteGLU(G_Port1,wReadVal);
  }
} /* End SetGraphicsSource */

/**********************************************************
*
*       File Name:  SetAudioSource
*
*       Module Abstract: This module switches between
*       tuner and external.
*
*       Calling Sequence:
*       SetAudioSource(int iSource)
*
*       Input Parameters:
*       int iSource
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   2/21/95
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void SetAudioSource(int iSource)
{
  unsigned short wReadVal;
  int i;


  /* Select the Audio source */
  /* Point the index register to the misc reg */
  ioWriteGLU(G_Port0,0x16);
  /* Read whats in the misc reg */
  wReadVal = ioReadGLU(G_Port1);
  /*printf("status = %x\n",wReadVal); */
  wReadVal &= 0x7fff;
  wReadVal |= iSource <<15;
  /*printf("source = %d\n",iSource); */
  /*printf("status = %x\n",wReadVal); */
  /*while(!kbhit()); */
  /*getch(); */
  ioWriteGLU(G_Port1,wReadVal);

} /* End SetAudioSource */

/**********************************************************
*
*       File Name:  SetAudioMute
*
*       Module Abstract: This module switches between
*       muted and unmuted audio.
*
*       Calling Sequence:
*       SetAudioMute(int iMute)
*
*       Input Parameters:
*       int iSource
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   2/21/95
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void SetAudioMute(int iMute)
{
  unsigned short wReadVal;
  int i;


  /* Mute/unmute the Audio source */
  /* Point the index register to the misc reg */
  ioWriteGLU(G_Port0,0x16);
  /* Read whats in the misc reg */
  wReadVal = ioReadGLU(G_Port1);
  /*printf("status = %x\n",wReadVal); */
  wReadVal &= 0xefff;
  wReadVal |= iMute <<12;
  /*printf("source = %d\n",iMute); */
  /*printf("status = %x\n",wReadVal); */
  /*while(!kbhit()); */
  /*getch(); */
  ioWriteGLU(G_Port1,wReadVal);

} /* End SetAudioMute */
