/**********************************************************
*
*       File Name:  T2070DWU.c
*
*       Module Abstract: This module verifies that the Display window
*               unit is capable of sourcing data from the VRAM to
*               the RAMDAC.
*
*
*       Calling Sequence:
*       Test2070DWU()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_wTestShorts[MAXSHORTPATS]
*       G_iErrorCount
*       G_iErrorLimit
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/

/* #includes --------------------------------------------*/
#include <stdio.h>
/*#include <graphics.h> */
#include <stdlib.h>
/*#include <conio.h> */


#include "evaldiag.h"
#include "evalprot.h"
#include "iodvp.h"
#include "iomd.h"
#include "px2070.h"

extern G_iErrorCount;
extern G_iErrorLimit;
extern G_pvConfigArray[];
/*extern G_Px2085PortType; */

void Test2070DWU()
{
int iTestCnt,iXSize, iYSize,iLoopCount,iColor,iMaxX,iMaxY;
unsigned char bExpected,bTemp;
unsigned short wReadVal,wWriteVal,wRowCount,wColCount,wExpected;
unsigned short wPixel0,wPixel1,wPort,wBir,wPixelArray[2];
unsigned long dwReadVal,dwExpected,dwLoopCount=0x7fff;
long lTimeCount;
int iWinXStart,iWinYStart,iWinWidth,iWinHeight,iCurrentDVP;
PX2070Ports *pPX2070AddrStruct;
iCurrentDVP = ioGetCurrentDVP();
pPX2070AddrStruct = (PX2070Ports *)G_pvConfigArray[PX2070BASE];

iXSize = 256;
iYSize = 256;

/* Take the 1085 out of vafc mode */
ioRSV2WriteMD(2);
/* disable the gamma palette */
ioVideoFormatWriteMD(0x10);

/* Use Borland graphics stuff to open image windows */
/*if (SetGraphicsMode()) */
  /*goto ERROREXIT; */

/*iWinXStart = 0; */
/*iWinYStart = 0; */
/*iWinWidth = getmaxx()+1; */
/*iWinHeight = getmaxy()+1; */
/*if (OpenWindow(iWinXStart,iWinYStart,iWinWidth,iWinHeight)) */
/*  goto ERROREXIT; */

/*iWinXStart = 20; */
/*iWinYStart = 20; */
/*iWinWidth = iXSize; */
/*iWinHeight = iYSize; */
/*if (OpenWindow(iWinXStart,iWinYStart,iWinWidth,iWinHeight)) */
  /*goto ERROREXIT; */


/**************************************************************
/* Write an object out to object 0 */
/**************************************************************/

/* Do a soft reset */
SoftResetDVP();

/* halt sequencer */
SeqHalt();

/* setup datapath controls */
GetHostPorts();

/* Clear out the fifos */
ResetFifo(ALL_FIFOS);

/* Enable the fifos */
EnableFifo(ALL_FIFOS);

/* Set up the MMU */
SetUpMMU();

/* Disable all objects */
OBReset(ALL_OBJECTS);

/* Setup sequencer */
ioRDTWriteDVP(SIU_SIM0,(IPU2_to_OB0 + offset_0)); /* Seq Inst 0 -- */

/* Setup Object (object,mcr, rfx, lsh, lsl, bsx, bsy, dec ) -- */
/*    normal addressing, xup, ydown, RFX=256, XS=256, YS=256, DEC=0, */

Setup_OB (OBU0_MCR, (OB_Normal +OB_SSM +  OB_XBLT + OB_YBLT + OB_No_Copy),
	  iXSize, 0, 0,  iXSize, iYSize, 0);

/* Enable sequencer start-- */
ioRDTWriteDVP(SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

/* Generate Newfield to start sequencer -- */
SeqManStart();

/* write to memory port -- */

lTimeCount = 0;
for (wRowCount = 0;wRowCount < iYSize;wRowCount++)
  {
  for (wColCount = 0;wColCount < iXSize;wColCount+=2)
    {
    /* While fifo F is full spin */
    while (IsFifoFull(FIFO_F))
      {
      lTimeCount++;
      if (lTimeCount == TIMEOUT)
	{
	printf("TIMEOUT ERROR Fifos Not Responding\n");
	wColCount = iXSize;
	wRowCount = iYSize;
	break;
	}
      }
    wPixel0 = ((wColCount << 8) | 0x80);
    wPixel1 = (((wColCount+1) << 8) | 0x80);
  ioMDTWriteDVP(((unsigned long)wPixel0 & 0xffff) |
		 (((unsigned long)wPixel1)<<16));
/*    wPixelArray[0] = wPixel0;
    wPixelArray[1] = wPixel1;
    ioMDTStreamWriteDVP(wPixelArray, 2);  */

    lTimeCount = 0;
    }  /* for ColCount */
  }  /* for RowCount */

/* Setup DWU to display a window */
ioRDTWriteDVP(DWU_MCR,0);
ioRDTWriteDVP(DWU_HCR, DW_VGA + 24);  /* Borland stuff needs 24 dont know why */
ioRDTWriteDVP(DWU1_DZF,DW_ZOOM_1X);
ioRDTWriteDVP(DWU1_RFX,iXSize);
ioRDTWriteDVP(DWU1_LSL,0);
ioRDTWriteDVP(DWU1_LSH,0);
ioRDTWriteDVP(DWU1_WSX,iXSize);
ioRDTWriteDVP(DWU1_WSY, iYSize);
ioRDTWriteDVP(DWU1_DSX,20+10);  /* Borland stuff needs 10 extra */
ioRDTWriteDVP(DWU1_DSY,20+9);   /* Borland stuff needs 9 extra */


  ioRDTWriteDVP(DWU_MCR,0x8000 /*+ DW_NOT_OCCLUDED + DW_VSYNC_HIGH */
      + DW_WIN1 );



UpdateGen();
#if 1
/* 1085 regs */
bTemp = ioAnalogSetupReadMD();
printf("ASC=%x\n",bTemp);
bTemp = ioGraphicsFormatReadMD();
printf("GFC=%x\n",bTemp);
bTemp = ioVideoFormatReadMD();
printf("VFC=%x\n",bTemp);
bTemp = ioGraphicsOvlyReadMD();
printf("GOC=%x\n",bTemp);
bTemp = ioRSV1ReadMD();
printf("RSV1=%x\n",bTemp);
bTemp = ioRSV2ReadMD();
printf("RSV2=%x\n",bTemp);
bTemp = ioRedChromaKeyReadMD();
printf("ckr=%x\n",bTemp);
bTemp = ioGreenChromaKeyReadMD();
printf("ckg=%x\n",bTemp);
bTemp = ioBlueChromaKeyReadMD();
printf("ckg=%x\n",bTemp);
bTemp = ioRedChromaMaskReadMD();
printf("kmr=%x\n",bTemp);
bTemp = ioGreenChromaMaskReadMD();
printf("kmg=%x\n",bTemp);
bTemp = ioBlueChromaMaskReadMD();
printf("kmb=%x\n",bTemp);

#endif

#if 0
while(dwLoopCount)
  {
  if(getc())
    {
    dwLoopCount = 0;
    }
  else
    dwLoopCount--;
  } /* while */
#endif
sleep(10);

ERROREXIT:
/* clean up */
ExitGraphicsMode();

} /* End Test2070DWU() */

