/*********************************************************************
*
* File: t2070mem.c
*
* Author: Mike Corry
* Date: 11/14/92
*
*  Test2070memio()    test fifo F to fifo D loop back
*                     then read data from memory
*
*       Global Variables:
*       G_iTestShorts[MAXSHORTPATS]
*
*
*********************************************************************/

/* #includes --------------------------------------------*/
#include <stdio.h>

#include "evaldiag.h"
#include "evalprot.h"
#include "iodvp.h"
#include "px2070.h"

extern G_wTestShorts[MAXSHORTPATS];


void Test2070FifoIO()
{
 int iTestCnt;
 unsigned short wReadVal,wWriteVal,iXSize, iYSize;
 iXSize = 64;
 iYSize = 1;

/* Test 1 write data to fifo F and read it back from fifo D */
/*SoftResetDVP(); */
ioOCSWriteDVP(0x10);
	/* halt sequencer */
	SeqHalt();

	/* setup datapath controls */
	GetHostPorts();

	/* Clear out the fifos */
	ResetFifo(ALL_FIFOS);

	/* Enable the fifos */
	EnableFifo(ALL_FIFOS);

	/* Read the fifo flags */
	/*wReadVal = ioRDTReadDVP(SIU_FCS); */
	/*printf("Fifo flags before write = %04x\n",wReadVal); */

	/* Disable all objects */
	OBReset(ALL_OBJECTS);

	/* Setup sequencer */
	ioRDTWriteDVP(SIU_SIM0,(IPU2_to_OB1 ));  /*Seq Inst 0 -- */


	/* Setup Object 0,1  (mcr, rfx, lsh, lsl, bsx, bsy, dec ) -- */
	/*    normal addressing, xup, ydown, RFX=1024, XS=48, YS=48, DEC=0, */


	Setup_OB (OBU1_MCR, (OB_Normal + /*OB_SSM*/ + OB_XBLT + OB_YBLT + OB_Copy_D),
		  iXSize, 0, 0,  iXSize, iYSize, 0);


	/* Enable sequencer start-- */
	ioRDTWriteDVP(i_SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

	/* Generate Newfield to start sequencer -- */
	SeqManStart();
	wReadVal = ioRDTReadDVP(SIU_FCS);
	/* write/read from memory port -- */

	for (iTestCnt=0;iTestCnt<64;iTestCnt++)
	  ioMDTShortWriteDVP(iTestCnt);

	/* setup datapath controls */
	GetHostPorts();

	for (iTestCnt=0;iTestCnt<64;iTestCnt++)
	 {
	  wReadVal = ioMDTShortReadDVP();
	  if (wReadVal != iTestCnt)
	   {
	    printf("ERROR fifo loop 1 test Expected %04x Actual %04x \n",
		    iTestCnt,wReadVal);
	   }
	 }
	for (iTestCnt=0;iTestCnt<64;iTestCnt++)
	  ioMDTShortWriteDVP(256-iTestCnt);
	/* setup datapath controls */
	GetHostPorts();

	for (iTestCnt=0;iTestCnt<64;iTestCnt++)
	 {
	  wReadVal = ioMDTShortReadDVP();
	  if (wReadVal != (256-iTestCnt))
	   {
	    printf("ERROR fifo loop 2 test Expected %04x Actual %04x \n",
		    iTestCnt,wReadVal);
	   }
	 }
	for (iTestCnt=0;iTestCnt<64;iTestCnt++)
	  ioMDTShortWriteDVP(0xaaaa);
	/* setup datapath controls */
	GetHostPorts();
	for (iTestCnt=0;iTestCnt<64;iTestCnt++)
	 {
	  wReadVal = ioMDTShortReadDVP();
	  if (wReadVal != 0xaaaa)
	   {
	    printf("ERROR fifo loop 3 test Expected %04x Actual %04x \n",
		    iTestCnt,wReadVal);
	   }
	 }
	for (iTestCnt=0;iTestCnt<64;iTestCnt++)
	  ioMDTShortWriteDVP(0x5555);
	/* setup datapath controls */
	GetHostPorts();
	for (iTestCnt=0;iTestCnt<64;iTestCnt++)
	 {
	  wReadVal = ioMDTShortReadDVP();
	  if (wReadVal != 0x5555)
	   {
	    printf("ERROR fifo loop 4 test Expected %04x Actual %04x \n",
		    iTestCnt,wReadVal);
	   }
	 }


	/* halt sequecer */
	SeqHalt();

/* -------END OF TEST ----------------------------------- */
ERROREXIT:
}


/**********************************************************
*
*       File Name:  T2070Mem.c
*
*       Module Abstract: This module verifies the integrity of
*               the 2070 memory port as well as the external ram
*               on the evalbrd.
*
*
*       Calling Sequence:
*       Test2070MemIO()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_wTestShorts[MAXSHORTPATS]
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void Test2070MemIO()
{
 int iTestCnt,iXSize, iYSize,iLoopCount;
 unsigned char bExpected;
 unsigned short wReadVal,wWriteVal,wRowCount,wColCount,wExpected;
 unsigned long dwReadVal,dwExpected;
 long lTimeCount;
 iXSize = 64;
 iYSize = 2;

/* Test 1 write data to fifo F  then OB0 and read it back from fifo D */

/* Do a  soft reset */
/* SoftReset(); */

/* halt sequencer */
SeqHalt();

/* setup datapath controls */
GetHostPorts();

/* Clear out the fifos */
ResetFifo(ALL_FIFOS);

/* Enable the fifos */
EnableFifo(ALL_FIFOS);

/* Read the fifo flags */
/*wReadVal = ioRDTReadDVP(SIU_FCS); */
/*printf("Fifo flags before write = %04x\n",wReadVal); */

/* Set up the MMU */
SetUpMMU();

/* Disable all objects */
OBReset(ALL_OBJECTS);

/* Setup sequencer */
ioRDTWriteDVP(SIU_SIM0,(IPU2_to_OB0 + offset_0)); /* Seq Inst 0 -- */

/* Setup Object (object,mcr, rfx, lsh, lsl, bsx, bsy, dec ) -- */
/*    normal addressing, xup, ydown, RFX=64, XS=64, YS=2, DEC=0, */

Setup_OB (OBU0_MCR, (0x00 + OB_Normal +OB_SSM +  OB_XBLT + OB_YBLT + OB_No_Copy),
	  iXSize, 0, 0,  iXSize, iYSize, 0);

/* Enable sequencer start-- */
ioRDTWriteDVP(SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

/* Generate Newfield to start sequencer -- */
SeqManStart();

/* write/read from memory port -- */

/* Make sure the fifo is ready */
lTimeCount = 0;
while (IsFifoFull(FIFO_F))
  {
  lTimeCount++;
  if (lTimeCount == TIMEOUT)
    {
    printf("TIMEOUT ERROR Fifos Not Responding\n");
    goto ERROREXIT;
    }
  }
for (iTestCnt=0;iTestCnt<(iXSize*iYSize);iTestCnt++)
  {
  ioMDTShortWriteDVP(iTestCnt |0x5540);
  iTestCnt++;
  ioMDTShortWriteDVP(iTestCnt |0x5540);
  iTestCnt++;
  ioMDTShortWriteDVP(iTestCnt |0xaa80);
  iTestCnt++;
  ioMDTShortWriteDVP(iTestCnt |0xaa80);
  }

/* Might need a delay here before halting */
/* Read the fifo flags */
wReadVal = ioRDTReadDVP(SIU_FCS);
/*printf("Fifo flags before read = %04x\n",wReadVal); */

/* halt sequencer */
SeqHalt();

/* set ob0 to read from memory */
Setup_OB (OBU0_MCR, (OB_Normal + OB_SSM + OB_XBLT + OB_YBLT + OB_No_Copy),
		  iXSize, 0, 0,  iXSize, iYSize, 0);

/* reprogram seqencer */
ioRDTWriteDVP(SIU_SIM0,(OB0_to_OP + offset_0)); /* Seq Inst 0 -- */

/* Enable sequencer start */
ioRDTWriteDVP(SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

/* Generate Newfield to start sequencer -- */
SeqManStart();

iTestCnt = lTimeCount =0;
while (iTestCnt < iXSize*iYSize)
  {
  lTimeCount++;
  if (lTimeCount == TIMEOUT)
    {
    printf("TIMEOUT ERROR Fifos Not Responding\n");
    goto ERROREXIT;
    }
  if (!IsFifoEmpty(FIFO_D))
    {
    lTimeCount = 0;
    wReadVal = ioMDTShortReadDVP();
    if (wReadVal != (iTestCnt|0x5540))
      {
      printf("ERROR memory read test Expected %04x Actual %04x \n",
	      iTestCnt|0x5540,wReadVal);
      }
    iTestCnt++;
    wReadVal = ioMDTShortReadDVP();
    if (wReadVal != (iTestCnt|0x5540))
      {
      printf("ERROR memory read test Expected %04x Actual %04x \n",
	      iTestCnt|0x5540,wReadVal);
      }
    iTestCnt++;
    wReadVal = ioMDTShortReadDVP();
    if (wReadVal != (iTestCnt|0xaa80))
      {
      printf("ERROR memory read test Expected %04x Actual %04x \n",
	      iTestCnt|0xaa80,wReadVal);
      }
    iTestCnt++;
    wReadVal = ioMDTShortReadDVP();
    if (wReadVal != (iTestCnt|0xaa80))
      {
      printf("ERROR memory read test Expected %04x Actual %04x \n",
	      iTestCnt|0xaa80,wReadVal);
      }
    iTestCnt++;
    } /* If fifo not empty */
  } /* While */

/* Read the fifo flags */
/*wReadVal = ioRDTReadDVP(SIU_FCS); */
/*printf("Fifo flags end of test = %04x\n",wReadVal); */

/****************************************************************
/* Now test the entire memory array with address dependent data */
/****************************************************************/

iXSize = 512;
iYSize = 512;

/* halt sequencer */
SeqHalt();

/* setup datapath controls */
GetHostPorts();

/* Clear out the fifos */
ResetFifo(ALL_FIFOS);

/* Enable the fifos */
EnableFifo(ALL_FIFOS);

/* Read the fifo flags */
/*wReadVal = ioRDTReadDVP(SIU_FCS); */
/*printf("Fifo flags before write = %04x\n",wReadVal); */

/* Set up the MMU */
SetUpMMU();

/* Disable all objects */
OBReset(ALL_OBJECTS);

/* Setup sequencer */
ioRDTWriteDVP(SIU_SIM0,(IPU2_to_OB0 + offset_0)); /* Seq Inst 0 -- */

/* Setup Object (object,mcr, rfx, lsh, lsl, bsx, bsy, dec ) -- */
/*    normal addressing, xup, ydown, RFX=1024, XS=1024, YS=1024, DEC=0, */

Setup_OB (OBU0_MCR, (OB_Normal +OB_SSM +  OB_XBLT + OB_YBLT + OB_No_Copy),
	  iXSize, 0, 0,  iXSize, iYSize, 0);

/* Enable sequencer start-- */
ioRDTWriteDVP(SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

/* Generate Newfield to start sequencer -- */
SeqManStart();

/* write to memory port -- */

printf("   Memory Address Test Writing Data\n");

lTimeCount = 0;
for (wRowCount = 0;wRowCount < iYSize;wRowCount++)
  {
  for (wColCount = 0;wColCount < iXSize;wColCount+=2)
    {
    /* While fifo F is full spin */
    while (IsFifoFull(FIFO_F))
      {
      /*printf("Fifo F full Address test Row = %04x Col = %04x\n", */
      /*                wRowCount,wColCount); */
      lTimeCount++;
      if (lTimeCount == TIMEOUT)
	{
	printf("TIMEOUT ERROR Fifos Not Responding\n");
	wColCount = iXSize;
	wRowCount = iYSize;
	goto ERROREXIT;
	}
      }
    ioMDTWriteDVP(((unsigned long)wColCount/2) | (((unsigned long)wRowCount)<<16));
    lTimeCount = 0;
    }  /* for ColCount */
  }  /* for RowCount */

/* Might need a delay here before halting */
/* Read the fifo flags */
wReadVal = ioRDTReadDVP(SIU_FCS);
/*printf("Fifo flags before read = %04x\n",wReadVal); */

/* halt sequecer */
SeqHalt();

/* set ob0 to read from memory */
Setup_OB (OBU0_MCR, (OB_Normal + OB_SSM + OB_XBLT + OB_YBLT + OB_No_Copy),
		  iXSize, 0, 0,  iXSize, iYSize, 0);

/* reprogram seqencer */
ioRDTWriteDVP(SIU_SIM0,(OB0_to_OP + offset_0)); /* Seq Inst 0 -- */

/* Enable sequencer start */
ioRDTWriteDVP(SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

/* Generate Newfield to start sequencer -- */
SeqManStart();

printf("   Memory Address Test Reading Data\n");

lTimeCount = 0;
/* Read back the data */
for (wRowCount = 0;wRowCount < iYSize;wRowCount++)
  {
  for (wColCount = 0;wColCount < iXSize;wColCount+=2)
    {
    /* If fifo D is empty spin */
    while (IsFifoEmpty(FIFO_D))
      {
      /*printf("Fifo D Empty Address test Row = %04x Col = %04x\n", */
      /*                wRowCount,wColCount); */
      lTimeCount++;
      if (lTimeCount == TIMEOUT)
	{
	printf("TIMEOUT ERROR Fifos Not Responding\n");
	wColCount = iXSize;
	wRowCount = iYSize;
	goto ERROREXIT;
	}
      }
    lTimeCount = 0;
    dwReadVal = ioMDTReadDVP();
    if (dwReadVal != (((unsigned long)wColCount/2) | (((unsigned long)wRowCount)<<16)))
      {
      printf("ERROR Memory Address Test Expected %08lx Actual %08lx \n",
	     (((unsigned long)wColCount/2) | (((unsigned long)wRowCount)<<16)) ,dwReadVal);
      }
    } /* For ColCount */
  } /* For RowCount */
#if(0)
/**************************************************************
/* Now test the entire memory array with test array data */
***************************************************************/

iXSize = 512;
iYSize = 512;
iTestCnt = 5;
if (kbhit())
  {
  getch();
  iTestCnt = MAXSHORTPATS;
  }

for (iLoopCount = 0;iLoopCount < iTestCnt;iLoopCount++)
  {
  /* Disable the ALU */
  ioRDTWriteDVP(VPU_MCR,ALU_Disable);
  UpdateGen();

  /* halt sequencer */
  SeqHalt();

  /* setup datapath controls */
  GetHostPorts();

  /* Clear out the fifos */
  ResetFifo(ALL_FIFOS);

  /* Enable the fifos */
  EnableFifo(ALL_FIFOS);

  /* Read the fifo flags */
  /*wReadVal = ioRDTReadDVP(SIU_FCS); */
  /*printf("Fifo flags before write = %04x\n",wReadVal); */

  /* Set up the MMU */
  SetUpMMU();

  /* Disable all objects */
  OBReset(ALL_OBJECTS);

  /* Setup sequencer */
  ioRDTWriteDVP(SIU_SIM0,(ALUE_to_OB0 + offset_0)); /* Seq Inst 0 -- */

  /* Setup Object (object,mcr, rfx, lsh, lsl, bsx, bsy, dec ) -- */
  /*    normal addressing, xup, ydown, RFX=1024, XS=1024, YS=1024, DEC=0, */

  Setup_OB (OBU0_MCR, (OB_Normal +OB_SSM +  OB_XBLT + OB_YBLT + OB_No_Copy),
	    iXSize, 0, 0,  iXSize, iYSize, 0);

  /* Setup the ALU A constant registers with the test array data */
  ioRDTWriteDVP(ALU_CAY,G_wTestShorts[iLoopCount]);
  ioRDTWriteDVP(ALU_CAU,G_wTestShorts[iLoopCount]);
  ioRDTWriteDVP(ALU_CAV,G_wTestShorts[iLoopCount]);

  /* Set up the ALU to pass constant reg A to fifo E */
  /* ALU MCR regs */
  ioRDTWriteDVP(ALU_MCR1,ALU_Asrc_Reg + ALU_Vout_Logic + ALU_Uout_Logic +
		ALU_Yout_Logic) ;
  ioRDTWriteDVP(ALU_MCR2,ALU_Asrc_Reg + ALU_Vout_Logic + ALU_Uout_Logic +
		ALU_Yout_Logic);

  /* ALU logic operation select */
  ioRDTWriteDVP(ALU_LOPY,ALU_PassA);
  ioRDTWriteDVP(ALU_LOPU,ALU_PassA);
  ioRDTWriteDVP(ALU_LOPV,ALU_PassA);
  UpdateGen();

  /* Enable the ALU */
  ioRDTWriteDVP(VPU_MCR,ALU_Enable);
  UpdateGen();


  /* Enable sequencer start-- */
  ioRDTWriteDVP(SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

  /* Generate Newfield to start sequencer -- */
  SeqManStart();


  printf("   Memory Data Test %d Writing Data\n",iLoopCount);

  /*wReadVal = ioRDTReadDVP(OBU0_MCR); */
  /*printf("wReadVal = %04x \n",wReadVal); */
  /* Spin here until write done */
  while ((ioRDTReadDVP(OBU0_MCR) & OPM_MASK))
    {
    /* spin */
    }

  /* halt sequencer */
  SeqHalt();

  /* set ob0 to read from memory */
  Setup_OB (OBU0_MCR, (OB_Normal + OB_SSM + OB_XBLT + OB_YBLT + OB_No_Copy),
		  iXSize, 0, 0,  iXSize, iYSize, 0);

  /* reprogram seqencer */
  ioRDTWriteDVP(SIU_SIM0,(OB0_to_OP + offset_0)); /* Seq Inst 0 -- */

  /* Enable sequencer start */
  ioRDTWriteDVP(SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

  /* Generate Newfield to start sequencer -- */
  SeqManStart();

  printf("   Memory Data Test %d Reading Data\n",iLoopCount);

  lTimeCount = 0;
  /* Read back the data */
  for (wRowCount = 0;wRowCount < iYSize;wRowCount++)
    {
    for (wColCount = 0;wColCount < iXSize;wColCount+=2)
      {
      /* If fifo D is empty spin */
      while (IsFifoEmpty(FIFO_D))
	{
	/*printf("Fifo D Empty Address test Row = %04x Col = %04x\n", */
	/*              wRowCount,wColCount); */
	lTimeCount++;
	if (lTimeCount == TIMEOUT)
	  {
	  printf("TIMEOUT ERROR Fifos Not Responding\n");
	  wColCount = iXSize;
	  wRowCount = iYSize;
	  goto ERROREXIT;
	  }
	}
      lTimeCount = 0;
      dwReadVal = ioMDTReadDVP();
      bExpected = (unsigned char) (G_wTestShorts[iLoopCount] &0xff);
      wExpected = (((unsigned short) bExpected) &0xff) | (((unsigned short) bExpected)<<8);
      dwExpected = (((unsigned long) wExpected) &0xffff) | (((unsigned long) wExpected)<<16);
      if (dwReadVal != dwExpected)
	{
	printf("ERROR Memory Data Test Expected %08lx Actual %08lx Row %d Col %d\n",
		dwExpected,dwReadVal,wRowCount,wColCount);
	}
      } /* For ColCount */
    } /* For RowCount */
  } /* For iLoopCount */
#endif
ERROREXIT:
} /* End T2070MemIo */














