/**********************************************************
*
*       File Name:  T2070Reg.c
*
*       Module Abstract: This module is the high level test routine
*               that enables the testing of the registers of the 2070.
*
*       Calling Sequence:
*       Test2070Regs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_wTestShorts[MAXSHORTPATS]
*       G_pvConfigArray[]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/* #includes --------------------------------------------*/
#include <stdio.h>

#include "evaldiag.h"
#include "evalprot.h"
#include "iodvp.h"
#include "px2070.h"


extern G_pvConfigArray[];
extern G_Px2070PortType;
/* Global test pattern array */
unsigned short G_wTestShorts[MAXSHORTPATS] = {0x0000,0xffff,0xaaaa,0x5555,
				0x0001,0x0002,0x0004,0x0008,
				0x0010,0x0020,0x0040,0x0080,
				0x0100,0x0200,0x0400,0x0800,
				0x1000,0x2000,0x4000,0x8000,
				0xfffe,0xfffd,0xfffb,0xfff7,
				0xffef,0xffdf,0xffbf,0xff7f,
				0xfeff,0xfdff,0xfbff,0xf7ff,
				0xefff,0xdfff,0xbfff,0x7fff,
				0};
unsigned short wTestResultsArray[MAX_SIU_INDX2];

void Test2070Regs()
{
/* Do a soft reset */
ioOCSWriteDVP(SW_RESET);
Test2070HiuRegs();
Test2070ViuRegs();
Test2070Ipu1Regs();
Test2070Ipu2Regs();
Test2070MmuRegs();
Test2070ObuRegs();
Test2070DwuRegs();
Test2070SiuRegs();
/* Do a soft reset */
ioOCSWriteDVP(SW_RESET);
} /* End Test2070Regs */
/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the HIU.
*
*       Calling Sequence:
*       Test2070HiuRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/*GS void was here */
int Test2070HiuRegs()
{
unsigned short wReadVal,wWriteVal,wCSUVal;
int i,iCurrentDVP;
PX2070Ports *pPX2070AddrStruct;

/* Test the CSU register of thi HIU. Since this is a read only */
/* register, all we can do is read it and test a few bits. */

/* The CSU value will vary dependent on the 2070 port selection */
/* so figure out which port. */
iCurrentDVP = ioGetCurrentDVP();
pPX2070AddrStruct = (PX2070Ports *)G_pvConfigArray[PX2070BASE];

ioOCSWriteDVP(0);
  wReadVal = ioCSUReadDVP() & HIU_CSU_MASK;


  /* Get the chip rev */

  wCSUVal = 0x3e;
  if (wReadVal != wCSUVal )
    {
    printf("HIU_CSU READ ERROR Expected %04x Actual %04x\n",wCSUVal,wReadVal);
    }
/* DBG and DRD registers aren't really testable so skip'em */

/* Test the OCS register */
for (i=0; i < MAXSHORTPATS; i++)
  {
  /* Get the test value and write it. */
  wWriteVal = G_wTestShorts[i] & HIU_OCS_MASK;
  ioOCSWriteDVP(wWriteVal);

  /* Is what you read what you wrote? */
  wReadVal = ioOCSReadDVP() & HIU_OCS_MASK;
  if (wReadVal != wWriteVal)
    {
    printf("HIU_OCS READ ERROR Expected %04x Actual %04x \n",wWriteVal,wReadVal);
    }
  } /* for */
/* Reset the HIU_OCS register */
ioOCSWriteDVP(0);

/* Can't generate interrupts yet so skip IRQ register test */

/* Test the HIU_RIN (index) register */
for (i=0; i < MAXSHORTPATS; i++)
  {

  /* Get the test value and write it. */
  wWriteVal = G_wTestShorts[i] & HIU_RIN_MASK;
  ioRINWriteDVP(wWriteVal);

  /* Is what you read what you wrote? */
  wReadVal = ioRINReadDVP() & HIU_RIN_MASK;
  if (wReadVal != wWriteVal)
    {
    printf("HIU_RIN READ ERROR Expected %04x Actual %04x \n",wWriteVal,wReadVal);
    }
  } /* for */

/* Test the HIU_ISU  register */
for (i=0; i < MAXSHORTPATS; i++)
  {

  /* Get the test value and write it. */
  wWriteVal = G_wTestShorts[i] & HIU_ISU_MASK;
  ioRDTWriteDVP(HIU_ISU,wWriteVal);

  /* Is what you read what you wrote? */
  wReadVal = ioRDTReadDVP(HIU_ISU) & HIU_ISU_MASK;
  if (wReadVal != wWriteVal)
    {
    printf("HIU_ISU READ ERROR Expected %04x Actual %04x \n",wWriteVal,wReadVal);
    }
  } /* for */
/* Reset all registers */
ioOCSWriteDVP(SW_RESET);
ioOCSWriteDVP(0);
} /* End Test2070HiuRegs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the VIU.
*
*       Calling Sequence:
*       Test2070ViuRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/* GS void was here */
int Test2070ViuRegs()
{
int iTestArrayIndex;
unsigned short wWriteVal,wReadVal,wIndex;
unsigned short wMaskArray[MAX_VIU_INDX1] = {VIU_MCR1_MASK,VIU_MCR2_MASK,
					     VIU_DPC1_MASK,VIU_DPC2_MASK,
					     VIU_WDT_MASK};

/* Do an address dependent test with out auto increment */

/* Write the data */
for (wWriteVal = VIU_INDEX_1; wWriteVal < VIU_INDEX_1 + MAX_VIU_INDX1;wWriteVal++)
  ioRDTWriteDVP(wWriteVal,(wWriteVal & wMaskArray[wWriteVal - VIU_INDEX_1]));

/* Post 'em */
UpdateGen();

/* Read the data back and test it */
for (wWriteVal = VIU_INDEX_1; wWriteVal < VIU_INDEX_1 + MAX_VIU_INDX1;wWriteVal++)
  {
  wReadVal = ioRDTReadDVP(wWriteVal) & wMaskArray[wWriteVal - VIU_INDEX_1];
  if (wReadVal != (wWriteVal & wMaskArray[wWriteVal - VIU_INDEX_1]))
    {
    printf("VIU READ ERROR Expected %04x Actual %04x \n",wWriteVal & wMaskArray[wWriteVal - VIU_INDEX_1],wReadVal);
    }
  } /* for wWriteVal */

/* Test each register in the VIU with the test array */

/* For each register */
for (wIndex = VIU_INDEX_1; wIndex < VIU_INDEX_1 + MAX_VIU_INDX1;wIndex++)
  {
  /* Write the contents of the test array and test it. */
  for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++)
    {
    wWriteVal = G_wTestShorts[iTestArrayIndex];
    ioRDTWriteDVP(wIndex,wWriteVal & wMaskArray[wIndex - VIU_INDEX_1]);
    UpdateGen();
    wReadVal = ioRDTReadDVP(wIndex) & wMaskArray[wIndex - VIU_INDEX_1];
    if (wReadVal != (wWriteVal & wMaskArray[wIndex - VIU_INDEX_1]))
      {
      printf("VIU READ ERROR Index %04x Expected %04x Actual %04x \n",
	   wIndex,wWriteVal & wMaskArray[wIndex - VIU_INDEX_1],wReadVal);
      }
    } /* for iTestIndex */
  } /* for wIndex */


} /* End Test2070ViuRegs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the VSU.
*
*       Calling Sequence:
*       Test2070VsuRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void Test2070VsuRegs()
{
int iTestArrayIndex;
unsigned short wWriteVal,wReadVal,wIndex;
unsigned short wMaskArray[MAX_VSU_INDX1] = {VSU_HSW_MASK,VSU_HAD_MASK,
					     VSU_HAP_MASK,VSU_HP_MASK,
					     VSU_VSW_MASK,VSU_VAD_MASK,
					     VSU_VAP_MASK,VSU_VP_MASK};
/* Do an address dependent test with out auto increment */

/* Write the data */
for (wWriteVal = VSU_INDEX_1; wWriteVal < VSU_INDEX_1 + MAX_VSU_INDX1;wWriteVal++)
  ioRDTWriteDVP(wWriteVal,wWriteVal);

/* Post 'em */
UpdateGen();

/* Read the data back and test it */
for (wWriteVal = VSU_INDEX_1; wWriteVal < VSU_INDEX_1 + MAX_VSU_INDX1;wWriteVal++)
  {
  wReadVal = ioRDTReadDVP(wWriteVal) & wMaskArray[wWriteVal - VSU_INDEX_1];
  if (wReadVal != (wWriteVal & wMaskArray[wWriteVal - VSU_INDEX_1]))
    {
    printf("VSU READ ERROR Expected %04x Actual %04x \n",
	   wWriteVal & wMaskArray[wWriteVal - VSU_INDEX_1],wReadVal);
    }
  } /* for wWriteVal */

/* Test each register in the VSU with the test array */

/* For each register */
for (wIndex = VSU_INDEX_1; wIndex < VSU_INDEX_1 + MAX_VSU_INDX1;wIndex++)
  {
  /* Write the contents of the test array and test it. */
  for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++)
    {
    wWriteVal = G_wTestShorts[iTestArrayIndex];
    ioRDTWriteDVP(wIndex,wWriteVal);
    /* Post 'em */
    UpdateGen();
    wReadVal = ioRDTReadDVP(wIndex) & wMaskArray[wIndex - VSU_INDEX_1];
    if (wReadVal != (wWriteVal & wMaskArray[wIndex - VSU_INDEX_1]))
      {
      printf("VSU READ ERROR Index %04x Expected %04x Actual %04x \n",
	     wIndex,wWriteVal & wMaskArray[wIndex - VSU_INDEX_1],wReadVal);
      }
    } /* for iTestIndex */
  } /* for wIndex */


} /* End Test2070VsuRegs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the VPU.
*
*       Calling Sequence:
*       Test2070VpuRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void Test2070VpuRegs()
{
int iTestArrayIndex;
unsigned short wWriteVal,wReadVal,wIndex;
unsigned short wMaskArray[MAX_VPU_INDX1] = {VPU_MCR_MASK};

/* Do an address dependent test with out auto increment */

/* Write the data */
for (wWriteVal = VPU_INDEX_1; wWriteVal < VPU_INDEX_1 + MAX_VPU_INDX1;wWriteVal++)
  ioRDTWriteDVP(wWriteVal,wWriteVal);

/* Post 'em */
UpdateGen();

/* Read the data back and test it */
for (wWriteVal = VPU_INDEX_1; wWriteVal < VPU_INDEX_1 + MAX_VPU_INDX1;wWriteVal++)
  {
  wReadVal = ioRDTReadDVP(wWriteVal) & wMaskArray[0];
  if (wReadVal != (wWriteVal & wMaskArray[0]))
    {
    printf("VPU READ ERROR Expected %04x Actual %04x \n",
	   wWriteVal & wMaskArray[0],wReadVal);
    }
  } /* for wWriteVal */

/* Test each register in the VPU with the test array */

/* For each register */
for (wIndex = VPU_INDEX_1; wIndex < VPU_INDEX_1 + MAX_VPU_INDX1;wIndex++)
  {
  /* Write the contents of the test array and test it. */
  for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++)
    {
    wWriteVal = G_wTestShorts[iTestArrayIndex];
    ioRDTWriteDVP(wIndex,wWriteVal);
    /* Post 'em */
    UpdateGen();
    wReadVal = ioRDTReadDVP(wIndex) & wMaskArray[0];
    if (wReadVal != (wWriteVal & wMaskArray[0]))
      {
      printf("VPU READ ERROR Index %04x Expected %04x Actual %04x \n",
	      wIndex,wWriteVal & wMaskArray[0],wReadVal);
      }
    } /* for iTestIndex */
  } /* for wIndex */


} /* End Test2070VpuRegs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the IPU1.
*
*       Calling Sequence:
*       Test2070Ipu1Regs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/* GS void was here */
int Test2070Ipu1Regs()
{
int iTestArrayIndex,iIndexCount,i;
int iMaskIndexA=0,iMaskIndexB=0,iMaskIndexC=0,iMaskIndexD=0;
unsigned short wWriteVal,wReadVal,wIndex;
int iMaxArray[4] = {MAX_IPU1_INDX1-3,
		   MAX_IPU1_INDX2,
		   MAX_IPU1_INDX3,
		   MAX_IPU1_INDX4};
unsigned short wIndexArray[4] = {IPU1_INDEX_1 + 3,
				  IPU1_INDEX_2,
				  IPU1_INDEX_3,
				  IPU1_INDEX_4};
unsigned char bLutInArray[MAX_IPU1_LUT];
unsigned char bLutOutArray[MAX_IPU1_LUT] ={0};
unsigned short wMaskArray[MAX_IPU1_INDX1-3 + MAX_IPU1_INDX3 + MAX_IPU1_INDX4] =
			  {/*IPU1_PIX_MASK,IPU1_LIC_MASK,IPU1_FLC_MASK,*/
			   IPU1_LIR_MASK,IPU1_FIR_MASK,/*IPU1_LRB_MASK,
			   IPU1_LRD_MASK,*/IPU1_MCR1_MASK,IPU1_XBF1_MASK,
			   IPU1_XBI1_MASK,IPU1_XEI1_MASK,IPU1_XSF1_MASK,
			   IPU1_XSI1_MASK,IPU1_YBF1_MASK,IPU1_YBI1_MASK,
			   IPU1_YEI1_MASK,IPU1_YSF1_MASK,IPU1_YSI1_MASK,
			   IPU1_KFC1_MASK,IPU1_MMY1_MASK,IPU1_MMU1_MASK,
			   IPU1_MMV1_MASK,IPU1_MCR2_MASK,IPU1_XBF2_MASK,
			   IPU1_XBI2_MASK,IPU1_XEI2_MASK,IPU1_XSF2_MASK,
			   IPU1_XSI2_MASK,IPU1_YBF2_MASK,IPU1_YBI2_MASK,
			   IPU1_YEI2_MASK,IPU1_YSF2_MASK,IPU1_YSI2_MASK,
			   IPU1_KFC2_MASK,IPU1_MMY2_MASK,IPU1_MMU2_MASK,
			   IPU1_MMV2_MASK};
/* Setup the VIU to source a clock  for ipu1 */
ioRDTWriteDVP(VIU_DPC1,IPU1_from_OP + IPU2_from_Host + OPU_to_Host);
ioRDTWriteDVP(VIU_DPC2,IPU1_from_OP + IPU2_from_Host + OPU_to_Host);

/* Test each of the four index bases of IPU1 */
for (iIndexCount = 0;iIndexCount < 4;iIndexCount++)
  {
  /* If this is the LUT index (1) skip it */
  if (iIndexCount == 1) continue;

  /* Do an address dependent test with out auto increment */

  /* Write the data */
  for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wWriteVal++)
    {
    ioRDTWriteDVP(wWriteVal,wWriteVal & wMaskArray[iMaskIndexA]);
    iMaskIndexA++;
    }

  /* Post 'em */
  UpdateGen();

  /* Read the data back and test it */
  for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wWriteVal++)
    {
    wReadVal = ioRDTReadDVP(wWriteVal) & wMaskArray[iMaskIndexD];
    if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexD]))
      {
      printf("IPU1 READ ERROR Expected %04x Actual %04x \n",
	      wWriteVal & wMaskArray[iMaskIndexD],wReadVal);
      }
    iMaskIndexD++;
    } /* for wWriteVal */

  /* Test each register in the IPU1 with the test array */

  /* For each register */
  for (wIndex = wIndexArray[iIndexCount];
       wIndex < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wIndex++)
    {
    /* Write the contents of the test array and test it. */
    /*for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++) */
    for (iTestArrayIndex = 0;iTestArrayIndex < 25;iTestArrayIndex++)
      {
      wWriteVal = G_wTestShorts[iTestArrayIndex];
      ioRDTWriteDVP(wIndex,wWriteVal & wMaskArray[iMaskIndexB]);
      /* Post 'em */
      UpdateGen();
      wReadVal = ioRDTReadDVP(wIndex) & wMaskArray[iMaskIndexB];
      if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexB]))
	{
	printf("IPU1 READ ERROR Index %04x Expected %04x Actual %04x \n",
		wIndex,wWriteVal & wMaskArray[iMaskIndexB],wReadVal);
	}
      } /* for iTestIndex */
    iMaskIndexB++;
    } /* for wIndex */


  } /* for iIndexCount */

/* Test the gamma lut in IPU1 */

/* Build the test data */
for (i = 0;i < MAX_IPU1_LUT;i++)
  {
  bLutInArray[i] = i/3;
  }

/* Write the data */
if (ioLutWriteDVP(0,bLutInArray,MAX_IPU1_LUT))
  printf("ERROR Unable to load IPU1 LUT\n");
else
  {
  /* Read the data */
  if (ioLutReadDVP(0,bLutOutArray,MAX_IPU1_LUT))
    printf("ERROR Unable to read IPU1 LUT\n");
  else
    {
    /* Is what you read what you wrote? */
    for (i = 0;i < MAX_IPU1_LUT;i++)
      {
      if (bLutInArray[i] != bLutOutArray[i])
	{
	printf("IPU1 LUT ERROR Index %02x Expected %02x Actual %02x\n",i,bLutInArray[i],bLutOutArray[i]);
	}
      } /* for i */
    } /* else */
  } /* else  */
} /* End Test2070Ipu1Regs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the IPU2.
*
*       Calling Sequence:
*       Test2070Ipu2Regs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/*Gs void was ehre */
int Test2070Ipu2Regs()
{
int iTestArrayIndex,iIndexCount;
int iMaskIndexA=0,iMaskIndexB=0,iMaskIndexC=0;
unsigned short wMaskArray[MAX_IPU2_INDX1-3 + MAX_IPU2_INDX2 + MAX_IPU2_INDX3] =
			  {/*IPU2_PIX_MASK,IPU2_LIC_MASK,IPU2_FLC_MASK,*/
			   IPU2_LIR_MASK,IPU2_FIR_MASK,IPU2_MCR1_MASK,
			   IPU2_XBI1_MASK,IPU2_XEI1_MASK,IPU2_YBI1_MASK,
			   IPU2_YEI1_MASK,IPU2_MCR2_MASK,IPU2_XBI2_MASK,
			   IPU2_XEI2_MASK,IPU2_YBI2_MASK,IPU2_YEI2_MASK};

unsigned short wWriteVal,wReadVal,wIndex;
int iMaxArray[3] = {MAX_IPU2_INDX1-3,
		   MAX_IPU2_INDX2,
		   MAX_IPU2_INDX3};
unsigned short wIndexArray[3] = {IPU2_INDEX_1+3,
				  IPU2_INDEX_2,
				  IPU2_INDEX_3};

/* Test each of the three index bases of IPU2 */
for (iIndexCount = 0;iIndexCount < 3;iIndexCount++)
 {
  /* Do an address dependent test with out auto increment */

  /* Write the data */
  for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wWriteVal++)
    {
    /* Skip over unwed addresses */
    if ((iIndexCount != 0) && (((wWriteVal & 0xf) == 1) ||
			       ((wWriteVal & 0xf) == 4) ||
			       ((wWriteVal & 0xf) == 5) ||
			       ((wWriteVal & 0xf) == 6))) continue;
    ioRDTWriteDVP(wWriteVal,wWriteVal & wMaskArray[iMaskIndexA]);
    iMaskIndexA++;
    }

  /* Post 'em */
  UpdateGen();

  /*iMaskIndexA=0; */
  /* Read the data back and test it */
  for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wWriteVal++)
    {
    /* Skip over unwed addresses */
    if ((iIndexCount != 0) && (((wWriteVal & 0xf) == 1) ||
			       ((wWriteVal & 0xf) == 4) ||
			       ((wWriteVal & 0xf) == 5) ||
			       ((wWriteVal & 0xf) == 6))) continue;
    wReadVal = ioRDTReadDVP(wWriteVal) & wMaskArray[iMaskIndexC];
    if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexC]))
      {
      printf("IPU2 READ ERROR Expected %04x Actual %04x \n",
	      wWriteVal & wMaskArray[iMaskIndexA],wReadVal);
      }
    iMaskIndexC++;
    } /* for wWriteVal */

  /* Test each register in the IPU2 with the test array */

  /* For each register */
  for (wIndex = wIndexArray[iIndexCount];
       wIndex < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wIndex++)
    {
    /* Skip over unwed addresses */
    if ((iIndexCount != 0) && (((wIndex & 0xf) == 1) ||
			       ((wIndex & 0xf) == 4) ||
			       ((wIndex & 0xf) == 5) ||
			       ((wIndex & 0xf) == 6))) continue;

    /* Write the contents of the test array and test it. */
    for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++)
      {
      wWriteVal = G_wTestShorts[iTestArrayIndex];
      ioRDTWriteDVP(wIndex,wWriteVal & wMaskArray[iMaskIndexB]);
      UpdateGen();
      wReadVal = ioRDTReadDVP(wIndex) & wMaskArray[iMaskIndexB];
      if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexB]))
	{
	printf("IPU2 READ ERROR Index %04x Expected %04x Actual %04x \n",
		wIndex,wWriteVal & wMaskArray[iMaskIndexB],wReadVal);
	}
      } /* for iTestIndex */
    iMaskIndexB++;
    } /* for wIndex */
  } /* for iIndexCount */
} /* End Test2070Ipu2Regs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the SIU.
*
*       Calling Sequence:
*       Test2070SiuRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/* GS void was here */
int Test2070SiuRegs()
{
int iTestArrayIndex,iIndexCount;
int iMaskIndexA=0,iMaskIndexB=0,iMaskIndexC=0;
unsigned short wWriteVal,wReadVal,wIndex;
int iMaxArray[2] = {MAX_SIU_INDX1,
		   MAX_SIU_INDX2};
unsigned short wIndexArray[2] = {SIU_INDEX_1-2,
				  SIU_INDEX_2};
unsigned short wMaskArray[MAX_SIU_INDX1 + MAX_SIU_INDX2] =
			  {SIU_MCR_MASK,SIU_FCS_MASK,SIU_FOU_MASK,
			   SIU_SIM0_MASK,SIU_SIM1_MASK,SIU_SIM2_MASK,
			   SIU_SIM3_MASK,SIU_SIM4_MASK,SIU_SIM5_MASK,
			   SIU_SIM6_MASK,SIU_SIM7_MASK,SIU_SIM8_MASK,
			   SIU_SIM9_MASK,SIU_SIM10_MASK,SIU_SIM11_MASK,
			   SIU_SIM12_MASK,SIU_SIM13_MASK,SIU_SIM14_MASK,
			   SIU_SIM15_MASK,SIU_SIM16_MASK,SIU_SIM17_MASK,
			   SIU_SIM18_MASK,SIU_SIM19_MASK,SIU_SIM20_MASK,
			   SIU_SIM21_MASK,SIU_SIM22_MASK,SIU_SIM23_MASK,
			   SIU_SIM24_MASK,SIU_SIM25_MASK,SIU_SIM26_MASK,
			   SIU_SIM27_MASK,SIU_SIM28_MASK,SIU_SIM29_MASK,
			   SIU_SIM30_MASK,SIU_SIM31_MASK};

  /* Test each of the two index bases of SIU */
  for (iIndexCount = 0;iIndexCount < 2;iIndexCount++)
  {
    /* Do an address dependent test with out auto increment */

    /* Write the data */
    for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wWriteVal++)
      ioRDTWriteDVP(wWriteVal,wWriteVal);

    /* Post 'em */
    UpdateGen();

    /* Read the data back and test it */
    for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wWriteVal++)
    {
      wReadVal = ioRDTReadDVP(wWriteVal) & wMaskArray[iMaskIndexA];
      if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexA]))
      {
	printf("SIU READ ERROR Expected %04x Actual %04x \n",
	      wWriteVal & wMaskArray[iMaskIndexA],wReadVal);
      }
      iMaskIndexA++;
    } /* for wWriteVal */

    /* Test each register in the SIU with the test array */

    /* For each register */
    for (wIndex = wIndexArray[iIndexCount];
       wIndex < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wIndex++)
    {
      /* Write the contents of the test array and test it. */
      for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++)
      /*for (iTestArrayIndex = 0;iTestArrayIndex < 25;iTestArrayIndex++) */
      {
	wWriteVal = G_wTestShorts[iTestArrayIndex];
	ioRDTWriteDVP(wIndex,wWriteVal);
	/* Post 'em */
	UpdateGen();

	wReadVal = ioRDTReadDVP(wIndex) & wMaskArray[iMaskIndexB];
	if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexB]))
	{
	  printf("SIU READ ERROR Index %04x Expected %04x Actual %04x \n",
		wIndex,wWriteVal & wMaskArray[iMaskIndexB],wReadVal);
	}
      } /* for iTestIndex */
      iMaskIndexB++;
    } /* for wIndex */


  iMaskIndexC++;
  } /* for iIndexCount */
/* Do a software reset */
/*ioOCSWriteDVP(SW_RESET); */
} /* End Test2070SiuRegs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the ALU.
*
*       Calling Sequence:
*       Test2070AluRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void Test2070AluRegs()
{
int iTestArrayIndex;
int iMaskIndex=0;
unsigned short wMaskArray[MAX_ALU_INDX1] =
			  {ALU_MCR1_MASK,ALU_MCR2_MASK,ALU_TOP_MASK,
			   ALU_AV_MASK,ALU_LOPY_MASK,ALU_LOPU_MASK,
			   ALU_LOPV_MASK,ALU_CAY_MASK,ALU_CAU_MASK,
			   ALU_CAV_MASK,ALU_CBY_MASK,ALU_CBU_MASK,
			   ALU_CBV_MASK,ALU_CCY_MASK,ALU_CCU_MASK,
			   ALU_CCV_MASK};
unsigned short wWriteVal,wReadVal,wIndex;
/* Do an address dependent test with out auto increment */

/* Write the data */
for (wWriteVal = ALU_INDEX_1; wWriteVal < ALU_INDEX_1 + MAX_ALU_INDX1;wWriteVal++)
  ioRDTWriteDVP(wWriteVal,wWriteVal & wMaskArray[iMaskIndex]);

  /* Post 'em */
  UpdateGen();

/* Read the data back and test it */
for (wWriteVal = ALU_INDEX_1; wWriteVal < ALU_INDEX_1 + MAX_ALU_INDX1;wWriteVal++)
  {
  wReadVal = ioRDTReadDVP(wWriteVal) & wMaskArray[iMaskIndex];
  if (wReadVal != (wWriteVal & wMaskArray[iMaskIndex]))
    {
    printf("ALU READ ERROR Expected %04x Actual %04x \n",
	    wWriteVal & wMaskArray[iMaskIndex],wReadVal);
    }
  iMaskIndex++;
  } /* for wWriteVal */

/* Test each register in the ALU with the test array */

/* For each register */
iMaskIndex=0;
for (wIndex = ALU_INDEX_1; wIndex < ALU_INDEX_1 + MAX_ALU_INDX1;wIndex++)
  {
  /* Write the contents of the test array and test it. */
  /*for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++) */
  for (iTestArrayIndex = 0;iTestArrayIndex < 25;iTestArrayIndex++)
    {
    wWriteVal = G_wTestShorts[iTestArrayIndex];
    ioRDTWriteDVP(wIndex,wWriteVal & wMaskArray[iMaskIndex]);
    /* Post 'em */
    UpdateGen();

    wReadVal = ioRDTReadDVP(wIndex) & wMaskArray[iMaskIndex];
    if (wReadVal != (wWriteVal & wMaskArray[iMaskIndex]))
      {
      printf("ALU READ ERROR Index %04x Expected %04x Actual %04x \n",
	      wIndex,wWriteVal & wMaskArray[iMaskIndex],wReadVal);
      }
    } /* for iTestIndex */
  iMaskIndex++;
  } /* for wIndex */


} /* End Test2070AluRegs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the OPU.
*
*       Calling Sequence:
*       Test2070OpuRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void Test2070OpuRegs()
{
int iTestArrayIndex,iIndexCount;
int iMaskIndexA=0,iMaskIndexB=0;
unsigned short wWriteVal,wReadVal,wIndex;
int iMaxArray[2] = {MAX_OPU_INDX1,
		   MAX_OPU_INDX2};
unsigned short wIndexArray[2] = {OPU_INDEX_1,
				  OPU_INDEX_2};
unsigned short wMaskArray[MAX_OPU_INDX1 + MAX_OPU_INDX2] =
			  {OPU_MCR1_MASK,OPU_XBI1_MASK,OPU_XEI1_MASK,
			  OPU_YBI1_MASK,OPU_YEI1_MASK,OPU_MCR2_MASK,
			  OPU_XBI2_MASK,OPU_XEI2_MASK,OPU_YBI2_MASK,
			  OPU_YEI2_MASK};

/* Test each of the two index bases of OPU */
for (iIndexCount = 0;iIndexCount < 2;iIndexCount++)
 {
  /* Do an address dependent test with out auto increment */

  /* Write the data */
  for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wWriteVal++)
    {
    /* Skip over unwed addresses */
    if (((wWriteVal & 0xf) == 1) ||
			       ((wWriteVal & 0xf) == 4) ||
			       ((wWriteVal & 0xf) == 5) ||
			       ((wWriteVal & 0xf) == 6)) continue;
    ioRDTWriteDVP(wWriteVal,wWriteVal);
    }
  /* Post 'em */
  UpdateGen();

  /* Read the data back and test it */
  for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wWriteVal++)
    {
    /* Skip over unwed addresses */
    if (((wWriteVal & 0xf) == 1) ||
			       ((wWriteVal & 0xf) == 4) ||
			       ((wWriteVal & 0xf) == 5) ||
			       ((wWriteVal & 0xf) == 6)) continue;
    wReadVal = ioRDTReadDVP(wWriteVal) & wMaskArray[iMaskIndexA];
    if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexA]))
      {
      printf("OPU READ ERROR Expected %04x Actual %04x \n",
	     wWriteVal & wMaskArray[iMaskIndexA],wReadVal);
      }
    iMaskIndexA++;
    } /* for wWriteVal */

  /* Test each register in the OPU with the test array */

  /* For each register */
  for (wIndex = wIndexArray[iIndexCount];
       wIndex < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wIndex++)
    {
    /* Skip over unwed addresses */
    if (((wIndex & 0xf) == 1) ||
			       ((wIndex & 0xf) == 4) ||
			       ((wIndex & 0xf) == 5) ||
			       ((wIndex & 0xf) == 6)) continue;
    /* Write the contents of the test array and test it. */
    for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++)
      {
      wWriteVal = G_wTestShorts[iTestArrayIndex];
      ioRDTWriteDVP(wIndex,wWriteVal);
      /* Post 'em */
      UpdateGen();
      wReadVal = ioRDTReadDVP(wIndex) & wMaskArray[iMaskIndexB];
      if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexB]))
	{
	printf("OPU READ ERROR Index %04x Expected %04x Actual %04x \n",
	       wIndex,wWriteVal & wMaskArray[iMaskIndexB],wReadVal);
	}
      } /* for iTestIndex */
    iMaskIndexB++;
    } /* for wIndex */
  } /* for iIndexCount */
} /* End Test2070OpuRegs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the MMU.
*
*       Calling Sequence:
*       Test2070MmuRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/* GS void was here */
int Test2070MmuRegs()
{
int iTestArrayIndex;
unsigned short wWriteVal,wReadVal,wIndex;
/* Do an address dependent test with out auto increment */

/* Write the data */
for (wWriteVal = MMU_INDEX_1; wWriteVal < MMU_INDEX_1 + MAX_MMU_INDX1;wWriteVal++)
  ioRDTWriteDVP(wWriteVal,wWriteVal);

/* Read the data back and test it */
for (wWriteVal = MMU_INDEX_1; wWriteVal < MMU_INDEX_1 + MAX_MMU_INDX1;wWriteVal++)
  {
  wReadVal = ioRDTReadDVP(wWriteVal) & MMU_MCR_MASK;
  if (wReadVal != (wWriteVal & MMU_MCR_MASK))
    {
    printf("MMU READ ERROR Expected %04x Actual %04x \n",
	    wWriteVal & MMU_MCR_MASK,wReadVal);
    }
  } /* for wWriteVal */

/* Test each register in the MMU with the test array */

/* For each register */
for (wIndex = MMU_INDEX_1; wIndex < MMU_INDEX_1 + MAX_MMU_INDX1;wIndex++)
  {
  /* Write the contents of the test array and test it. */
  for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++)
    {
    wWriteVal = G_wTestShorts[iTestArrayIndex];
    ioRDTWriteDVP(wIndex,wWriteVal);
    wReadVal = ioRDTReadDVP(wIndex) & MMU_MCR_MASK;
    if (wReadVal != (wWriteVal & MMU_MCR_MASK))
      {
      printf("MMU READ ERROR Index %04x Expected %04x Actual %04x \n",
	      wIndex,wWriteVal & MMU_MCR_MASK,wReadVal);
      }
    } /* for iTestIndex */
  } /* for wIndex */
} /* End Test2070MmuRegs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the OBU.
*
*       Calling Sequence:
*       Test2070ObuRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/* Void was here gs */
int Test2070ObuRegs()
{
int iTestArrayIndex,iIndexCount;
int iMaskIndexA=0,iMaskIndexB=0,iMaskIndexC=0;
unsigned short wWriteVal,wReadVal,wIndex;
int iMaxArray[1] = {MAX_OBU_INDX1};
unsigned short wIndexArray[8] = {OBU0_INDEX_1,OBU1_INDEX_1,
				  OBU2_INDEX_1,OBU3_INDEX_1,
				  OBU4_INDEX_1,OBU5_INDEX_1,
				  OBU6_INDEX_1,OBU7_INDEX_1};
unsigned short wMaskArray[MAX_OBU_INDX1] =
			    {OBU_MCR_MASK,OBU_RFX_MASK,OBU_LSL_MASK,
			     OBU_LSH_MASK,OBU_BSX_MASK,OBU_BSY_MASK,
			     OBU_DEC_MASK};

  /* Test each of the seven index bases of OBU */
  for (iIndexCount = 0;iIndexCount < 8;iIndexCount++)
  {
    iMaskIndexA = iMaskIndexB = iMaskIndexC=0;
    /* Do an address dependent test with out auto increment */

    /* Write the data */
    for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[0];
       wWriteVal++)
      ioRDTWriteDVP(wWriteVal,wWriteVal);
    /*Post 'em */
    UpdateGen();
    /* Read the data back and test it */
    for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[0];
       wWriteVal++)
    {
      wReadVal = ioRDTReadDVP(wWriteVal) & wMaskArray[iMaskIndexA];
      if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexA]))
      {
	printf("OBU READ ERROR Expected %04x Actual %04x \n",
	       wWriteVal & wMaskArray[iMaskIndexA],wReadVal);
      }
      iMaskIndexA++;
    } /* for wWriteVal */

    /* Test each register in the OBU with the test array */

    /* For each register */
    for (wIndex = wIndexArray[iIndexCount];
       wIndex < wIndexArray[iIndexCount] + iMaxArray[0];
       wIndex++)
    {
      /* Write the contents of the test array and test it. */
      for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++)
      {
	wWriteVal = G_wTestShorts[iTestArrayIndex];
	ioRDTWriteDVP(wIndex,wWriteVal);
	/*Post 'em */
	UpdateGen();
	wReadVal = ioRDTReadDVP(wIndex) & wMaskArray[iMaskIndexB];
	if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexB]))
	{
	  printf("OBU READ ERROR Index %04x Expected %04x Actual %04x \n",
		wIndex,wWriteVal & wMaskArray[iMaskIndexB],wReadVal);
	}
      } /* for iTestIndex */
      iMaskIndexB++;
    } /* for wIndex */
  }

} /* End Test2070ObuRegs */

/**********************************************************
*
*       File Name:  Test2070.c
*
*       Module Abstract: This module performs the diagnostic
*               testing of the registers in the DWU.
*
*       Calling Sequence:
*       Test2070DwuRegs()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       G_iTestPats[MAXPATTERNS]
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/3/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
/* GS Void was here */
int Test2070DwuRegs()
{
int iTestArrayIndex,iIndexCount;
int iMaskIndexA,iMaskIndexB,iMaskIndexC;
unsigned short wWriteVal,wReadVal,wIndex;
int iMaxArray[5] = {MAX_DWU_INDX1,
		    MAX_DWU_INDX2,
		    MAX_DWU_INDX2,
		    MAX_DWU_INDX2,
		    MAX_DWU_INDX2,};
unsigned short wIndexArray[5] = {DWU_INDEX_1,
				  DWU0_INDEX_2,
				  DWU1_INDEX_2,
				  DWU2_INDEX_2,
				  DWU3_INDEX_2};
unsigned short wMaskArray[MAX_DWU_INDX1 + MAX_DWU_INDX2] =
				{DWU_MCR_MASK,DWU_HCR_MASK,
				 DWU_DZF_MASK,DWU_RFX_MASK,
				 DWU_LSL_MASK,DWU_LSH_MASK,
				 DWU_WSX_MASK,DWU_WSY_MASK,
				 DWU_DSX_MASK,DWU_DSY_MASK};

/* Test each of the five index bases of DWU */
  for (iIndexCount = 0;iIndexCount < 5;iIndexCount++)
  {
    if (iIndexCount == 0)
      iMaskIndexA = iMaskIndexB = iMaskIndexC=0;
    else
     iMaskIndexA = iMaskIndexB = iMaskIndexC=MAX_DWU_INDX1;
    /* Do an address dependent test with out auto increment */

    /* Write the data */
    for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wWriteVal++)
      ioRDTWriteDVP(wWriteVal,wWriteVal);
    /*Post 'em */
    UpdateGen();

    /* Read the data back and test it */
    for (wWriteVal = wIndexArray[iIndexCount];
       wWriteVal < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wWriteVal++)
    {
      wReadVal = ioRDTReadDVP(wWriteVal) & wMaskArray[iMaskIndexA];
      if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexA]))
      {
	printf("DWU READ ERROR Expected %04x Actual %04x \n",
	      wWriteVal & wMaskArray[iMaskIndexA],wReadVal);
      }
      iMaskIndexA++;
    } /* for wWriteVal */

    /* Test each register in the DWU with the test array */

    /* For each register */
    for (wIndex = wIndexArray[iIndexCount];
       wIndex < wIndexArray[iIndexCount] + iMaxArray[iIndexCount];
       wIndex++)
    {
      /* Write the contents of the test array and test it. */
      for (iTestArrayIndex = 0;iTestArrayIndex < MAXSHORTPATS;iTestArrayIndex++)
      {
	wWriteVal = G_wTestShorts[iTestArrayIndex];
	ioRDTWriteDVP(wIndex,wWriteVal);
	/*Post 'em */
	UpdateGen();
	wReadVal = ioRDTReadDVP(wIndex) & wMaskArray[iMaskIndexB];
	if (wReadVal != (wWriteVal & wMaskArray[iMaskIndexB]))
	{
	  printf("DWU READ ERROR Index %04x Expected %04x Actual %04x \n",
	       wIndex,wWriteVal & wMaskArray[iMaskIndexB],wReadVal);
	}
      } /* for iTestIndex */
      iMaskIndexB++;
    } /* for wIndex */
  }

} /* End Test2070DwuRegs */

