/**********************************************************
*
*       File Name:  test2070_utils.c
*
*       Abstract: This file contains functions to setup
*          2070 units.
*
*      Author: Mike Corry
*      Date: 11/13/92
*
***********************************************************/

/* #includes --------------------------------------------*/
#include <stdio.h>
#include <stdlib.h>
#include <vga.h>
#include <asm/io.h>

#if 0
#include "evaldiag.h"
#include "evalprot.h"
#endif
#include "iodvp.h"
#include "iomd.h"
#include "px2070.h"

extern void dbox(void);
/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module assigns fifo F and fifo D
*               to the host.
*
*
*       Calling Sequence:
*       GetHostPorts()
*
*       Input Parameters:
*       none
*       Output Parameters:
*       none
*
*       Global Variables:
*       none
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/23/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void GetHostPorts()
{
/* reset datapath controls to flush any bogus state */
ioRDTWriteDVP(VIU_DPC1, 0);
ioRDTWriteDVP(VIU_DPC2, 0);
UpdateGen();

/* setup datapath controls for the Host */
ioRDTWriteDVP(VIU_DPC1, OPU_to_Host+IPU2_from_Host);
ioRDTWriteDVP(VIU_DPC2, OPU_to_Host+IPU2_from_Host);
UpdateGen();
} /* End GetHost Ports */

void SeqWait(iStartField)
{
  int iLastFieldId,iNewFieldId,iEnableStart;

  iEnableStart  = 0;
  iLastFieldId =  ioRDTReadDVP(i_VIU_TEST) & 0x4000;

  while (iEnableStart == 0)
  {
    iNewFieldId =  ioRDTReadDVP(i_VIU_TEST) & 0x4000;
    if (iLastFieldId != iNewFieldId)
    {
      if (iStartField == SIU_Start1)    /* Wait for trailing edge of mfldid */
      {
	if (iNewFieldId == 0x4000)
	  iLastFieldId = iNewFieldId;
	else
	  iEnableStart =1;
      } /* if SIU_Start1 */

      else                            /* Wait for leading edge of mfldid */
      {
	if (iNewFieldId == 0)
	  iLastFieldId = iNewFieldId;
	else
	  iEnableStart =1;
      } /* if !SIU_Start1 */
    } /* if iLastField != iNewField */
  } /* While */

} /* End SeqWait */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module sets the MMU for the standard
*       eval board configuration.
*
*       Calling Sequence:
*       SetUpMMU();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       none
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/24/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void SetUpMMU()
{
ioRDTWriteDVP(MMU_MCR,(FBWidth32 + FBType128K));
} /* End SetUpMMU */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module halts the sequencer.
*
*       Calling Sequence:
*       SeqHalt();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       none
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/23/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void SeqHalt()
{
/* halt sequencer */
ioRDTWriteDVP(i_SIU_MCR,SIU_Halt);
UpdateGen();
} /* End SeqHalt */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module manually starts the sequencer.
*
*       Calling Sequence:
*       SeqManStart();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       none
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/23/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void SeqManStart()
{
/* Generate Newfield to start sequencer -- */
ioRDTWriteDVP(i_VIU_WDT,VIU_MField_man);
UpdateGen();
ioRDTWriteDVP(i_VIU_WDT,VIU_MField_man+VIU_Man_Start);
UpdateGen();
} /* End SeqManStart */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module takes the VGA controller out of graphics
*               mode.
*
*       Calling Sequence:
*       ExitGraphicsMode();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       none
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/6/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void ExitGraphicsMode()
{
/*closegraph(); */



  /*vga_setmode(TEXT); */
/* If 2080 in system */
/*if (ioGetCurrentMD() !=-1) */
  ioGraphicsOvlyWriteMD(GOC_GRAPHICS_ONLY);
} /* End ExitGraphicsMode() */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module puts the VGA controller in graphics
*               mode so that windows may be opened for displaying images.
*
*       Calling Sequence:
*       iError = SetGraphicsMode();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       return 0=success iErrorCode = fail
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/5/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
unsigned char *vbuf;
int SetGraphicsMode()
{
int x=0,
    y=0;                          

#ifndef __XR__
if( vga_hasmode(20) )             
        vga_setmode(20);
else
  {
  printf("video mode not available.\n");
  exit(-1);
  }
  vga_setcolor(7);       
                       

for(x=0; x <= 640 ; x++)            
{
  for(y=0; y <= 480 ; y++)
  {
  vga_drawpixel(x,y);
  }
}
#endif
iopl(3);
/*
GOC_GRAPHICS_ONLY 0x0
GOC_CHROMA_ONLY   0xaa
GOC_ZCODE_ONLY    0xf
GOC_CHROMA_AND_ZCODE    0xa
*/

	/* If 2080 in system */
	/* ioGraphicsOvlyWriteMD(0xa); */
        outw_p(0xa,5457);
        /*
	ioRedChromaKeyWriteMD(0x7);
        */
        outw_p(0x7,5464);
        outw_p(0x7,5465);
        outw_p(0x7,5466);
        /*
	ioGreenChromaKeyWriteMD(0x7);
	ioBlueChromaKeyWriteMD(0x7);
        */
#ifndef __XR__
        drawpic("tv.raw",640,480);
#endif
	return(0);
} /* End SetGraphicsMode */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module fills a rectangle in VGA memory
*               and sets the 484module/2080 chroma key register to the
*               appropriate value.
*
*       Calling Sequence:
*       iError = OpenWindow(iXStart,iYStart,iWidth,iHeight);
*
*       Input Parameters:
*       iXStart         Location of upper left X coordinate
*       iYStart         Location of upper left Y coordinate
*       iWidth          X dimension of window in pixels
*       iHeight         Y dimension of window in pixels
*
*       Output Parameters:
*       return 0=success iErrorCode = fail
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   12/5/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int OpenWindow(iXStart,iYStart,iWidth,iHeight)

{
#ifdef 0
int iPoly[8];
int iColor, iMaxX, iMaxY;

iPoly[0] = iXStart;        /* 1st vertex */
iPoly[1] = iYStart;

iPoly[2] = iXStart + iWidth - 1; /* 2nd */
iPoly[3] = iYStart;

iPoly[4] = iXStart + iWidth - 1; /* 3rd */
iPoly[5] = iYStart + iHeight - 1;

/*
  4th vertex. fillpoly automatically
  closes the polygon.
*/
iPoly[6] = iXStart;
iPoly[7] = iYStart + iHeight - 1;

/* Test bounds */
if (iPoly[0] < 0)
  return(-1);

if (iPoly[1] < 0)
  return(-1);

iMaxX = getmaxx();
if (iPoly[2] > iMaxX)
  return(-1);

iMaxY = getmaxy();
if (iPoly[5] > iMaxY)
  return(-1);

/* set fill pattern */
iColor = getmaxcolor();
/*setfillstyle(SOLID_FILL, iColor/2); */

/* draw a filled polygon */
/*fillpoly(4, iPoly); */

#endif

return(0);
} /* End OpenWindow */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module sets up the border registers of the
*               2085 to position the image window.
*
*
*       Calling Sequence:
*       iError = OpenImageWindow(iXStart,iYStart,iWidth,iHeight);
*
*       Input Parameters:
*       iXStart         Location of upper left X coordinate
*       iYStart         Location of upper left Y coordinate
*       iWidth          X dimension of window in pixels
*       iHeight         Y dimension of window in pixels
*
*       Output Parameters:
*       return 0=success iErrorCode = fail
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   08/18/93
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int OpenImageWindow(iXStart,iYStart,iWidth,iHeight)

{

return(0);
} /* End OpenImageWindow */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module disables the specified object buffers.
*
*       Calling Sequence:
*       iError = OBReset(E_WhichObject)
*
*       Input Parameters:
*       E_WhichObject           object to be reset
*
*       Output Parameters:
*       iError          return code 0=success -1=fail
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/23/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int OBReset(E_WhichObject)
WhichObject E_WhichObject;

{
int iReturn=0;
switch (E_WhichObject)
  {
  case ALL_OBJECTS:
    /*Disable all objex */
    ioRDTWriteDVP(OBU0_MCR,0);
    ioRDTWriteDVP(OBU1_MCR,0);
    ioRDTWriteDVP(OBU2_MCR,0);
    ioRDTWriteDVP(OBU3_MCR,0);
    ioRDTWriteDVP(OBU4_MCR,0);
    ioRDTWriteDVP(OBU5_MCR,0);
    ioRDTWriteDVP(OBU6_MCR,0);
    ioRDTWriteDVP(OBU7_MCR,0);
    UpdateGen();
    break;
  case OBJECT0:
    ioRDTWriteDVP(OBU0_MCR,0);
    UpdateGen();
    break;
  case OBJECT1:
    ioRDTWriteDVP(OBU1_MCR,0);
    UpdateGen();
    break;
  case OBJECT2:
    ioRDTWriteDVP(OBU2_MCR,0);
    UpdateGen();
    break;
  case OBJECT3:
    ioRDTWriteDVP(OBU3_MCR,0);
    UpdateGen();
    break;
  case OBJECT4:
    ioRDTWriteDVP(OBU4_MCR,0);
    UpdateGen();
    break;
  case OBJECT5:
    ioRDTWriteDVP(OBU5_MCR,0);
    UpdateGen();
    break;
  case OBJECT6:
    ioRDTWriteDVP(OBU6_MCR,0);
    UpdateGen();
    break;
  case OBJECT7:
    ioRDTWriteDVP(OBU7_MCR,0);
    UpdateGen();
    break;
  default:
    iReturn = -1;
  }
return(iReturn);
} /* End OBReset */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module resets the specified fifo(s).
*
*       Calling Sequence:
*       ResetFifo(wData)
*
*       Input Parameters:
*       wData           fifo(s) to be reset
*
*       Output Parameters:
*       none
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/23/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void ResetFifo(wData)
unsigned short wData;

{
ioRDTWriteDVP(SIU_FCS,wData);
} /* End ResetFifo */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module enables the specified fifo(s).
*
*       Calling Sequence:
*       EnableFifo(wData)
*
*       Input Parameters:
*       wData           fifo(s) to be enabled
*
*       Output Parameters:
*       none
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/23/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void EnableFifo(wData)
unsigned short wData;

{
ioRDTWriteDVP(SIU_FCS,~wData);
} /* End EnableFifo */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module checks the full flag of
*                the specified fifo.
*
*       Calling Sequence:
*       iRetVal = IsFifoFull(E_WhichFifo)
*
*       Input Parameters:
*       E_WhichFifo             fifo to be checked
*
*       Output Parameters:
*       iRetVal         return code 0=not full
*                                   1=full
*                                  -1=fail
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/23/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int IsFifoFull(E_WhichFifo)
WhichFifo E_WhichFifo;

{
int iReturnVal=0;
switch (E_WhichFifo)
  {
  case FIFO_A:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & ALUA_FIFO);
    break;
  case FIFO_B:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & ALUB_FIFO);
    break;
  case FIFO_C:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & ALUC_FIFO);
    break;
  case FIFO_D:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & OPU_FIFO);
    break;
  case FIFO_E:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & ALUE_FIFO);
    break;
  case FIFO_F:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & IPU2_FIFO);
    break;
  case FIFO_G:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & IPU1_FIFO);
    break;
  default:
    iReturnVal = -1;
  }
return(iReturnVal);
} /* End IsFifoFull */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module checks the empty flag of
*                the specified fifo.
*
*       Calling Sequence:
*       iRetVal = IsFifoEmpty(E_WhichFifo)
*
*       Input Parameters:
*       E_WhichFifo             fifo to be checked
*
*       Output Parameters:
*       iRetVal         return code 0=not empty
*                                   1=empty
*                                  -1=fail
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/23/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int IsFifoEmpty(E_WhichFifo)
WhichFifo E_WhichFifo;

{
int iReturnVal=0;
switch (E_WhichFifo)
  {
  case FIFO_A:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & ALUA_FIFO>>1);
    break;
  case FIFO_B:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & ALUB_FIFO>>1);
    break;
  case FIFO_C:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & ALUC_FIFO>>1);
    break;
  case FIFO_D:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & OPU_FIFO>>1);
    break;
  case FIFO_E:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & ALUE_FIFO>>1);
    break;
  case FIFO_F:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & IPU2_FIFO>>1);
    break;
  case FIFO_G:
    iReturnVal = (ioRDTReadDVP(SIU_FCS) & IPU1_FIFO>>1);
    break;
  default:
    iReturnVal = -1;
  }
return(iReturnVal);
} /* End IsFifoEmpty */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module checks the almost empty flag of
*                fifo D or the almost full flag of fifo F.
*
*       Calling Sequence:
*       iRetVal = IsFifoBlastReady(E_WhichFifo)
*
*       Input Parameters:
*       E_WhichFifo             fifo to be checked
*
*       Output Parameters:
*       iRetVal         return code 0=not ready for blast
*                                   1=ready for blast
*                                  -1=fail
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/23/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
int IsFifoBlastReady(E_WhichFifo)
WhichFifo E_WhichFifo;

{
int iReturnVal=0;
switch (E_WhichFifo)
  {
  case FIFO_D:
    iReturnVal = (ioOCSReadDVP() & FIFO_ALMOST_EMPTY);
    break;
  case FIFO_F:
    iReturnVal = !(ioOCSReadDVP() & FIFO_ALMOST_FULL);
    break;
  default:
    iReturnVal = -1;
  }
return(iReturnVal);
} /* End IsFifoBlastReady */

/**********************************************************
*
*       File Name:  T2070UTL.c
*
*       Module Abstract: This module performs a soft reset of the 2070.
*
*       Calling Sequence:
*       SoftResetDVP();
*
*       Input Parameters:
*       none
*
*       Output Parameters:
*       none
*
*       Global Variables:
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   11/23/92
*
*       Revision History:
*       WHO             WHEN            WHAT/WHY/HOW
*
*
*********************************************************/
void SoftResetDVP()

{
ioOCSWriteDVP(SW_RESET);
ioOCSWriteDVP(0);
} /* End SoftResetDVP */

    /* ---------------------------------------------------- */
       void Setup_OB(offset,mc,refx,lah,lal,xsz,ysz,decm)
	 unsigned short offset,mc,refx,lah,lal,xsz,ysz,decm;
       {

	 ioRDTWriteDVP(offset+0,mc);
	 ioRDTWriteDVP(offset+1,refx);
	 ioRDTWriteDVP(offset+2,lal);
	 ioRDTWriteDVP(offset+3,lah);
	 ioRDTWriteDVP(offset+4,xsz);
	 ioRDTWriteDVP(offset+5,ysz);
	 ioRDTWriteDVP(offset+6,decm);
       } /* Setup_OB; */

    /*- ---------------------------------------------------- */
       void Setup_DW (offset,refx,lah,lal,xsz,xst,xzm,ysz,yst,yzm)
	 unsigned short offset,refx,lah,lal,xsz,xst,xzm,ysz,yst,yzm;
       {
 
	 ioRDTWriteDVP(offset+i_DWU_RFX,refx);
	 ioRDTWriteDVP(offset+i_DWU_LSH,lah);
	 ioRDTWriteDVP(offset+i_DWU_LSL,lal);
	 ioRDTWriteDVP(offset+i_DWU_WSX,xsz);
	 ioRDTWriteDVP(offset+i_DWU_DSX,xst);
	 ioRDTWriteDVP(offset+i_DWU_WSY,ysz);
	 ioRDTWriteDVP(offset+i_DWU_DSY,yst);
	 ioRDTWriteDVP(offset+i_DWU_DWZ,((yzm*256)+xzm));
       } /* Setup_DW; */

     /*-- ---------------------------------------------------- */

       void Setup_VSU (hsw,had,hap,hp,vsw,vad,vap,vp,vsumode)
       unsigned short hsw,had,hap,hp,vsw,vad,vap,vp,vsumode;

       {
	  ioRDTWriteDVP(i_VSU_HSW, hsw);
	  ioRDTWriteDVP(i_VSU_HAD, had);
	  ioRDTWriteDVP(i_VSU_HAP, hap);
	  ioRDTWriteDVP(i_VSU_HP,  hp);
	  ioRDTWriteDVP(i_VSU_VSW, vsw);
	  ioRDTWriteDVP(i_VSU_VAD, vad);
	  ioRDTWriteDVP(i_VSU_VAP, vap);
	  ioRDTWriteDVP(i_VSU_VP,  vp+vsumode);
       } /* Setup_VSU; */

     /*-- ---------------------------------------------------- */


       void Set_ALU_Constants (cay,cau,cav,cby,cbu,cbv,ccy,ccu,ccv)
       unsigned short cay,cau,cav,cby,cbu,cbv,ccy,ccu,ccv;
       {
	  ioRDTWriteDVP(i_ALU_CAY,cay);
	  ioRDTWriteDVP(i_ALU_CAU,cau);
	  ioRDTWriteDVP(i_ALU_CAV,cav);
	  ioRDTWriteDVP(i_ALU_CBY,cby);
	  ioRDTWriteDVP(i_ALU_CBU,cbu);
	  ioRDTWriteDVP(i_ALU_CBV,cbv);
	  ioRDTWriteDVP(i_ALU_CCY,ccy);
	  ioRDTWriteDVP(i_ALU_CCU,ccu);
	  ioRDTWriteDVP(i_ALU_CCV,ccv);
       } /* Set_ALU_constants; */

     /*-- ---------------------------------------------------- */

       void Set_ALU_Logic_Function(lopy,lopu,lopv)
       unsigned short lopy,lopu,lopv;
       {
	  ioRDTWriteDVP(i_ALU_LOPY,lopy);
	  ioRDTWriteDVP(i_ALU_LOPU,lopu);
	  ioRDTWriteDVP(i_ALU_LOPV,lopv);
       } /* Set_ALU_Logic_Function; */


    /* -- ---------------------------------------------------- */

       void Setup_Ip1 (offset,mcrval,xbi,xbf,xei,xsi,xsf,
		      ybi,ybf,yei,ysi,ysf)
       unsigned short offset,mcrval,xbi,xbf,xei,xsi,xsf;
       unsigned short ybi,ybf,yei,ysi,ysf;
       {
	  ioRDTWriteDVP(offset+i_MCR_offset,mcrval);  
	  ioRDTWriteDVP(offset+i_XBI_offset,xbi);   
	  ioRDTWriteDVP(offset+i_XBF_offset,xbf);   
	  ioRDTWriteDVP(offset+i_XEI_offset,xei); 
	  ioRDTWriteDVP(offset+i_XSI_offset,xsi);  
	  ioRDTWriteDVP(offset+i_XSF_offset,xsf); 
  
	  ioRDTWriteDVP(offset+i_YBI_offset,ybi);   
	  ioRDTWriteDVP(offset+i_YBF_offset,ybf);   
	  ioRDTWriteDVP(offset+i_YEI_offset,yei); 
	  ioRDTWriteDVP(offset+i_YSI_offset,ysi);  
	  ioRDTWriteDVP(offset+i_YSF_offset,ysf);   
       } /* Setup_Ip1; */

     /*-- ---------------------------------------------------- */

       void Setup_OP (offset,mcrval,xbi,xei,ybi,yei)
	 unsigned short offset,mcrval,xbi,xei,ybi,yei;
       {
	  ioRDTWriteDVP(offset+i_MCR_offset,mcrval);  
	  ioRDTWriteDVP(offset+i_XBI_offset,xbi);   
	  ioRDTWriteDVP(offset+i_XEI_offset,xei);   
	  ioRDTWriteDVP(offset+i_YBI_offset,ybi);   
	  ioRDTWriteDVP(offset+i_YEI_offset,yei); 
       } /* Setup_OP; */

       void Setup_Ip2 (offset,mcrval,xbi,xei,ybi,yei)
	 unsigned short offset,mcrval,xbi,xei,ybi,yei;
       {
	  ioRDTWriteDVP(offset+i_MCR_offset,mcrval);  
	  ioRDTWriteDVP(offset+i_XBI_offset,xbi);   
	  ioRDTWriteDVP(offset+i_XEI_offset,xei);   
	  ioRDTWriteDVP(offset+i_YBI_offset,ybi);   
	  ioRDTWriteDVP(offset+i_YEI_offset,yei); 
       } /* Setup_OP; */

      /*-- --------------------------------------------------- */
 
void UpdateGen()
{
	unsigned short wReadVal;

	wReadVal = ioOCSReadDVP();
	ioOCSWriteDVP(0x0380);
} /* UpdateGen */





 
