#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/keysym.h>
#include <unistd.h>

/* MIT Shared Memory Extension for X stuff */
#ifdef __MIT_SHM__
#include <sys/ipc.h>
#include <sys/shm.h>
#include <X11/extensions/XShm.h>
XShmSegmentInfo SHMInfo;
#endif

#include "evaldiag.h"
#include "evalprot.h"
#include "i2capi.h"
#include "iodvp.h"
#include "iomd.h"
#include "px2070.h"

#include <forms.h>

#include "tv_image.h"
#include "remote.h"

#define MAX_X       1024
#define MAX_Y       768
#define MIN_X       80
#define MIN_Y       60
#define XS 40
#define YS 40
#define MAX_XSIZE 346L
#define MAX_YSIZE 240L
#define X_RES	1024

FL_FORM		*form;
FL_OBJECT	*obj;
XImage		*ximage;
Display		*disp;
Window		win;
Screen		*screen;
GC			gc;
Colormap	cmap;
int			screen_num;
unsigned short	*cap_buf;

unsigned short RS0=0x100, RS1=0x8000;
unsigned short tmp;
extern void *G_pvConfigArray[MAXCONFIGARRAY];

Window tv_win;
int	card_present = 1;

int iWidth = 524; /* 346 */
int iHeight = 400; /* 240 */


int tv_setup()
{
	char keypress;
	unsigned long dwLoopCount=0x7fff;
	int iXSize, iYSize,iXRef,iStartField,iTemp;
	int iCurrentDVP;
	PX2070Ports *pPX2070AddrStruct;


	OpenPX();
	Test0001Regs(0);

	if(G_pvConfigArray[VIDMODBASE]!=NULL)
	{
		printf("Executing 9051 Tests \n");
		ioInitVid(NULL);
		printf("Executing Tuner Tests\n");
		ioInitTuner(NULL);
	}

	InitPx0001();
	ioInitVid(NULL);
	ioSetVidChannel(0);
	ioSetVideoHue(0);
	ioInitTuner();
	SetAudioSource(0);
	SetAudioMute( AUDIO_MUTE );
	SetGraphicsSource( PX1085_GRAPHICS );

iCurrentDVP = ioGetCurrentDVP();

pPX2070AddrStruct = (PX2070Ports *)G_pvConfigArray[iCurrentDVP];

/* Take the 1085 out of vafc mode */
ioRSV2WriteMD(2);

/* test */
//ioSyncAlignWriteMD( SAR_HSIN_HI );
//ioSyncAlignWriteMD( SAR_VSIN_HI );
ioSyncAlignWriteMD( SAR_NORMAL );
ioGraphicsFormatWriteMD( GFC_TRUE_COLOR );

/* disable the gamma palette */
ioVideoFormatWriteMD( VFC_GAMMA_DISABLE );

SetGraphicsMode();

iXSize = iWidth;
iYSize = iHeight;
iXRef  = X_RES;

    /* Do a soft reset */
    SoftResetDVP();

    /* halt sequencer */
    SeqHalt();

    /* Clear out the fifos */
    ResetFifo(ALL_FIFOS);

    /* Set up the MMU - tell it 32-bit  Frame Buffer Data Bus and 128k mem */
    SetUpMMU();

    /* Disable all objects - Writes 0 to all OBU?_MCR's */
    OBReset(ALL_OBJECTS);

    /* Disable Units - disables IPU1, IPU2, and OPU.  Is this really
       needed?  It should do the same basic thing when you set up
       your input/outputs later. It may flush out old data though. */
    ioRDTWriteDVP(i_VPU_MCR,0);

    /* Setup DWU to display a window */
    /* Among other things, disables all windows */
    ioRDTWriteDVP(DWU_MCR,0);
    
    /* OK, most registers so far are Posted, meaning they won't
       take effect until a field toggle or a manual request.  So
       be sure and do a manual request so things actually get flushed */
    UpdateGen();

    /* Don't really know.  Something about Horizontal Active Count.
       Specifies the number of pixel periods in the horizontal line
       active interval fore the output CRT display. */
    ioRDTWriteDVP(DWU_HCR, DW_VGA + 24);

    /* I'll use DWU0 for my display (even though I can't see it) */

    /* You can zoom in with this.  Formula is scaling = 256 / Zoom Factor.
       0 is a special case where it does a scaling factor of 1X. */
    ioRDTWriteDVP(DWU0_DZF, DW_ZOOM_1X);
    /* Reference Frame X Size */
    ioRDTWriteDVP(DWU0_RFX,iXRef);
    /* You could probably change these offsets to make the display
       window skip past unwanted data to be seen, such as the VBI.
       Overlay doesn't work for me so I don't know.  */
    ioRDTWriteDVP(DWU0_LSL,0);
    ioRDTWriteDVP(DWU0_LSH,0);
    ioRDTWriteDVP(DWU0_WSX,iXSize);
    ioRDTWriteDVP(DWU0_WSY,iYSize);
    /* The following Specifies te (X,Y) start position on your CRT to
       place the overlay window.  (0,0) is the upper left corner. */
    ioRDTWriteDVP(DWU0_DSX,2+10+160);
    ioRDTWriteDVP(DWU0_DSY,1+9+120);

    /* Means set Graphics Clock to 1x GPCLK if your interested
       and it also turns on Displa Window 0. */
    ioRDTWriteDVP(DWU_MCR,DW_1XCLOCK + DW_WIN0);

    /* This just reads the OCS register, then disable's all IRQ's,
       Imediately post any register updates that haven't been made
       yet. */
    UpdateGen();

    /* Setup Video Port 1 to have Input Video Vertical Sync Polarity */
    ioRDTWriteDVP(i_VIU_MCR1,VIU_IVSP_HI);

    /* Flush out anything related to Field 1. If someone wants to
       do full 60 frames a second for overlay mode they will need
       to initialize both DPC1 and DPC2 since DPC1=Field 1 and
       DPC2=Field 2.
     */
    ioRDTWriteDVP(i_VIU_DPC1, 0);
    UpdateGen();
    /* Field 1 comes from IPU1 and sources its sync from there and
     is also phase qualified. */
    ioRDTWriteDVP(i_VIU_DPC1, IPU1_from_Vp1_Phase);

    /* I'll use Object Buffer 0 for my input object */
    Setup_OB (OBU0_MCR,
	      /* Make Object Buffer 1 in Normal Address mod,
		 with X and Y BLT counters increasing its memory
		 address. */
	      (OB_Normal + OB_XBLT + OB_YBLT),
	      /* Needs to match DWU and IPU */
	      iXRef,
	      /* Offset into buffer to start.  Using anything other then
		 zero has strange results that I don't understand yet.
		 This is a 22-bit value.  The first specifies the
		 upper 6-bits and the 2nd value specifies the lower 16-bits.
	      */
	      0, 0,
	      /* You can also set the following so that Sync fields
		 in the right side aren't captured. */
	      iXSize, iYSize,
	      /* This is an 8-bit mask.  If a given bit is set then
		 for every 8 pixels read in, it will drop the pixel
		 that matches the bit location.  This is probably
	         of use as a fast scaler. */
	      0);

    /* offset,mcrval,xbi,xbf,xei,xsi,xsf,ybi,ybf,yei,ysi,ysf */
    /* Setup IP1 */
    Setup_Ip1 (i_IPU1_F1_BASE,
	       /* Input should always be 411 from Philips chip, I've
		  chosen RGB 5:6:5 output because its pretty simple to parse.
		  If you output RGB then you need to turn on the Color Space
		  Converter option. */
	       ColorConvert + In411 + OutRGBNoTag, /* In/Out Format */
	       /* The following two values define a floating point #.
		  The first # can only be a 11-bit value and the second
		  # can only be a 3-bit value.  They are combined in
		  hardware to make a 11.3 value.  For some reason the
		  first # has to be at least a 1.
	       */
	       1 + 9,0,		/* XStart */
	       /* Put where you want to stop here.  Make sure you don't
		  include horizontal sync area if you don't want that.
		  Also make sure you always set the following to at
		  least iXSize+Xstart-1
	       */
	       iXSize,		/* XStop */
	       /* Same as above on makeup for 4.10 value. */
	       1,0,		/* XShrink */
	       /* Same as above on makeup for 11.3 value. */
	       /* You could change this to something like 22,0
		  to skip the VBI data.
	       */
	       22,0,		/* YStart */
	       /* Put where you want to stop here.  Make sure you don't
		  include horizontal sync area if you don't want that.
		  Also make sure you always set the following to at
		  least iYSize+Ystart-1
	       */
	       iYSize,		/* YStop */
	       /* Same as above on makeup for 4.10 value. */
	       1,0		/* YShrink */
	);

    /* To SIU_FCS to Enable all FIFO's */
    EnableFifo(ALL_FIFOS);

    /* Enable IP1 */
    /* This Starts IPU1 on field 1, only the single field is processed */
    /* This probably make sences because we can supposedly only read up
       to 30 frames a second through the ISA bus which is what is
       equal to a single fields worth of data in 1 second. */
    /* Needs to be changed this for full 60-frames a second mode, probably
       to IP1_Start_F1. */
    ioRDTWriteDVP(i_VPU_MCR,IP1_F1_Only);

    UpdateGen();
    
    /* Only thing we want to do is copy data from V1 to Object Buffer 0. */
    /* Do this and loop back to the same instruction. */
    ioRDTWriteDVP(SIU_SIM0,(IPU1_to_OB0 + offset_0));      /* Seq Inst 0 */

    /* (SIU_SI1 * 0) means place a Starting Address of 0 into the part of
       the register that contains Start Index 1. */
    ioRDTWriteDVP(i_SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

    /* wait to start the sequencer */
    SeqWait(SIU_Start1);

	return( card_present );
} 


int new_resize( int x, int y, int w, int h, int xref )
{
	long lx, ly, lw, lh;
	char keypress;
	unsigned long dwLoopCount=0x7fff;
	int iXSize, iYSize,iXRef,iStartField,iTemp;


	lx = x;
	ly = y;
	lw = ( w / 2 ) * 2;	// this done to make sure we have multiple of 2
	lh = ( h / 2 ) * 2;	// this done to make sure we have multiple of 2

	iXSize = iWidth = w;
	iYSize = iHeight = h;
	iXRef  = xref;

	/* Do a soft reset */
	SoftResetDVP();

	/* halt sequencer */
	SeqHalt();

	/* setup datapath controls */
	GetHostPorts();

	/* Clear out the fifos */
	ResetFifo(ALL_FIFOS);

	/* Set up the MMU */
	SetUpMMU();

	/* Disable all objects */
	OBReset(OBJECT0);

	XDestroyImage( ximage );

#ifdef __MIT_SHM__
	ximage = XShmCreateImage(disp, DefaultVisual(disp, screen_num),
		iImageDepth, ZPixmap, NULL, &SHMInfo, iWidth, iHeight );
	ximage->data = SHMInfo.shmaddr;
#else
	ximage = XCreateImage( disp, DefaultVisual( disp, screen_num ), iImageDepth,
		ZPixmap, 0, (char *)cap_buf, iWidth, iHeight, iImageDepth, 0 );
#endif

	/* Disable Units */
	ioRDTWriteDVP(i_VPU_MCR,0);
	ioRDTWriteDVP(DWU_MCR,0);
	UpdateGen();

	/* Setup DWU to display a window */
	ioRDTWriteDVP(DWU_HCR, DW_VGA + 24 );
	ioRDTWriteDVP(DWU0_DZF, DW_ZOOM_1X);
	ioRDTWriteDVP(DWU0_RFX,iXRef);
	ioRDTWriteDVP(DWU0_LSL,0);
	ioRDTWriteDVP(DWU0_LSH,0);
	ioRDTWriteDVP(DWU0_WSX,iXSize);
	ioRDTWriteDVP(DWU0_WSY,iYSize);
	ioRDTWriteDVP(DWU0_DSX,x + 31);
	ioRDTWriteDVP(DWU0_DSY,y + 31);

	ioRDTWriteDVP(DWU_MCR, DW_1XCLOCK + DW_WIN0 );

	UpdateGen();

	/* Setup Video Port 1 */
	ioRDTWriteDVP(i_VIU_MCR1,VIU_IVSP_HI);

	ioRDTWriteDVP(i_VIU_DPC1, 0 );
	UpdateGen();

	/* setup datapath controls */
	ioRDTWriteDVP(i_VIU_DPC1, IPU1_from_Vp1_Phase );
	//ioRDTWriteDVP(i_VIU_DPC1, IPU1_from_Vp1_Phase +
	//	      IPU2_from_Vp1_Phase);
	//OBReset (OBJECT0);
	//OBReset (OBJECT1);
	Setup_OB (OBU0_MCR, (OB_Normal + OB_XBLT + OB_YBLT ),
		  iXRef, 0, 0,
		  iXSize, iYSize, 0);

	/* Setup IP1 */
	Setup_Ip1 (i_IPU1_F1_BASE,
		   ColorConvert + In411 + OutRGBNoTag,  /* MCR */
			1, 0,								/* XStart */
			iXSize * 2,						/* XStop */
			2,0,							/* XShrink (11.3 float) */
//			X_RES / iXSize, 0,
			22, 0,							/* YStart */
			iYSize + 22,							/* YStop */
			1,0								/* YShrink (11.3 float) */
		   );

	EnableFifo(ALL_FIFOS);

	/* Enable IP1 */
	ioRDTWriteDVP(i_VPU_MCR,IP1_F1_Only );
//	ioRDTWriteDVP(i_VPU_MCR,IP1_F1_Only + IP2_F1_Only);
	UpdateGen();

//	ioOCSWriteDVP(0x100);
	/* Sequencer start */
	ioRDTWriteDVP(SIU_SIM0,(IPU1_to_OB0 + offset_0));          /* Seq Inst 0 */
//	ioRDTWriteDVP(SIU_SIM1,(IPU2_to_OB1 + offset_M1));  /* Seq Inst 1 */

	ioRDTWriteDVP(i_SIU_MCR,(SIU_Start1 + SIU_No_Toggle + (SIU_SI1 * 0)));

	/* wait to start the sequencer */
	SeqWait(SIU_Start1);

	return( card_present );
} 



void resize_image( int x, int y, int w, int h, int xref )
{
	unsigned short usReadVal;
	long lx, ly, lw, lh;

	ioRDTWriteDVP( DWU0_DZF, DW_ZOOM_1X );
	ioRDTWriteDVP( DWU0_RFX, xref );
	ioRDTWriteDVP( DWU0_LSL, 0 );
	ioRDTWriteDVP( DWU0_LSH, 0 );
	ioRDTWriteDVP( DWU0_WSX, w );
	ioRDTWriteDVP( DWU0_WSY, h );
	ioRDTWriteDVP( DWU0_DSX, x + 309 );
	ioRDTWriteDVP( DWU0_DSY, y + 31 );
	UpdateGen();

	Setup_OB (OBU0_MCR, (OB_Normal + OB_XBLT + OB_YBLT), xref, 0, 0, w, h, 0);

	lx = x; ly = y; lw = w; lh = h;

	Setup_Ip1 (i_IPU1_F1_BASE,
		ColorConvert + In411 + OutRGBNoTag/*+ColorConvert*/,  // MCR
		1, 0,								/* XStart */
		346 * 2,						/* XStop */
		((( 346 << 17 ) / lw ) >> 16 ) & 0xffff, 	/* XShrinkI */
		(( 346 << 17 ) / lw ),		/* XShrinkF */
		1 + 9, 0,							/* YStart */
		240 * 2 + 9,						/* YStop */
		0,5
//		((( h << 17 ) / lh ) >> 16 ) & 0xffff,	/* YShrinkI */
//		(( h << 17 ) / lh )			/* YShrinkF */
		);

    ioOCSWriteDVP(0x0200); // enable update
    usReadVal = ioOCSReadDVP();
    while ((usReadVal & 0x0300) !=0 ){   // wait one field
     usReadVal = ioOCSReadDVP();
    }
    ioOCSWriteDVP(0x0100); // enable update
    usReadVal = ioOCSReadDVP();
    while ((usReadVal & 0x0100) !=0 ){  // wait one field
     usReadVal = ioOCSReadDVP();
    }

XDestroyImage( ximage );

#ifdef __MIT_SHM__
ximage = XShmCreateImage(disp, DefaultVisual(disp, screen_num),
	iImageDepth, ZPixmap, NULL, &SHMInfo, iWidth, iHeight );
ximage->data = SHMInfo.shmaddr;
#else
ximage = XCreateImage( disp, DefaultVisual( disp, screen_num ), iImageDepth,
	ZPixmap, 0, (char *)cap_buf, iWidth, iHeight, iImageDepth, 0 );
#endif
}

void tv_set_image_to_window( Window window )
{
	int		x, y, w, h;
	int		tvs_magic_number;


	if ( ! card_present )
	{
		return;
	}

	fl_get_wingeometry( window, &x, &y, &w, &h );

//	printf( "cp=%d, x=%d, y=%d, w=%d, h=%d\n", card_present, x, y, w, h );

	iWidth = w;
	iHeight = h;

	/* magic number, need to get formula for this if there is one */
	tvs_magic_number = 1024;

	// update the size & change position
#ifdef NEW_RESIZE
	new_resize_image( x, y, w, h, tvs_magic_number );
#else
	resize_image( x, y, w, h, tvs_magic_number );
#endif
}

void fixup_interlace()
{
	unsigned short tmp_buf[ 2000 ];
	int i;

//	printf( "fixup_interlace(): h= %d, w = %d\n", iWidth, iHeight );
	for ( i = iHeight / 2; i > 0 ; i-- )
	{
		memcpy( &cap_buf[ ( i * 2 - 1 ) * iWidth ],
			&cap_buf[  i * iWidth ],
			sizeof( unsigned short ) * iWidth );
		memcpy( &cap_buf[ ( i * 2 ) * iWidth ],
			&cap_buf[ i * iWidth ],
			sizeof( unsigned short ) * iWidth );
	}
}

void capture_and_paste()
{
	int cnt;
	int iXSize, iYSize,iXRef,iStartField,iTemp;
	int ReadX, ReadY;

	iXSize = iWidth;
	iYSize = iHeight;
	iXRef  = X_RES;

	if ( !card_present )
		return;

#ifndef __XTV__
	SeqHalt();
	GetHostPorts();
	OBReset( OBJECT0 );
	ioRDTWriteDVP(SIU_SIM0,(IPU1_to_OB0 + offset_0)); // Seq Inst 0 --
	Setup_OB(OBU0_MCR,OB_Normal+OB_SSM+OB_XBLT+OB_YBLT+OB_No_Copy,
		iXRef,0,0,iXSize,iYSize,0);
	ioRDTWriteDVP(SIU_SIM0,(OB0_to_OP+offset_0));
	ioRDTWriteDVP(SIU_MCR,(SIU_Start1+SIU_No_Toggle+(SIU_SI1*0)));
	ResetFifo(ALL_FIFOS);
	EnableFifo(ALL_FIFOS);
	SeqManStart();

	cnt=0;


#ifdef __USE_BLAST__
//	printf( "blast " );
	fflush( stdout );
	ioMDTBlastReadDVP( cap_buf, iXSize * iYSize );
#else
//	printf( "cnt = %d\n", cnt );
	while(!IsFifoEmpty(FIFO_D)&&(cnt<iXSize*iYSize))
//	while(cnt<iXSize*iYSize)
		cap_buf[cnt++] = ioMDTShortReadDVP();
//	printf( "cnt = %d\n", cnt );
#endif

	fixup_interlace();

#ifdef __MIT_SHM__
	XShmPutImage(disp, win, gc, ximage, 0, 0, 0, 0, iXSize, iYSize, False );
#else
	XPutImage(disp, win, gc, ximage, 0, 0, 0, 0, iXSize, iYSize );
#endif
	XFlush(disp);

	ResetFifo(ALL_FIFOS);
	ioRDTWriteDVP(i_VIU_WDT,0);
	ioRDTWriteDVP(i_VPU_MCR,0);
	ioRDTWriteDVP(i_VIU_DPC1, IPU1_from_Vp1_Phase);
	OBReset (OBJECT0);
	Setup_OB (OBU0_MCR, (OB_Normal+OB_XBLT + OB_YBLT),
			  iXRef, 0, 0,
			  iXSize, iYSize, 0);
	EnableFifo(ALL_FIFOS);
	ioRDTWriteDVP(i_VPU_MCR,IP1_F1_Only);
	ioOCSWriteDVP(0x100);
	ioRDTWriteDVP(SIU_SIM0,(IPU1_to_OB0 + offset_0)); /* Seq Inst 0 */

#else
	    /* Freeze Image */
	    SeqHalt();

	    /* Disable all objects - Writes 0 to all OBU?_MCR's */
	    OBReset(OBJECT2);

	    /* Field 1 comes from IPU1 and sources its sync from there and
	       is also phase qualified. But Flush First. */
	    ioRDTWriteDVP(i_VIU_DPC1, 0);
	    UpdateGen();
	    
	    ioRDTWriteDVP(i_VIU_DPC1, OPU_to_Host);
	    
	    Setup_OB(OBU2_MCR,OB_Normal+OB_SSM+OB_XBLT+OB_YBLT+OB_No_Copy,
		     iXRef,0,0,
		     iXSize,iYSize,0);
	    ioRDTWriteDVP(SIU_SIM0,(OB2_to_OP+offset_0));
	    ioRDTWriteDVP(i_SIU_MCR,(SIU_Start1 + SIU_No_Toggle +
				     (SIU_SI1 * 0)));

	    /* Clear out the fifos */
	    ResetFifo(ALL_FIFOS);
	    /* To SIU_FCS to Enable all FIFO's */
	    EnableFifo(ALL_FIFOS);
	    UpdateGen();
	    
	    SeqManStart();
	     
	    cnt=0;

		printf( "cnt = %d\n", cnt );
	    while(!IsFifoEmpty(FIFO_D)&&(cnt<iXSize*iYSize))
//	    while(cnt<iXSize*iYSize)
			cap_buf[cnt++] = ioMDTShortReadDVP();

//		ioMDTBlastReadDVP( cap_buf, iXSize * iYSize );

		printf( "cnt = %d\n", cnt );

#ifndef __MIT_SHM__
		XShmPutImage(disp, win, gc, ximage, 0, 0, 0, 0, iXSize, iYSize, False );
#else
		XPutImage(disp, win, gc, ximage, 0, 0, 0, 0, iXSize, iYSize );
#endif
		XFlush(disp);

		SeqHalt();

	    /* The following code is close to the minimum needed to
	       start moving data again.  For some reason, there is a
	       problem that the captured video starts to "roll".  Does
	       it do this on the overlay video???  If I remove all this
	       code and copy EVERYTHING from the SoftReset() above down
	       to the begining of the while() loop then this problem
	       stops.  Kinda extreme to do a soft reset between each capture
	       though!  FIX ME FIX ME FIX ME PLEASE PLEASE PLEASE 
	     */

	    /* Clear out the fifos */
	    ResetFifo(ALL_FIFOS);

	    /* Disable all objects - Writes 0 to all OBU?_MCR's */
//        OBReset(ALL_OBJECTS);
        OBReset(OBJECT0);

        /* Make sure Vertical Sync toggles Master Field Select */
        ioRDTWriteDVP(i_VIU_WDT,0);
        UpdateGen();

        /* Setup Video Port 1 to have Input Video Vertical Sync Polarity */
        ioRDTWriteDVP(i_VIU_MCR1,VIU_IVSP_HI);

        /* Field 1 comes from IPU1 and sources its sync from there and
           is also phase qualified. But Flush First. */
        ioRDTWriteDVP(i_VIU_DPC1, 0);
        UpdateGen();
        ioRDTWriteDVP(i_VIU_DPC1, IPU1_from_Vp1_Phase);

	    /* I'll use Object0 for my input object */
	    Setup_OB (OBU0_MCR, (OB_Normal + OB_XBLT + OB_YBLT),
		      iXRef, 0, 0,
		      iXSize, iYSize, 0);

	    /* To SIU_FCS to Enable all FIFO's */
	    EnableFifo(ALL_FIFOS);
	    UpdateGen();

	    /* Only thing we want to do is copy data from V1 to Object
	       Buffer 0. */
	    /* Do this and loop back to the same instruction. */
	    ioRDTWriteDVP(SIU_SIM0,(IPU1_to_OB0 + offset_0));      /* Seq Inst 0 */

	    /* (SIU_SI1 * 0) means place a Starting Address of 0 into the
	       part of the register that contains Start Index 1. */
	    ioRDTWriteDVP(i_SIU_MCR,(SIU_Start1 + SIU_No_Toggle +
				     (SIU_SI1 * 0)));

	    /* wait to start the sequencer till trailing edge of mfldid */
	    SeqWait(SIU_Start1);
#endif
}

void refresh_image()
{
#ifndef __MIT_SHM__
	XShmPutImage(disp, win, gc, ximage, 0, 0, 0, 0, iWidth, iHeight, False );
#else
	XPutImage(disp, win, gc, ximage, 0, 0, 0, 0, iWidth, iHeight );
#endif
	XFlush(disp);
}


/*
 * TV Window event callback routine
 */
int tv_callback(XEvent *xev, void *p)
{
	fl_winset( tv_win );

	capture_and_paste();

	if ( xev->type == ConfigureNotify )
	{
		tv_set_image_to_window( xev->xconfigure.window );
	}

	if ( xev->type == Expose )
	{
		tv_set_image_to_window( xev->xexpose.window );
	}

	return 0;
}

/*
 * routine to create TV window
 */
Window tv_create_win( void )
{
	Window	tv;

	XGCValues values;

	fl_initial_winsize( iWidth, iHeight );
	fl_winminsize( 0, MIN_X, MIN_Y );
	fl_winmaxsize( 0, MAX_X, MAX_Y );
//	fl_winaspect( 0, iWidth, iHeight );
	fl_winbackground( 0, 7 );
	tv = fl_winopen( "TV" );
	fl_set_event_callback( tv_callback, 0 );

	win = tv;

	disp = XOpenDisplay( "localhost:0.0" );
	gc = XCreateGC(disp, win, 0, &values );
	screen = DefaultScreenOfDisplay(disp);
	screen_num = DefaultScreen(disp);
	iImageDepth = DefaultDepthOfScreen(screen);

#ifdef __MIT_SHM__
	ximage = XShmCreateImage(disp, DefaultVisual(disp, screen_num),
		iImageDepth, ZPixmap, NULL, &SHMInfo, iWidth, iHeight);
	SHMInfo.shmid = shmget( IPC_PRIVATE,
		MAX_X * MAX_Y * sizeof( unsigned short ), IPC_CREAT|0777);
	cap_buf = (unsigned short *)ximage->data = SHMInfo.shmaddr =
		shmat(SHMInfo.shmid, 0, 0 );
	XShmAttach( disp, &SHMInfo );
	XSync( disp, 0 );
#else
	ximage = XCreateImage(disp, DefaultVisual(disp,screen_num), iImageDepth,
		ZPixmap, 0, (char *)cap_buf, iWidth, iHeight, iImageDepth, 0 );
	cap_buf = malloc( MAX_X * MAX_Y * sizeof( unsigned short ));
#endif

	printf( "Screen depth: %d\n", iImageDepth );

	return tv;
}

void tv_destroy()
{
#ifdef __MIT_SHM__
	XDestroyImage( ximage );
	XShmDetach( disp, &SHMInfo );
	shmdt( SHMInfo.shmaddr );
	shmctl( SHMInfo.shmid, IPC_RMID, 0 );
#else
	free( cap_buf );
#endif
}
